﻿using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Data.Linq.Mapping;
using PTMIBase.Entity;

namespace DongGuanWI.Entity.Inpatient
{
    class AdmissionRegistrationInput:EntityBase
    {
        /// <summary>
        /// 交易号
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "function_id", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "交易号不能为空")]
        [StringLength(20, ErrorMessage = "交易号长度不能超过20个字符")]
        public string function_id { get; set; }

        /// <summary>
        /// 入参类型
        /// 类型：string, 长度：70, 不允许为空
        /// 备注：aac001电脑号；aac002社会保障号码；bka100社保卡号；aaz218就医登记号
        /// </summary>
        [Column(Name = "bka895", Storage = null, DbType = "VarChar(70)", CanBeNull = false)]
        [Required(ErrorMessage = "入参类型不能为空")]
        [StringLength(70, ErrorMessage = "入参类型长度不能超过70个字符")]
        public string bka895 { get; set; }

        /// <summary>
        /// 入参值
        /// 类型：string, 长度：70, 不允许为空
        /// </summary>
        [Column(Name = "bka896", Storage = null, DbType = "VarChar(70)", CanBeNull = false)]
        [Required(ErrorMessage = "入参值不能为空")]
        [StringLength(70, ErrorMessage = "入参值长度不能超过70个字符")]
        public string bka896 { get; set; }

        /// <summary>
        /// 医疗机构编码
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "akb020", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "医疗机构编码不能为空")]
        [StringLength(20, ErrorMessage = "医疗机构编码长度不能超过20个字符")]
        public string akb020 { get; set; }

        /// <summary>
        /// 医疗待遇类型
        /// 类型：string, 长度：6, 不允许为空
        /// 备注：见码表
        /// </summary>
        [Column(Name = "bka006", Storage = null, DbType = "VarChar(6)", CanBeNull = false)]
        [Required(ErrorMessage = "医疗待遇类型不能为空")]
        [StringLength(6, ErrorMessage = "医疗待遇类型长度不能超过6个字符")]
        public string bka006 { get; set; }
    }

    class AdmissionRegistrationOutput : EntityBase
    {
        public List<BizInfoOfRegisterRtn> bizInfo;
    }

    class BizInfoOfRegisterRtn : EntityBase
    {
        /// <summary>
        /// 医疗机构编号
        /// 类型：string, 长度：20, 默认可空
        /// </summary>
        [Column(Name = "akb020", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20, ErrorMessage = "医疗机构编号长度不能超过20个字符")]
        public string akb020 { get; set; }

        /// <summary>
        /// 业务类型
        /// 类型：string, 长度：2, 默认可空
        /// 备注：见码表
        /// </summary>
        [Column(Name = "aka130", Storage = null, DbType = "VarChar(2)", CanBeNull = true)]
        [StringLength(2, ErrorMessage = "业务类型长度必须为2个字符")]
        public string aka130 { get; set; }

        /// <summary>
        /// 工伤保险中心编码
        /// 类型：string, 长度：6, 默认可空
        /// </summary>
        [Column(Name = "aaa027", Storage = null, DbType = "VarChar(6)", CanBeNull = true)]
        [StringLength(6, ErrorMessage = "工伤保险中心编码长度不能超过6个字符")]
        public string aaa027 { get; set; }

        /// <summary>
        /// 电脑号
        /// 类型：string, 长度：20, 默认可空
        /// </summary>
        [Column(Name = "aac001", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20, ErrorMessage = "电脑号长度不能超过20个字符")]
        public string aac001 { get; set; }

        /// <summary>
        /// 姓名
        /// 类型：string, 长度：20, 默认可空
        /// </summary>
        [Column(Name = "aac003", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20, ErrorMessage = "姓名长度不能超过20个字符")]
        public string aac003 { get; set; }

        /// <summary>
        /// 性别
        /// 类型：string, 长度：1, 默认可空
        /// 备注："2"——"女"，"1"——"男"
        /// </summary>
        [Column(Name = "aac004", Storage = null, DbType = "VarChar(1)", CanBeNull = true)]
        [StringLength(1, ErrorMessage = "性别长度必须为1个字符")]
        public string aac004 { get; set; }

        /// <summary>
        /// 社会保障号码
        /// 类型：string, 长度：25, 默认可空
        /// </summary>
        [Column(Name = "aac002", Storage = null, DbType = "VarChar(25)", CanBeNull = true)]
        [StringLength(25, ErrorMessage = "社会保障号码长度不能超过25个字符")]
        public string aac002 { get; set; }

        /// <summary>
        /// 工伤保险卡号
        /// 类型：string, 长度：25, 默认可空
        /// </summary>
        [Column(Name = "bka100", Storage = null, DbType = "VarChar(25)", CanBeNull = true)]
        [StringLength(25, ErrorMessage = "工伤保险卡号长度不能超过25个字符")]
        public string bka100 { get; set; }

        /// <summary>
        /// 出生日期
        /// 类型：string, 长度：10, 默认可空
        /// 格式：yyyyMMdd
        /// </summary>
        [Column(Name = "aac006", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "出生日期长度必须为10个字符")]
        public string aac006 { get; set; }

        /// <summary>
        /// 联系电话
        /// 类型：string, 长度：20, 默认可空
        /// </summary>
        [Column(Name = "aae005", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20, ErrorMessage = "联系电话长度不能超过20个字符")]
        public string aae005 { get; set; }

        /// <summary>
        /// 单位编码
        /// 类型：string, 长度：20, 默认可空
        /// </summary>
        [Column(Name = "aab001", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20, ErrorMessage = "单位编码长度不能超过20个字符")]
        public string aab001 { get; set; }

        /// <summary>
        /// 单位名称
        /// 类型：string, 长度：150, 默认可空
        /// </summary>
        [Column(Name = "bka008", Storage = null, DbType = "VarChar(150)", CanBeNull = true)]
        [StringLength(150, ErrorMessage = "单位名称长度不能超过150个字符")]
        public string bka008 { get; set; }

        /// <summary>
        /// 医师编码
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "bka503", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "医师编码长度不能超过10个字符")]
        public string bka503 { get; set; }

        /// <summary>
        /// 参保地统筹区
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "baa027", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "参保地统筹区长度不能超过10个字符")]
        public string baa027 { get; set; }

        /// <summary>
        /// 待遇类别
        /// 类型：string, 长度：10, 默认可空
        /// 备注：见码表
        /// </summary>
        [Column(Name = "bka006", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "待遇类别长度不能超过10个字符")]
        public string bka006 { get; set; }

        /// <summary>
        /// 业务登记日期
        /// 类型：string, 长度：10, 默认可空
        /// 格式：yyyyMMdd
        /// </summary>
        [Column(Name = "bka013", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "业务登记日期长度必须为10个字符")]
        public string bka013 { get; set; }

        /// <summary>
        /// 登记人工号
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "bka014", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "登记人工号长度不能超过10个字符")]
        public string bka014 { get; set; }

        /// <summary>
        /// 结束人
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "bka034", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "结束人长度不能超过10个字符")]
        public string bka034 { get; set; }

        /// <summary>
        /// 结束人工号
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "bka033", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "结束人工号长度不能超过10个字符")]
        public string bka033 { get; set; }

        /// <summary>
        /// 结算标识
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "bka891", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "结算标识长度不能超过10个字符")]
        public string bka891 { get; set; }

        /// <summary>
        /// 完成标志
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "bka039", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "完成标志长度不能超过10个字符")]
        public string bka039 { get; set; }

        /// <summary>
        /// 登记人
        /// 类型：string, 长度：20, 默认可空
        /// </summary>
        [Column(Name = "bka015", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20, ErrorMessage = "登记人长度不能超过20个字符")]
        public string bka015 { get; set; }

        /// <summary>
        /// 出院日期
        /// 类型：string, 长度：10, 默认可空
        /// 格式：yyyyMMdd
        /// </summary>
        [Column(Name = "bka032", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "出院日期长度必须为10个字符")]
        public string bka032 { get; set; }

        /// <summary>
        /// 出院疾病诊断
        /// 类型：string, 长度：20, 默认可空
        /// </summary>
        [Column(Name = "bka031", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20, ErrorMessage = "出院疾病诊断长度不能超过20个字符")]
        public string bka031 { get; set; }

        /// <summary>
        /// 住院天数
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "bka030", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "住院天数长度不能超过10个字符")]
        public string bka030 { get; set; }

        /// <summary>
        /// 定点医疗机构名称
        /// 类型：string, 长度：50, 默认可空
        /// </summary>
        [Column(Name = "akb021", Storage = null, DbType = "VarChar(50)", CanBeNull = true)]
        [StringLength(50, ErrorMessage = "定点医疗机构名称长度不能超过50个字符")]
        public string akb021 { get; set; }

        /// <summary>
        /// 就医登记号
        /// 类型：string, 长度：20, 默认可空
        /// </summary>
        [Column(Name = "aaz218", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20, ErrorMessage = "就医登记号长度不能超过20个字符")]
        public string aaz218 { get; set; }

        /// <summary>
        /// 住院时间
        /// 类型：string, 长度：10, 默认可空
        /// 格式：yyyyMMdd
        /// </summary>
        [Column(Name = "bka017", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "住院时间长度必须为10个字符")]
        public string bka017 { get; set; }

        /// <summary>
        /// 入院科室
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "bka019", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "入院科室长度不能超过10个字符")]
        public string bka019 { get; set; }

        /// <summary>
        /// 入院病区
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "bka021", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "入院病区长度不能超过10个字符")]
        public string bka021 { get; set; }

        /// <summary>
        /// 入院床位号
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "bka023", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "入院床位号长度不能超过10个字符")]
        public string bka023 { get; set; }

        /// <summary>
        /// 住院号
        /// 类型：string, 长度：20, 默认可空
        /// </summary>
        [Column(Name = "bka025", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20, ErrorMessage = "住院号长度不能超过20个字符")]
        public string bka025 { get; set; }

        /// <summary>
        /// 入院疾病诊断（ICD码）
        /// 类型：string, 长度：20, 默认可空
        /// </summary>
        [Column(Name = "bka026", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20, ErrorMessage = "入院疾病诊断（ICD码）长度不能超过20个字符")]
        public string bka026 { get; set; }

        /// <summary>
        /// 用卡标志
        /// 类型：string, 长度：1, 默认可空
        /// </summary>
        [Column(Name = "bka036", Storage = null, DbType = "VarChar(1)", CanBeNull = true)]
        [StringLength(1, ErrorMessage = "用卡标志长度必须为1个字符")]
        public string bka036 { get; set; }

        /// <summary>
        /// 工伤凭证号
        /// 类型：string, 长度：20, 默认可空
        /// 备注：工伤业务
        /// </summary>
        [Column(Name = "bka042", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20, ErrorMessage = "工伤凭证号长度不能超过20个字符")]
        public string bka042 { get; set; }

        /// <summary>
        /// 备注
        /// 类型：string, 长度：100, 默认可空
        /// </summary>
        [Column(Name = "bka043", Storage = null, DbType = "VarChar(100)", CanBeNull = true)]
        [StringLength(100, ErrorMessage = "备注长度不能超过100个字符")]
        public string bka043 { get; set; }

        /// <summary>
        /// 结算日期
        /// 类型：string, 长度：10, 默认可空
        /// 格式：yyyyMMdd
        /// </summary>
        [Column(Name = "bka045", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "结算日期长度必须为10个字符")]
        public string bka045 { get; set; }

        /// <summary>
        /// 结算人工号
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "bka046", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "结算人工号长度不能超过10个字符")]
        public string bka046 { get; set; }

        /// <summary>
        /// 结算人
        /// 类型：string, 长度：20, 默认可空
        /// </summary>
        [Column(Name = "bka047", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20, ErrorMessage = "结算人长度不能超过20个字符")]
        public string bka047 { get; set; }

        /// <summary>
        /// 医院级别
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "bka502", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "医院级别长度不能超过10个字符")]
        public string bka502 { get; set; }

        /// <summary>
        /// 行政区域
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "bka501", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "行政区域长度不能超过10个字符")]
        public string bka501 { get; set; }

        /// <summary>
        /// 行政职务级别
        /// 类型：string, 长度：3, 默认可空
        /// </summary>
        [Column(Name = "bka005", Storage = null, DbType = "VarChar(3)", CanBeNull = true)]
        [StringLength(3, ErrorMessage = "行政职务级别长度不能超过3个字符")]
        public string bka005 { get; set; }

        /// <summary>
        /// 人员类别
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "bka004", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "人员类别长度不能超过10个字符")]
        public string bka004 { get; set; }

        /// <summary>
        /// 险种编码
        /// 类型：string, 长度：6, 默认可空
        /// 备注："410"——"工伤"
        /// </summary>
        [Column(Name = "aae140", Storage = null, DbType = "VarChar(6)", CanBeNull = true)]
        [StringLength(6, ErrorMessage = "险种编码长度不能超过6个字符")]
        public string aae140 { get; set; }
    }
}
