﻿using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Data.Linq.Mapping;
using PTMIBase.Entity;


namespace DongGuanWI.Entity.Inpatient
{
    class DischargeRegistrationInput:EntityBase
    {
        /// <summary>
        /// 交易号
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "function_id", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "交易号不能为空")]
        [StringLength(20, ErrorMessage = "交易号长度不能超过20个字符")]
        public string function_id { get; set; }

        /// <summary>
        /// 医疗机构编码
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "akb020", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "医疗机构编码不能为空")]
        [StringLength(20, ErrorMessage = "医疗机构编码长度不能超过20个字符")]
        public string akb020 { get; set; }

        /// <summary>
        /// 就医登记号
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "aaz218", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "就医登记号不能为空")]
        [StringLength(20, ErrorMessage = "就医登记号长度不能超过20个字符")]
        public string aaz218 { get; set; }

        /// <summary>
        /// 出院日期
        /// 类型：string, 长度：10, 不允许为空
        /// 格式：yyyyMMdd
        /// </summary>
        [Column(Name = "bka032", Storage = null, DbType = "VarChar(10)", CanBeNull = false)]
        [Required(ErrorMessage = "出院日期不能为空")]
        [StringLength(10, ErrorMessage = "出院日期长度必须为10个字符")]
        public string bka032 { get; set; }

        /// <summary>
        /// 登记人员工号
        /// 类型：string, 长度：10, 不允许为空
        /// </summary>
        [Column(Name = "bka033", Storage = null, DbType = "VarChar(10)", CanBeNull = false)]
        [Required(ErrorMessage = "登记人员工号不能为空")]
        [StringLength(10, ErrorMessage = "登记人员工号长度不能超过10个字符")]
        public string bka033 { get; set; }

        /// <summary>
        /// 登记人姓名
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "bka034", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "登记人姓名不能为空")]
        [StringLength(20, ErrorMessage = "登记人姓名长度不能超过20个字符")]
        public string bka034 { get; set; }

        /// <summary>
        /// 血型
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "bkf001", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "血型长度不能超过10个字符")]
        public string bkf001 { get; set; }

        /// <summary>
        /// 入院方式
        /// 类型：string, 长度：10, 不允许为空
        /// </summary>
        [Column(Name = "bkf002", Storage = null, DbType = "VarChar(10)", CanBeNull = false)]
        [Required(ErrorMessage = "入院方式不能为空")]
        [StringLength(10, ErrorMessage = "入院方式长度不能超过10个字符")]
        public string bkf002 { get; set; }

        /// <summary>
        /// 入院情况
        /// 类型：string, 长度：10, 不允许为空
        /// </summary>
        [Column(Name = "bkf003", Storage = null, DbType = "VarChar(10)", CanBeNull = false)]
        [Required(ErrorMessage = "入院情况不能为空")]
        [StringLength(10, ErrorMessage = "入院情况长度不能超过10个字符")]
        public string bkf003 { get; set; }

        /// <summary>
        /// 出院转归情况
        /// 类型：string, 长度：10, 不允许为空
        /// </summary>
        [Column(Name = "bkf004", Storage = null, DbType = "VarChar(10)", CanBeNull = false)]
        [Required(ErrorMessage = "出院转归情况不能为空")]
        [StringLength(10, ErrorMessage = "出院转归情况长度不能超过10个字符")]
        public string bkf004 { get; set; }

        /// <summary>
        /// 抢救次数
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "bkf005", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "抢救次数长度不能超过10个字符")]
        public string bkf005 { get; set; }

        /// <summary>
        /// 抢救成功次数
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "bkf006", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "抢救成功次数长度不能超过10个字符")]
        public string bkf006 { get; set; }

        /// <summary>
        /// 因伤出院诊断
        /// 类型：string, 长度：3000, 不允许为空
        /// </summary>
        [Column(Name = "bka031", Storage = null, DbType = "VarChar(3000)", CanBeNull = false)]
        [Required(ErrorMessage = "因伤出院诊断不能为空")]
        [StringLength(3000, ErrorMessage = "因伤出院诊断长度不能超过3000个字符")]
        public string bka031 { get; set; }

        /// <summary>
        /// 因病出院诊断
        /// 类型：string, 长度：3000, 默认可空
        /// </summary>
        [Column(Name = "Bka510", Storage = null, DbType = "VarChar(3000)", CanBeNull = true)]
        [StringLength(3000, ErrorMessage = "因病出院诊断长度不能超过3000个字符")]
        public string Bka510 { get; set; }

        /// <summary>
        /// 出院说明
        /// 类型：string, 长度：100, 默认可空
        /// </summary>
        [Column(Name = "bka043", Storage = null, DbType = "VarChar(100)", CanBeNull = true)]
        [StringLength(100, ErrorMessage = "出院说明长度不能超过100个字符")]
        public string bka043 { get; set; }

        /// <summary>
        /// 生育业务类型（工伤业务不需要考虑此字段内容）
        /// 类型：string, 长度：10, 不允许为空
        /// </summary>
        [Column(Name = "amc050", Storage = null, DbType = "VarChar(10)", CanBeNull = false)]
        [Required(ErrorMessage = "生育业务类型不能为空")]
        [StringLength(10, ErrorMessage = "生育业务类型长度不能超过10个字符")]
        public string amc050 { get; set; }

        /// <summary>
        /// 生育手术类别（工伤业务不需要考虑此字段内容）
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "amc029", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "生育手术类别长度不能超过10个字符")]
        public string amc029 { get; set; }

        /// <summary>
        /// 胎次（工伤业务不需要考虑此字段内容）
        /// 类型：string, 长度：10, 不允许为空
        /// </summary>
        [Column(Name = "amc031", Storage = null, DbType = "VarChar(10)", CanBeNull = false)]
        [Required(ErrorMessage = "胎次不能为空")]
        [StringLength(10, ErrorMessage = "胎次长度不能超过10个字符")]
        public string amc031 { get; set; }

        /// <summary>
        /// 手术日期（工伤业务不需要考虑此字段内容）
        /// 类型：string, 长度：10, 不允许为空
        /// </summary>
        [Column(Name = "bka911", Storage = null, DbType = "VarChar(10)", CanBeNull = false)]
        [Required(ErrorMessage = "手术日期不能为空")]
        [StringLength(10, ErrorMessage = "手术日期长度不能超过10个字符")]
        public string bka911 { get; set; }

        /// <summary>
        /// 生育类别（工伤业务不需要考虑此字段内容）
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "bka912", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "生育类别长度不能超过10个字符")]
        public string bka912 { get; set; }

        /// <summary>
        /// 胎儿数（工伤业务不需要考虑此字段内容）
        /// 类型：string, 长度：10, 不允许为空
        /// </summary>
        [Column(Name = "bka913", Storage = null, DbType = "VarChar(10)", CanBeNull = false)]
        [Required(ErrorMessage = "胎儿数不能为空")]
        [StringLength(10, ErrorMessage = "胎儿数长度不能超过10个字符")]
        public string bka913 { get; set; }

        /// <summary>
        /// 母亲情况（工伤业务不需要考虑此字段内容）
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "bka914", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "母亲情况长度不能超过10个字符")]
        public string bka914 { get; set; }

        /// <summary>
        /// 母亲死亡时间（工伤业务不需要考虑此字段内容）
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "bka915", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "母亲死亡时间长度不能超过10个字符")]
        public string bka915 { get; set; }

        /// <summary>
        /// 婴儿情况（工伤业务不需要考虑此字段内容）
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "bka916", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "婴儿情况长度不能超过10个字符")]
        public string bka916 { get; set; }

        /// <summary>
        /// 婴儿死亡时间（工伤业务不需要考虑此字段内容）
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "bka917", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "婴儿死亡时间长度不能超过10个字符")]
        public string bka917 { get; set; }

        /// <summary>
        /// 出院原因（省内异地住院业务必填，工伤业务不需要考虑此字段内容）
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "ykc195", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "出院原因长度不能超过10个字符")]
        public string ykc195 { get; set; }

        /// <summary>
        /// 住院天数（省内异地住院业务必填，工伤业务不需要考虑此字段内容）
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "akb063", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "住院天数长度不能超过10个字符")]
        public string akb063 { get; set; }

        /// <summary>
        /// 血透次数（工伤业务不需要考虑此字段内容）
        /// 类型：string, 长度：12, 默认可空
        /// </summary>
        [Column(Name = "bka856", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "血透次数长度不能超过12个字符")]
        public string bka856 { get; set; }

        /// <summary>
        /// 待遇类型（工伤业务不需要考虑此字段内容）
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "bka006", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "待遇类型长度不能超过10个字符")]
        public string bka006 { get; set; }
    }

    class DischargeRegistrationOutput : EntityBase
    {
        /// <summary>
        /// 医院编号
        /// 类型：string, 长度：20, 默认可空
        /// </summary>
        [Column(Name = "akb020", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20, ErrorMessage = "医院编号长度不能超过20个字符")]
        public string akb020 { get; set; }

        /// <summary>
        /// 就医登记号
        /// 类型：string, 长度：20, 默认可空
        /// </summary>
        [Column(Name = "aaz218", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20, ErrorMessage = "就医登记号长度不能超过20个字符")]
        public string aaz218 { get; set; }

        /// <summary>
        /// 医疗总费用
        /// 类型：string, 长度：12, 默认可空
        /// 计算公式：akc264 = bka831 + bka832，精确到小数点后2位
        /// </summary>
        [Column(Name = "akc264", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "医疗总费用长度不能超过12个字符")]
        public string akc264 { get; set; }

        /// <summary>
        /// 个人自付
        /// 类型：string, 长度：12, 默认可空
        /// 计算公式：bka831 = akb067 + akb066 + bka839，精确到小数点后2位
        /// </summary>
        [Column(Name = "bka831", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "个人自付长度不能超过12个字符")]
        public string bka831 { get; set; }

        /// <summary>
        /// 工伤保险支付
        /// 类型：string, 长度：12, 默认可空
        /// 计算公式：bka832 = ake039 + ake035 + ake026 + ake029 + bka841 + bka842 + bka840 + bka821，精确到小数点后2位
        /// </summary>
        [Column(Name = "bka832", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "工伤保险支付长度不能超过12个字符")]
        public string bka832 { get; set; }

        /// <summary>
        /// 全自费费用
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka825", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "全自费费用长度不能超过12个字符")]
        public string bka825 { get; set; }

        /// <summary>
        /// 部分自费费用
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka826", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "部分自费费用长度不能超过12个字符")]
        public string bka826 { get; set; }

        /// <summary>
        /// 起付线费用
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "aka151", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "起付线费用长度不能超过12个字符")]
        public string aka151 { get; set; }

        /// <summary>
        /// 超共付段费用个人自付
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka838", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "超共付段费用个人自付长度不能超过12个字符")]
        public string bka838 { get; set; }

        /// <summary>
        /// 个人现金支付
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "akb067", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "个人现金支付长度不能超过12个字符")]
        public string akb067 { get; set; }

        /// <summary>
        /// 个人账户支付
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "akb066", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "个人账户支付长度不能超过12个字符")]
        public string akb066 { get; set; }

        /// <summary>
        /// 民政救助金支付
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka821", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "民政救助金支付长度不能超过12个字符")]
        public string bka821 { get; set; }

        /// <summary>
        /// 其他支付
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka839", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "其他支付长度不能超过12个字符")]
        public string bka839 { get; set; }

        /// <summary>
        /// 工伤保险统筹基金支付
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "ake039", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "工伤保险统筹基金支付长度不能超过12个字符")]
        public string ake039 { get; set; }

        /// <summary>
        /// 公务员医疗补助基金支付
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "ake035", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "公务员医疗补助基金支付长度不能超过12个字符")]
        public string ake035 { get; set; }

        /// <summary>
        /// 企业补充工伤保险基金支付
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "ake026", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "企业补充工伤保险基金支付长度不能超过12个字符")]
        public string ake026 { get; set; }

        /// <summary>
        /// 大额医疗费用补助基金支付
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "ake029", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "大额医疗费用补助基金支付长度不能超过12个字符")]
        public string ake029 { get; set; }

        /// <summary>
        /// 单位支付
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka841", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "单位支付长度不能超过12个字符")]
        public string bka841 { get; set; }

        /// <summary>
        /// 医院垫付
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka842", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "医院垫付长度不能超过12个字符")]
        public string bka842 { get; set; }

        /// <summary>
        /// 其他基金支付
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka840", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "其他基金支付长度不能超过12个字符")]
        public string bka840 { get; set; }
    }
}
