﻿using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Data.Linq.Mapping;
using PTMIBase.Entity;


namespace DongGuanWI.Entity.Inpatient
{
    class GetpatientInfoInput:EntityBase
    {
        /// <summary>
        /// 交易号
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "function_id", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "交易号不能为空")]
        [StringLength(20, ErrorMessage = "交易号长度不能超过20个字符")]
        public string function_id { get; set; }

        /// <summary>
        /// 参保人所属行政区划代码
        /// 类型：string, 长度：6, 允许为空
        /// 备注：采用GB/T 2260，对异地就医，必须送入此参数；对参保人本地就医，不需送入。
        /// </summary>
        [Column(Name = "aab301", Storage = null, DbType = "VarChar(6)", CanBeNull = true)]
        [StringLength(6, ErrorMessage = "参保人所属行政区划代码长度不能超过6个字符")]
        public string aab301 { get; set; }

        /// <summary>
        /// 入参类型
        /// 类型：string, 长度：70, 不允许为空
        /// 备注：aac001电脑号；aac002社会保障号码；bka100社保卡号
        /// </summary>
        [Column(Name = "bka895", Storage = null, DbType = "VarChar(70)", CanBeNull = false)]
        [Required(ErrorMessage = "入参类型不能为空")]
        [StringLength(70, ErrorMessage = "入参类型长度不能超过70个字符")]
        public string bka895 { get; set; }

        /// <summary>
        /// 入参值
        /// 类型：string, 长度：70, 不允许为空
        /// </summary>
        [Column(Name = "bka896", Storage = null, DbType = "VarChar(70)", CanBeNull = false)]
        [Required(ErrorMessage = "入参值不能为空")]
        [StringLength(70, ErrorMessage = "入参值长度不能超过70个字符")]
        public string bka896 { get; set; }

        /// <summary>
        /// 医疗机构编码
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "akb020", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "医疗机构编码不能为空")]
        [StringLength(20, ErrorMessage = "医疗机构编码长度不能超过20个字符")]
        public string akb020 { get; set; }

        /// <summary>
        /// 业务类型
        /// 类型：string, 长度：2, 不允许为空
        /// 备注：见码表
        /// </summary>
        [Column(Name = "aka130", Storage = null, DbType = "VarChar(2)", CanBeNull = false)]
        [Required(ErrorMessage = "业务类型不能为空")]
        [StringLength(2, ErrorMessage = "业务类型长度必须为2个字符")]
        public string aka130 { get; set; }

        /// <summary>
        /// 住院时间
        /// 类型：string, 长度：8, 不允许为空
        /// 格式：“yyyyMMdd”
        /// </summary>
        [Column(Name = "bka017", Storage = null, DbType = "VarChar(8)", CanBeNull = false)]
        [Required(ErrorMessage = "住院时间不能为空")]
        [StringLength(8, ErrorMessage = "住院时间长度必须为8个字符")]
        public string bka017 { get; set; }

        /// <summary>
        /// 生育业务类型
        /// 类型：string, 长度：6, 允许为空
        /// 备注：工伤业务不需要考虑此字段内容
        /// </summary>
        [Column(Name = "amc050", Storage = null, DbType = "VarChar(6)", CanBeNull = true)]
        [StringLength(6, ErrorMessage = "生育业务类型长度不能超过6个字符")]
        public string amc050 { get; set; }

        /// <summary>
        /// 生育类别
        /// 类型：string, 长度：6, 允许为空
        /// 备注：工伤业务不需要考虑此字段内容
        /// </summary>
        [Column(Name = "bka912", Storage = null, DbType = "VarChar(6)", CanBeNull = true)]
        [StringLength(6, ErrorMessage = "生育类别长度不能超过6个字符")]
        public string bka912 { get; set; }

        /// <summary>
        /// 生育手术类别
        /// 类型：string, 长度：6, 允许为空
        /// 备注：工伤业务不需要考虑此字段内容
        /// </summary>
        [Column(Name = "amc029", Storage = null, DbType = "VarChar(6)", CanBeNull = true)]
        [StringLength(6, ErrorMessage = "生育手术类别长度不能超过6个字符")]
        public string amc029 { get; set; }

        /// <summary>
        /// 工伤待遇类型
        /// 类型：string, 长度：6, 不允许为空
        /// 备注：工伤业务必填
        /// </summary>
        [Column(Name = "bka006", Storage = null, DbType = "VarChar(6)", CanBeNull = false)]
        [Required(ErrorMessage = "工伤待遇类型不能为空")]
        [StringLength(6, ErrorMessage = "工伤待遇类型长度不能超过6个字符")]
        public string bka006 { get; set; }

        /// <summary>
        /// 工伤凭证号
        /// 类型：string, 长度：20, 允许为空/不允许为空
        /// 备注：工伤业务 如第一次调用返回多条相同电脑号 可根据填写返回的工伤凭证号bka042填写入参获取单条信息
        /// </summary>
        [Column(Name = "bka042", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20, ErrorMessage = "工伤凭证号长度不能超过20个字符")]
        public string bka042 { get; set; }

        /// <summary>
        /// 医疗期id
        /// 类型：string, 长度：20, 允许为空/不允许为空
        /// 备注：康复医疗如返回多条人员信息需要将bka507传入来获取单条人员信息(bka507=blz516)
        /// </summary>
        [Column(Name = "bka507", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20, ErrorMessage = "医疗期id长度不能超过20个字符")]
        public string bka507 { get; set; }
    }

    class GetpatientInfoOutput : EntityBase
    {
        public List<PersonInfoOfInpat> personInfoOfInpat;
    }

    /// <summary>
    /// 个人信息实体类
    /// </summary>
    public class PersonInfoOfInpat : EntityBase
    {
        /// <summary>
        /// 电脑号
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "aac001", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "电脑号不能为空")]
        [StringLength(20, ErrorMessage = "电脑号长度不能超过20个字符")]
        public string aac001 { get; set; }

        /// <summary>
        /// 姓名
        /// 类型：string, 长度：20, 默认可空
        /// </summary>
        [Column(Name = "aac003", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20, ErrorMessage = "姓名长度不能超过20个字符")]
        public string aac003 { get; set; }

        /// <summary>
        /// 性别
        /// 类型：string, 长度：1, 默认可空
        /// 备注："2"——"女"，"1"——"男"
        /// </summary>
        [Column(Name = "aac004", Storage = null, DbType = "VarChar(1)", CanBeNull = true)]
        [StringLength(1, ErrorMessage = "性别长度必须为1个字符")]
        public string aac004 { get; set; }

        /// <summary>
        /// 人员类别
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "bka004", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "人员类别长度不能超过10个字符")]
        public string bka004 { get; set; }

        /// <summary>
        /// 用工形式
        /// 类型：string, 长度：10, 默认可空
        /// 备注：见码表
        /// </summary>
        [Column(Name = "aac013", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "用工形式长度不能超过10个字符")]
        public string aac013 { get; set; }

        /// <summary>
        /// 行政职务级别
        /// 类型：string, 长度：3, 默认可空
        /// </summary>
        [Column(Name = "bka005", Storage = null, DbType = "VarChar(3)", CanBeNull = true)]
        [StringLength(3, ErrorMessage = "行政职务级别长度不能超过3个字符")]
        public string bka005 { get; set; }

        /// <summary>
        /// 社会保障号码
        /// 类型：string, 长度：25, 默认可空
        /// </summary>
        [Column(Name = "aac002", Storage = null, DbType = "VarChar(25)", CanBeNull = true)]
        [StringLength(25, ErrorMessage = "社会保障号码长度不能超过25个字符")]
        public string aac002 { get; set; }

        /// <summary>
        /// 联系电话
        /// 类型：string, 长度：25, 默认可空
        /// </summary>
        [Column(Name = "aae005", Storage = null, DbType = "VarChar(25)", CanBeNull = true)]
        [StringLength(25, ErrorMessage = "联系电话长度不能超过25个字符")]
        public string aae005 { get; set; }

        /// <summary>
        /// 出生日期
        /// 类型：string, 长度：10, 默认可空
        /// 格式：yyyyMMdd
        /// </summary>
        [Column(Name = "aac006", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "出生日期长度必须为10个字符")]
        public string aac006 { get; set; }

        /// <summary>
        /// 参保地区编码
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "baa027", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "参保地区编码长度不能超过10个字符")]
        public string baa027 { get; set; }

        /// <summary>
        /// 单位编码
        /// 类型：string, 长度：20, 默认可空
        /// </summary>
        [Column(Name = "aab001", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20, ErrorMessage = "单位编码长度不能超过20个字符")]
        public string aab001 { get; set; }

        /// <summary>
        /// 单位名称
        /// 类型：string, 长度：50, 默认可空
        /// </summary>
        [Column(Name = "bka008", Storage = null, DbType = "VarChar(50)", CanBeNull = true)]
        [StringLength(50, ErrorMessage = "单位名称长度不能超过50个字符")]
        public string bka008 { get; set; }

        /// <summary>
        /// 险种编码
        /// 类型：string, 长度：6, 默认可空
        /// 备注："410"——"工伤"
        /// </summary>
        [Column(Name = "aae140", Storage = null, DbType = "VarChar(6)", CanBeNull = true)]
        [StringLength(6, ErrorMessage = "险种编码长度不能超过6个字符")]
        public string aae140 { get; set; }

        /// <summary>
        /// 个人基金状态
        /// 类型：string, 长度：10, 默认可空
        /// 备注：0正常、1冻结、9未参保
        /// </summary>
        [Column(Name = "bka888", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "个人基金状态长度不能超过10个字符")]
        public string bka888 { get; set; }

        /// <summary>
        /// 工伤保险中心编码
        /// 类型：string, 长度：6, 默认可空
        /// </summary>
        [Column(Name = "aaa027", Storage = null, DbType = "VarChar(6)", CanBeNull = true)]
        [StringLength(6, ErrorMessage = "工伤保险中心编码长度不能超过6个字符")]
        public string aaa027 { get; set; }

        /// <summary>
        /// 待遇类别
        /// 类型：string, 长度：10, 默认可空
        /// 备注：工伤业务不需要考虑此字段内容
        /// </summary>
        [Column(Name = "bka006", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "待遇类别长度不能超过10个字符")]
        public string bka006 { get; set; }

        /// <summary>
        /// 疾病编码
        /// 类型：string, 长度：20, 默认可空
        /// 备注：工伤业务不需要考虑此字段内容
        /// </summary>
        [Column(Name = "bka026", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20, ErrorMessage = "疾病编码长度不能超过20个字符")]
        public string bka026 { get; set; }

        /// <summary>
        /// 工伤凭证号
        /// 类型：string, 长度：20, 默认可空
        /// 备注：工伤业务
        /// </summary>
        [Column(Name = "bka042", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20, ErrorMessage = "工伤凭证号长度不能超过20个字符")]
        public string bka042 { get; set; }

        /// <summary>
        /// 开始日期(医疗期开始时间)
        /// 类型：string, 长度：10, 默认可空
        /// 格式：yyyyMMdd
        /// 备注：工伤
        /// </summary>
        [Column(Name = "aae030", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "开始日期长度必须为10个字符")]
        public string aae030 { get; set; }

        /// <summary>
        /// 结束日期(医疗期结束时间)
        /// 类型：string, 长度：10, 默认可空
        /// 格式：yyyyMMdd
        /// 备注：工伤
        /// </summary>
        [Column(Name = "aae031", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "结束日期长度必须为10个字符")]
        public string aae031 { get; set; }

        /// <summary>
        /// 工伤医疗期id
        /// 类型：string, 长度：20, 默认可空
        /// 备注：康复医疗获取到多条人员信息时，需要将该值传入
        /// </summary>
        [Column(Name = "blz516", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20, ErrorMessage = "工伤医疗期id长度不能超过20个字符")]
        public string blz516 { get; set; }

        /// <summary>
        /// 工伤医疗期类型
        /// 类型：string, 长度：20, 默认可空
        /// 备注：见码表
        /// </summary>
        [Column(Name = "blc586", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20, ErrorMessage = "工伤医疗期类型长度不能超过20个字符")]
        public string blc586 { get; set; }

        /// <summary>
        /// 工伤发生时间
        /// 类型：string, 长度：10, 默认可空
        /// 格式：yyyyMMdd
        /// 备注：工伤
        /// </summary>
        [Column(Name = "alc020", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "工伤发生时间长度必须为10个字符")]
        public string alc020 { get; set; }

        /// <summary>
        /// 工伤认定书编号
        /// 类型：string, 长度：100, 默认可空
        /// </summary>
        [Column(Name = "alc011", Storage = null, DbType = "VarChar(100)", CanBeNull = true)]
        [StringLength(100, ErrorMessage = "工伤认定书编号长度不能超过100个字符")]
        public string alc011 { get; set; }

        /// <summary>
        /// 伤残等级
        /// 类型：string, 长度：10, 默认可空
        /// 备注：见码表
        /// </summary>
        [Column(Name = "ala040", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "伤残等级长度不能超过10个字符")]
        public string ala040 { get; set; }

        /// <summary>
        /// 工伤类型
        /// 类型：string, 长度：1, 默认可空
        /// 备注：见码表
        /// </summary>
        [Column(Name = "alc081", Storage = null, DbType = "VarChar(1)", CanBeNull = true)]
        [StringLength(1, ErrorMessage = "工伤类型长度必须为1个字符")]
        public string alc081 { get; set; }

        /// <summary>
        /// 伤害部位
        /// 类型：string, 长度：500, 默认可空
        /// </summary>
        [Column(Name = "alc022", Storage = null, DbType = "VarChar(500)", CanBeNull = true)]
        [StringLength(500, ErrorMessage = "伤害部位长度不能超过500个字符")]
        public string alc022 { get; set; }
    }
}
