﻿using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Data.Linq.Mapping;
using PTMIBase.Entity;

namespace DongGuanWI.Entity.Inpatient
{
    class SettlementInput:EntityBase
    {
        /// <summary>
        /// 交易号
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "function_id", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "交易号不能为空")]
        [StringLength(20, ErrorMessage = "交易号长度不能超过20个字符")]
        public string function_id { get; set; }

        /// <summary>
        /// 医疗机构编码
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "akb020", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "医疗机构编码不能为空")]
        [StringLength(20, ErrorMessage = "医疗机构编码长度不能超过20个字符")]
        public string akb020 { get; set; }

        /// <summary>
        /// 就医登记号
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "aaz218", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "就医登记号不能为空")]
        [StringLength(20, ErrorMessage = "就医登记号长度不能超过20个字符")]
        public string aaz218 { get; set; }

        /// <summary>
        /// 完成人工号
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "bka046", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "完成人工号不能为空")]
        [StringLength(20, ErrorMessage = "完成人工号长度不能超过20个字符")]
        public string bka046 { get; set; }

        /// <summary>
        /// 完成人
        /// 类型：string, 长度：50, 不允许为空
        /// </summary>
        [Column(Name = "bka047", Storage = null, DbType = "VarChar(50)", CanBeNull = false)]
        [Required(ErrorMessage = "完成人不能为空")]
        [StringLength(50, ErrorMessage = "完成人长度不能超过50个字符")]
        public string bka047 { get; set; }
    }

    class SettlementOUtuput : EntityBase
    {
        /// <summary>
        /// 医院编号
        /// 类型：string, 长度：20, 默认可空
        /// </summary>
        [Column(Name = "akb020", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20, ErrorMessage = "医院编号长度不能超过20个字符")]
        public string akb020 { get; set; }

        /// <summary>
        /// 就医登记号
        /// 类型：string, 长度：20, 默认可空
        /// </summary>
        [Column(Name = "aaz218", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20, ErrorMessage = "就医登记号长度不能超过20个字符")]
        public string aaz218 { get; set; }

        /// <summary>
        /// 医疗总费用
        /// 类型：string, 长度：12, 默认可空
        /// 计算公式：akc264 = bka831 + bka832，精确到小数点后2位
        /// </summary>
        [Column(Name = "akc264", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "医疗总费用长度不能超过12个字符")]
        public string akc264 { get; set; }

        /// <summary>
        /// 个人自付
        /// 类型：string, 长度：12, 默认可空
        /// 计算公式：bka831 = akb067 + akb066 + bka839，精确到小数点后2位
        /// </summary>
        [Column(Name = "bka831", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "个人自付长度不能超过12个字符")]
        public string bka831 { get; set; }

        /// <summary>
        /// 工伤保险支付
        /// 类型：string, 长度：12, 默认可空
        /// 计算公式：bka832 = ake039 + ake035 + ake026 + ake029 + bka841 + bka842 + bka840 + bka821，精确到小数点后2位
        /// </summary>
        [Column(Name = "bka832", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "工伤保险支付长度不能超过12个字符")]
        public string bka832 { get; set; }

        /// <summary>
        /// 全自费费用
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka825", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "全自费费用长度不能超过12个字符")]
        public string bka825 { get; set; }

        /// <summary>
        /// 部分自费费用
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka826", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "部分自费费用长度不能超过12个字符")]
        public string bka826 { get; set; }

        /// <summary>
        /// 起付线费用
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "aka151", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "起付线费用长度不能超过12个字符")]
        public string aka151 { get; set; }

        /// <summary>
        /// 超共付段费用个人自付
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka838", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "超共付段费用个人自付长度不能超过12个字符")]
        public string bka838 { get; set; }

        /// <summary>
        /// 个人现金支付
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "akb067", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "个人现金支付长度不能超过12个字符")]
        public string akb067 { get; set; }

        /// <summary>
        /// 个人账户支付
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "akb066", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "个人账户支付长度不能超过12个字符")]
        public string akb066 { get; set; }

        /// <summary>
        /// 民政救助金支付
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka821", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "民政救助金支付长度不能超过12个字符")]
        public string bka821 { get; set; }

        /// <summary>
        /// 其他支付
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka839", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "其他支付长度不能超过12个字符")]
        public string bka839 { get; set; }

        /// <summary>
        /// 工伤保险统筹基金支付
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "ake039", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "工伤保险统筹基金支付长度不能超过12个字符")]
        public string ake039 { get; set; }

        /// <summary>
        /// 公务员医疗补助基金支付
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "ake035", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "公务员医疗补助基金支付长度不能超过12个字符")]
        public string ake035 { get; set; }

        /// <summary>
        /// 企业补充工伤保险基金支付
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "ake026", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "企业补充工伤保险基金支付长度不能超过12个字符")]
        public string ake026 { get; set; }

        /// <summary>
        /// 大额医疗费用补助基金支付
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "ake029", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "大额医疗费用补助基金支付长度不能超过12个字符")]
        public string ake029 { get; set; }

        /// <summary>
        /// 单位支付
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka841", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "单位支付长度不能超过12个字符")]
        public string bka841 { get; set; }

        /// <summary>
        /// 医院垫付
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka842", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "医院垫付长度不能超过12个字符")]
        public string bka842 { get; set; }

        /// <summary>
        /// 其他基金支付
        /// 类型：string, 长度：12, 默认可空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka840", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "其他基金支付长度不能超过12个字符")]
        public string bka840 { get; set; }
    }
}
