﻿using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Data.Linq.Mapping;
using PTMIBase.Entity;

namespace DongGuanWI.Entity.Inpatient
{
    class UploadFeeInput:EntityBase
    {
        /// <summary>
        /// 交易号
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "function_id", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "交易号不能为空")]
        [StringLength(20, ErrorMessage = "交易号长度不能超过20个字符")]
        public string function_id { get; set; }

        /// <summary>
        /// 就医登记号
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "aaz218", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "就医登记号不能为空")]
        [StringLength(20, ErrorMessage = "就医登记号长度不能超过20个字符")]
        public string aaz218 { get; set; }

        /// <summary>
        /// 医疗机构编码
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "akb020", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "医疗机构编码不能为空")]
        [StringLength(20, ErrorMessage = "医疗机构编码长度不能超过20个字符")]
        public string akb020 { get; set; }

        /// <summary>
        /// 费用明细列表
        /// 每次上传交易不能超过300条费用明细
        /// </summary>
        public List<FeeInfoOfInpat> feeinfo { get; set; } 
    }

    /// <summary>
    /// 费用明细实体类
    /// </summary>
    public class FeeInfoOfInpat:EntityBase
    {
        /// <summary>
        /// 录入人工号
        /// 类型：string, 长度：10, 不允许为空
        /// </summary>
        [Column(Name = "bka063", Storage = null, DbType = "VarChar(10)", CanBeNull = false)]
        [Required(ErrorMessage = "录入人工号不能为空")]
        [StringLength(10, ErrorMessage = "录入人工号长度不能超过10个字符")]
        public string bka063 { get; set; }

        /// <summary>
        /// 录入人姓名
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "bka064", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "录入人姓名不能为空")]
        [StringLength(20, ErrorMessage = "录入人姓名长度不能超过20个字符")]
        public string bka064 { get; set; }

        /// <summary>
        /// 医院药品项目编码
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "ake005", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "医院药品项目编码不能为空")]
        [StringLength(20, ErrorMessage = "医院药品项目编码长度不能超过20个字符")]
        public string ake005 { get; set; }

        /// <summary>
        /// 医院药品项目名称
        /// 类型：string, 长度：50, 不允许为空
        /// </summary>
        [Column(Name = "ake006", Storage = null, DbType = "VarChar(50)", CanBeNull = false)]
        [Required(ErrorMessage = "医院药品项目名称不能为空")]
        [StringLength(50, ErrorMessage = "医院药品项目名称长度不能超过50个字符")]
        public string ake006 { get; set; }

        /// <summary>
        /// 剂型
        /// 类型：string, 长度：30, 默认可空
        /// </summary>
        [Column(Name = "bka052", Storage = null, DbType = "VarChar(30)", CanBeNull = true)]
        [StringLength(30, ErrorMessage = "剂型长度不能超过30个字符")]
        public string bka052 { get; set; }

        /// <summary>
        /// 厂家
        /// 类型：string, 长度：50, 默认可空
        /// </summary>
        [Column(Name = "bka053", Storage = null, DbType = "VarChar(50)", CanBeNull = true)]
        [StringLength(50, ErrorMessage = "厂家长度不能超过50个字符")]
        public string bka053 { get; set; }

        /// <summary>
        /// 规格
        /// 类型：string, 长度：30, 默认可空
        /// </summary>
        [Column(Name = "bka054", Storage = null, DbType = "VarChar(30)", CanBeNull = true)]
        [StringLength(30, ErrorMessage = "规格长度不能超过30个字符")]
        public string bka054 { get; set; }

        /// <summary>
        /// 费用发生日期
        /// 类型：string, 长度：10, 不允许为空
        /// 格式：yyyyMMdd
        /// </summary>
        [Column(Name = "bka051", Storage = null, DbType = "VarChar(10)", CanBeNull = false)]
        [Required(ErrorMessage = "费用发生日期不能为空")]
        [StringLength(10, ErrorMessage = "费用发生日期长度必须为10个字符")]
        public string bka051 { get; set; }

        /// <summary>
        /// 计量单位
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "bka055", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "计量单位长度不能超过10个字符")]
        public string bka055 { get; set; }

        /// <summary>
        /// 单价
        /// 类型：string, 长度：12, 不允许为空
        /// 精确到小数点后4位
        /// </summary>
        [Column(Name = "bka056", Storage = null, DbType = "VarChar(12)", CanBeNull = false)]
        [Required(ErrorMessage = "单价不能为空")]
        [StringLength(12, ErrorMessage = "单价长度不能超过12个字符")]
        public string bka056 { get; set; }

        /// <summary>
        /// 用量
        /// 类型：string, 长度：12, 不允许为空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka057", Storage = null, DbType = "VarChar(12)", CanBeNull = false)]
        [Required(ErrorMessage = "用量不能为空")]
        [StringLength(12, ErrorMessage = "用量长度不能超过12个字符")]
        public string bka057 { get; set; }

        /// <summary>
        /// 金额
        /// 类型：string, 长度：12, 不允许为空
        /// 精确到小数点后2位，负数时为退费
        /// </summary>
        [Column(Name = "bka058", Storage = null, DbType = "VarChar(12)", CanBeNull = false)]
        [Required(ErrorMessage = "金额不能为空")]
        [StringLength(12, ErrorMessage = "金额长度不能超过12个字符")]
        public string bka058 { get; set; }

        /// <summary>
        /// 处方号
        /// 类型：string, 长度：20, 默认可空
        /// </summary>
        [Column(Name = "bka070", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20, ErrorMessage = "处方号长度不能超过20个字符")]
        public string bka070 { get; set; }

        /// <summary>
        /// 处方医生编号
        /// 类型：string, 长度：12, 默认可空
        /// </summary>
        [Column(Name = "bka074", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12, ErrorMessage = "处方医生编号长度不能超过12个字符")]
        public string bka074 { get; set; }

        /// <summary>
        /// 处方医生姓名
        /// 类型：string, 长度：10, 默认可空
        /// </summary>
        [Column(Name = "bka075", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "处方医生姓名长度不能超过10个字符")]
        public string bka075 { get; set; }

        /// <summary>
        /// 费用序列号
        /// 类型：string, 长度：9, 不允许为空
        /// </summary>
        [Column(Name = "aaz213", Storage = null, DbType = "VarChar(9)", CanBeNull = false)]
        [Required(ErrorMessage = "费用序列号不能为空")]
        [StringLength(9, ErrorMessage = "费用序列号长度不能超过9个字符")]
        public string aaz213 { get; set; }

        /// <summary>
        /// 限制使用标志
        /// 类型：string, 长度：10, 默认可空
        /// 使用有限制使用条件的“五目”项目，符合限制使用条件的，本参数传1，不符合限制使用条件的，本参数不上传或为空
        /// </summary>
        [Column(Name = "aaz267", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10, ErrorMessage = "限制使用标志长度不能超过10个字符")]
        public string aaz267 { get; set; }

        /// <summary>
        /// 伤病分离标志
        /// 类型：string, 长度：20, 不允许为空
        /// 1----因病
        /// 0----因伤
        /// </summary>
        [Column(Name = "bka061", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "伤病分离标志不能为空")]
        [StringLength(20, ErrorMessage = "伤病分离标志长度不能超过20个字符")]
        public string bka061 { get; set; }
    }

}
