﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Data;
using System.Data.Linq.Mapping;
using PTMIBase.Entity;

namespace DongGuanWI.Entity.Outpatient
{
    class GetBusinessInfoOfDisChargeInput:EntityBase
    {
        /// <summary>
        /// 交易号
        /// 类型：string, 长度：20, 不允许为空
        /// 备注：标识每笔交易的唯一编号。
        /// </summary>
        [Column(Name = "function_id", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [StringLength(20)]
        [DisplayName("交易号")]
        public string function_id { get; set; }

        /// <summary>
        /// 入参类型
        /// 类型：string, 长度：70, 不允许为空
        /// 备注：aac001电脑号；aac002社会保障号码；bka100社保卡号；aaz218就医登记号。
        /// </summary>
        [Column(Name = "bka895", Storage = null, DbType = "VarChar(70)", CanBeNull = false)]
        [StringLength(70)]
        [DisplayName("入参类型")]
        public string bka895 { get; set; }

        /// <summary>
        /// 入参值
        /// 类型：string, 长度：70, 不允许为空
        /// 备注：与入参类型对应的值。
        /// </summary>
        [Column(Name = "bka896", Storage = null, DbType = "VarChar(70)", CanBeNull = false)]
        [StringLength(70)]
        [DisplayName("入参值")]
        public string bka896 { get; set; }

        /// <summary>
        /// 医疗机构编码
        /// 类型：string, 长度：20, 不允许为空
        /// 备注：标识医疗机构的唯一编号。
        /// </summary>
        [Column(Name = "akb020", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [StringLength(20)]
        [DisplayName("医疗机构编码")]
        public string akb020 { get; set; }

        /// <summary>
        /// 医疗待遇类型
        /// 类型：string, 长度：6, 不允许为空
        /// 备注：见码表。
        /// </summary>
        [Column(Name = "bka006", Storage = null, DbType = "VarChar(6)", CanBeNull = false)]
        [StringLength(6)]
        [DisplayName("医疗待遇类型")]
        public string bka006 { get; set; }

        /// <summary>
        /// 费用批次
        /// 类型：string, 长度：10, 不允许为空
        /// 备注：取 bka001 对应批次的费用；收费一次为“1”。
        /// </summary>
        [Column(Name = "bka001", Storage = null, DbType = "VarChar(10)", CanBeNull = false)]
        [StringLength(10)]
        [DisplayName("费用批次")]
        public string bka001 { get; set; }
    }
    class GetBusinessInfoOfDisChargeOutput : EntityBase
    {
        public List<BizInfo> bizInfo;
        public List<FeeInfoRtn> feeInfo;
        public List<FeeBatchInfo> feeBatchInfo;
    }

    /// <summary>
    /// 业务信息实体类
    /// </summary>
    public class BizInfo:EntityBase
    {
        /// <summary>
        /// 医疗机构编号
        /// 类型：string, 长度：20, 允许为空
        /// </summary>
        [Column(Name = "akb020", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("医疗机构编号")]
        public string akb020 { get; set; }

        /// <summary>
        /// 就医登记号
        /// 类型：string, 长度：20, 允许为空
        /// </summary>
        [Column(Name = "aaz218", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("就医登记号")]
        public string aaz218 { get; set; }

        /// <summary>
        /// 业务类型
        /// 类型：string, 长度：2, 允许为空
        /// 备注：见码表
        /// </summary>
        [Column(Name = "aka130", Storage = null, DbType = "VarChar(2)", CanBeNull = true)]
        [StringLength(2)]
        [DisplayName("业务类型")]
        public string aka130 { get; set; }

        /// <summary>
        /// 中心编码
        /// 类型：string, 长度：6, 允许为空
        /// </summary>
        [Column(Name = "aaa027", Storage = null, DbType = "VarChar(6)", CanBeNull = true)]
        [StringLength(6)]
        [DisplayName("中心编码")]
        public string aaa027 { get; set; }

        /// <summary>
        /// 个人电脑号
        /// 类型：string, 长度：20, 允许为空
        /// </summary>
        [Column(Name = "aac001", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("个人电脑号")]
        public string aac001 { get; set; }

        /// <summary>
        /// 姓名
        /// 类型：string, 长度：20, 允许为空
        /// </summary>
        [Column(Name = "aac003", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("姓名")]
        public string aac003 { get; set; }

        /// <summary>
        /// 性别
        /// 类型：string, 长度：1, 允许为空
        /// 备注："0"——"女"; "1"——"男"
        /// </summary>
        [Column(Name = "aac004", Storage = null, DbType = "VarChar(1)", CanBeNull = true)]
        [StringLength(1)]
        [DisplayName("性别")]
        public string aac004 { get; set; }

        /// <summary>
        /// 社会保障号码
        /// 类型：string, 长度：25, 允许为空
        /// </summary>
        [Column(Name = "aac002", Storage = null, DbType = "VarChar(25)", CanBeNull = true)]
        [StringLength(25)]
        [DisplayName("社会保障号码")]
        public string aac002 { get; set; }

        /// <summary>
        /// 工伤保险卡号
        /// 类型：string, 长度：25, 允许为空
        /// </summary>
        [Column(Name = "bka100", Storage = null, DbType = "VarChar(25)", CanBeNull = true)]
        [StringLength(25)]
        [DisplayName("工伤保险卡号")]
        public string bka100 { get; set; }

        /// <summary>
        /// 出生日期
        /// 类型：string, 长度：10, 允许为空
        /// 备注：格式：yyyyMMdd
        /// </summary>
        [Column(Name = "aac006", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10)]
        [RegularExpression(@"^\d{8}$")]
        [DisplayName("出生日期")]
        public string aac006 { get; set; }

        /// <summary>
        /// 联系电话
        /// 类型：string, 长度：20, 允许为空
        /// </summary>
        [Column(Name = "aae005", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("联系电话")]
        public string aae005 { get; set; }

        /// <summary>
        /// 单位编码
        /// 类型：string, 长度：20, 允许为空
        /// </summary>
        [Column(Name = "aab001", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("单位编码")]
        public string aab001 { get; set; }

        /// <summary>
        /// 单位名称
        /// 类型：string, 长度：50, 允许为空
        /// </summary>
        [Column(Name = "bka008", Storage = null, DbType = "VarChar(50)", CanBeNull = true)]
        [StringLength(50)]
        [DisplayName("单位名称")]
        public string bka008 { get; set; }

        /// <summary>
        /// 待遇类别
        /// 类型：string, 长度：3, 允许为空
        /// 备注：见码表
        /// </summary>
        [Column(Name = "bka006", Storage = null, DbType = "VarChar(3)", CanBeNull = true)]
        [StringLength(3)]
        [DisplayName("待遇类别")]
        public string bka006 { get; set; }

        /// <summary>
        /// 业务登记日期
        /// 类型：string, 长度：10, 允许为空
        /// 备注：格式：yyyyMMdd
        /// </summary>
        [Column(Name = "bka013", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10)]
        [RegularExpression(@"^\d{8}$")]
        [DisplayName("业务登记日期")]
        public string bka013 { get; set; }

        /// <summary>
        /// 登记人工号
        /// 类型：string, 长度：10, 允许为空
        /// </summary>
        [Column(Name = "bka014", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10)]
        [DisplayName("登记人工号")]
        public string bka014 { get; set; }

        /// <summary>
        /// 登记人
        /// 类型：string, 长度：20, 允许为空
        /// </summary>
        [Column(Name = "bka015", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("登记人")]
        public string bka015 { get; set; }

        /// <summary>
        /// 登记标志
        /// 类型：string, 长度：1, 允许为空
        /// </summary>
        [Column(Name = "bka016", Storage = null, DbType = "VarChar(1)", CanBeNull = true)]
        [StringLength(1)]
        [DisplayName("登记标志")]
        public string bka016 { get; set; }

        /// <summary>
        /// 就诊时间
        /// 类型：string, 长度：10, 允许为空
        /// 备注：格式：yyyyMMdd
        /// </summary>
        [Column(Name = "bka017", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10)]
        [RegularExpression(@"^\d{8}$")]
        [DisplayName("就诊时间")]
        public string bka017 { get; set; }

        /// <summary>
        /// 业务开始情况
        /// 类型：string, 长度：10, 允许为空
        /// </summary>
        [Column(Name = "bka018", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10)]
        [DisplayName("业务开始情况")]
        public string bka018 { get; set; }

        /// <summary>
        /// 入院科室
        /// 类型：string, 长度：10, 允许为空
        /// </summary>
        [Column(Name = "bka019", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10)]
        [DisplayName("入院科室")]
        public string bka019 { get; set; }

        /// <summary>
        /// 入院科室名称
        /// 类型：string, 长度：20, 允许为空
        /// </summary>
        [Column(Name = "bka020", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("入院科室名称")]
        public string bka020 { get; set; }

        /// <summary>
        /// 入院病区
        /// 类型：string, 长度：10, 允许为空
        /// </summary>
        [Column(Name = "bka021", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10)]
        [DisplayName("入院病区")]
        public string bka021 { get; set; }

        /// <summary>
        /// 入院病区名称
        /// 类型：string, 长度：20, 允许为空
        /// </summary>
        [Column(Name = "bka022", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("入院病区名称")]
        public string bka022 { get; set; }

        /// <summary>
        /// 入院床位号
        /// 类型：string, 长度：10, 允许为空
        /// </summary>
        [Column(Name = "bka023", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10)]
        [DisplayName("入院床位号")]
        public string bka023 { get; set; }

        /// <summary>
        /// 医院业务号(挂号)
        /// 类型：string, 长度：20, 允许为空
        /// </summary>
        [Column(Name = "bka025", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("医院业务号(挂号)")]
        public string bka025 { get; set; }

        /// <summary>
        /// 入院疾病诊断（ICD码）
        /// 类型：string, 长度：20, 允许为空
        /// </summary>
        [Column(Name = "bka026", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("入院疾病诊断（ICD码）")]
        public string bka026 { get; set; }

        /// <summary>
        /// 疾病名称
        /// 类型：string, 长度：50, 允许为空
        /// </summary>
        [Column(Name = "aka121", Storage = null, DbType = "VarChar(50)", CanBeNull = true)]
        [StringLength(50)]
        [DisplayName("疾病名称")]
        public string aka121 { get; set; }

        /// <summary>
        /// 用卡标志
        /// 类型：string, 长度：1, 允许为空
        /// </summary>
        [Column(Name = "bka036", Storage = null, DbType = "VarChar(1)", CanBeNull = true)]
        [StringLength(1)]
        [DisplayName("用卡标志")]
        public string bka036 { get; set; }

        /// <summary>
        /// 工伤生育凭证号
        /// 类型：string, 长度：20, 允许为空
        /// 备注：工伤业务
        /// </summary>
        [Column(Name = "bka042", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("工伤生育凭证号")]
        public string bka042 { get; set; }

        /// <summary>
        /// 备注
        /// 类型：string, 长度：500, 允许为空
        /// </summary>
        [Column(Name = "bka043", Storage = null, DbType = "VarChar(500)", CanBeNull = true)]
        [StringLength(500)]
        [DisplayName("备注")]
        public string bka043 { get; set; }

        /// <summary>
        /// 诊次结束标志
        /// 类型：string, 长度：1, 允许为空
        /// 备注："0"——未结束；"1"——诊次结束
        /// </summary>
        [Column(Name = "bka039", Storage = null, DbType = "VarChar(1)", CanBeNull = true)]
        [StringLength(1)]
        [DisplayName("诊次结束标志")]
        public string bka039 { get; set; }
    }
    /// <summary>
    /// 费用信息实体类
    /// </summary>
    public class FeeInfoRtn:EntityBase
    {
        /// <summary>
        /// 医院编码
        /// 类型：string, 长度：20, 允许为空
        /// </summary>
        [Column(Name = "akb020", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("医院编码")]
        public string akb020 { get; set; }

        /// <summary>
        /// 就医登记号
        /// 类型：string, 长度：20, 允许为空
        /// </summary>
        [Column(Name = "aaz218", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("就医登记号")]
        public string aaz218 { get; set; }

        /// <summary>
        /// 批次
        /// 类型：string, 长度：10, 允许为空
        /// </summary>
        [Column(Name = "bka001", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10)]
        [DisplayName("批次")]
        public string bka001 { get; set; }

        /// <summary>
        /// 费用序号
        /// 类型：string, 长度：9, 允许为空
        /// 备注：在退费时，需获取该费用序号作为入参传入。
        /// </summary>
        [Column(Name = "aaz213", Storage = null, DbType = "VarChar(9)", CanBeNull = true)]
        [StringLength(9)]
        [DisplayName("费用序号")]
        public string aaz213 { get; set; }

        /// <summary>
        /// 统计类别
        /// 类型：string, 长度：2, 允许为空
        /// 备注：见码表
        /// </summary>
        [Column(Name = "aka063", Storage = null, DbType = "VarChar(2)", CanBeNull = true)]
        [StringLength(2)]
        [DisplayName("统计类别")]
        public string aka063 { get; set; }

        /// <summary>
        /// 项目药品类型
        /// 类型：string, 长度：1, 允许为空
        /// </summary>
        [Column(Name = "ake003", Storage = null, DbType = "VarChar(1)", CanBeNull = true)]
        [StringLength(1)]
        [DisplayName("项目药品类型")]
        public string ake003 { get; set; }

        /// <summary>
        /// 中心药品项目编码
        /// 类型：string, 长度：20, 允许为空
        /// </summary>
        [Column(Name = "ake001", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("中心药品项目编码")]
        public string ake001 { get; set; }

        /// <summary>
        /// 中心药品项目名称
        /// 类型：string, 长度：50, 允许为空
        /// </summary>
        [Column(Name = "ake002", Storage = null, DbType = "VarChar(50)", CanBeNull = true)]
        [StringLength(50)]
        [DisplayName("中心药品项目名称")]
        public string ake002 { get; set; }

        /// <summary>
        /// 医院药品项目编码
        /// 类型：string, 长度：20, 允许为空
        /// </summary>
        [Column(Name = "ake005", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("医院药品项目编码")]
        public string ake005 { get; set; }

        /// <summary>
        /// 医院药品项目名称
        /// 类型：string, 长度：50, 允许为空
        /// </summary>
        [Column(Name = "ake006", Storage = null, DbType = "VarChar(50)", CanBeNull = true)]
        [StringLength(50)]
        [DisplayName("医院药品项目名称")]
        public string ake006 { get; set; }

        /// <summary>
        /// 费用发生日期
        /// 类型：string, 长度：10, 允许为空
        /// 备注：格式：yyyyMMdd
        /// </summary>
        [Column(Name = "bka051", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10)]
        [RegularExpression(@"^\d{8}$")]
        [DisplayName("费用发生日期")]
        public string bka051 { get; set; }

        /// <summary>
        /// 剂型
        /// 类型：string, 长度：30, 允许为空
        /// </summary>
        [Column(Name = "bka052", Storage = null, DbType = "VarChar(30)", CanBeNull = true)]
        [StringLength(30)]
        [DisplayName("剂型")]
        public string bka052 { get; set; }

        /// <summary>
        /// 厂商
        /// 类型：string, 长度：50, 允许为空
        /// </summary>
        [Column(Name = "bka053", Storage = null, DbType = "VarChar(50)", CanBeNull = true)]
        [StringLength(50)]
        [DisplayName("厂商")]
        public string bka053 { get; set; }

        /// <summary>
        /// 规格
        /// 类型：string, 长度：30, 允许为空
        /// </summary>
        [Column(Name = "bka054", Storage = null, DbType = "VarChar(30)", CanBeNull = true)]
        [StringLength(30)]
        [DisplayName("规格")]
        public string bka054 { get; set; }

        /// <summary>
        /// 计量单位
        /// 类型：string, 长度：20, 允许为空
        /// </summary>
        [Column(Name = "bka055", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("计量单位")]
        public string bka055 { get; set; }

        /// <summary>
        /// 单价
        /// 类型：string, 长度：12, 允许为空
        /// 备注：精确到小数点后4位
        /// </summary>
        [Column(Name = "bka056", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12)]
        [DisplayName("单价")]
        public string bka056 { get; set; }

        /// <summary>
        /// 用量
        /// 类型：string, 长度：12, 允许为空
        /// 备注：精确到小数点后2位
        /// </summary>
        [Column(Name = "bka057", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12)]
        [DisplayName("用量")]
        public string bka057 { get; set; }

        /// <summary>
        /// 金额
        /// 类型：string, 长度：12, 允许为空
        /// 备注：精确到小数点后2位
        /// </summary>
        [Column(Name = "bka058", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12)]
        [DisplayName("金额")]
        public string bka058 { get; set; }

        /// <summary>
        /// 可退金额
        /// 类型：string, 长度：12, 允许为空
        /// 备注：精确到小数点后2位
        /// </summary>
        [Column(Name = "bka059", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12)]
        [DisplayName("可退金额")]
        public string bka059 { get; set; }

        /// <summary>
        /// 用药标志
        /// 类型：string, 长度：1, 允许为空
        /// </summary>
        [Column(Name = "bka060", Storage = null, DbType = "VarChar(1)", CanBeNull = true)]
        [StringLength(1)]
        [DisplayName("用药标志")]
        public string bka060 { get; set; }

        /// <summary>
        /// 对应冲减的费用序号
        /// 类型：string, 长度：9, 允许为空
        /// </summary>
        [Column(Name = "bka062", Storage = null, DbType = "VarChar(9)", CanBeNull = true)]
        [StringLength(9)]
        [DisplayName("对应冲减的费用序号")]
        public string bka062 { get; set; }

        /// <summary>
        /// 处方号
        /// 类型：string, 长度：20, 允许为空
        /// </summary>
        [Column(Name = "bka070", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("处方号")]
        public string bka070 { get; set; }

        /// <summary>
        /// 医生编号
        /// 类型：string, 长度：8, 允许为空
        /// </summary>
        [Column(Name = "bka074", Storage = null, DbType = "VarChar(8)", CanBeNull = true)]
        [StringLength(8)]
        [DisplayName("医生编号")]
        public string bka074 { get; set; }

        /// <summary>
        /// 医生名称
        /// 类型：string, 长度：20, 允许为空
        /// </summary>
        [Column(Name = "bka075", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("医生名称")]
        public string bka075 { get; set; }

        /// <summary>
        /// 费用录入日期
        /// 类型：string, 长度：10, 允许为空
        /// 备注：格式：yyyyMMdd
        /// </summary>
        [Column(Name = "bka065", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10)]
        [RegularExpression(@"^\d{8}$")]
        [DisplayName("费用录入日期")]
        public string bka065 { get; set; }

        /// <summary>
        /// 录入人工号
        /// 类型：string, 长度：10, 允许为空
        /// </summary>
        [Column(Name = "bka063", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10)]
        [DisplayName("录入人工号")]
        public string bka063 { get; set; }

        /// <summary>
        /// 录入人姓名
        /// 类型：string, 长度：20, 允许为空
        /// </summary>
        [Column(Name = "bka064", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("录入人姓名")]
        public string bka064 { get; set; }
    }
    /// <summary>
    /// 费用批次信息实体类
    /// </summary>
    public class FeeBatchInfo:EntityBase
    {
        /// <summary>
        /// 医院编码
        /// 类型：string, 长度：20, 允许为空
        /// </summary>
        [Column(Name = "akb020", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("医院编码")]
        public string akb020 { get; set; }

        /// <summary>
        /// 就医登记号
        /// 类型：string, 长度：20, 允许为空
        /// </summary>
        [Column(Name = "aaz218", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("就医登记号")]
        public string aaz218 { get; set; }

        /// <summary>
        /// 个人电脑号
        /// 类型：string, 长度：20, 允许为空
        /// </summary>
        [Column(Name = "aac001", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("个人电脑号")]
        public string aac001 { get; set; }

        /// <summary>
        /// 姓名
        /// 类型：string, 长度：20, 允许为空
        /// </summary>
        [Column(Name = "aac003", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("姓名")]
        public string aac003 { get; set; }

        /// <summary>
        /// 批次
        /// 类型：string, 长度：10, 允许为空
        /// </summary>
        [Column(Name = "bka001", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10)]
        [DisplayName("批次")]
        public string bka001 { get; set; }

        /// <summary>
        /// 批次费用
        /// 类型：string, 长度：10, 允许为空
        /// 备注：精确到小数点后2位
        /// </summary>
        [Column(Name = "bka058", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10)]
        [DisplayName("批次费用")]
        public string bka058 { get; set; }
    }
}
