﻿using PTMIBase.Entity;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Data;
using System.Data.Linq.Mapping;
using System.Linq;
using System.Text;
using System.Threading.Tasks;


namespace DongGuanWI.Entity.Outpatient
{
    class GetPatientInfoInput: EntityBase
    {
        /// <summary>
        /// 交易号
        /// 类型：string, 允许为空：是
        /// 备注：标识每笔交易的唯一编号。
        /// </summary>
        [Column(Name = "function_id", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [StringLength(20)]
        [DisplayName("交易号")]
        [DefaultValue("bizh110001")] // 标记默认值
        public string function_id { get; set; }

        /// <summary>
        /// 参保人所属行政区划代码
        /// 类型：string, 允许为空：否
        /// 备注：采用GB/T 2260，对异地就医，必须送入此参数；对参保人本地就医，不需送入。
        /// </summary>
        [Column(Name = "aab301", Storage = null, DbType = "VarChar(6)", CanBeNull = true)]
        [Required]
        [StringLength(6)]
        [DisplayName("参保人所属行政区划代码")]
        public string aab301 { get; set; }

        /// <summary>
        /// 入参类型
        /// 类型：string, 允许为空：是
        /// 备注：aac001电脑号；aac002社会保障号码；bka100社保卡号。
        /// </summary>
        [Column(Name = "bka895", Storage = null, DbType = "VarChar(70)", CanBeNull = false)]
        [StringLength(70)]
        [DisplayName("入参类型")]
        public string bka895 { get; set; }

        /// <summary>
        /// 入参值
        /// 类型：string, 允许为空：是
        /// 备注：与入参类型对应的值。
        /// </summary>
        [Column(Name = "bka896", Storage = null, DbType = "VarChar(70)", CanBeNull = false)]
        [StringLength(70)]
        [DisplayName("入参值")]
        public string bka896 { get; set; }

        /// <summary>
        /// 医疗机构编码
        /// 类型：string, 允许为空：是
        /// 备注：标识医疗机构的唯一编号。
        /// </summary>
        [Column(Name = "akb020", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [StringLength(20)]
        [DisplayName("医疗机构编码")]
        public string akb020 { get; set; }

        /// <summary>
        /// 医疗待遇类型
        /// 类型：string, 允许为空：是
        /// 备注：见码表。
        /// </summary>
        [Column(Name = "bka006", Storage = null, DbType = "VarChar(6)", CanBeNull = false)]
        [StringLength(6)]
        [DisplayName("医疗待遇类型")]
        public string bka006 { get; set; }

        /// <summary>
        /// 就诊时间
        /// 类型：string, 允许为空：否
        /// 备注：格式：yyyyMMdd。
        /// </summary>
        [Column(Name = "bka017", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [Required]
        [StringLength(10)]
        [RegularExpression(@"^\d{8}$")]
        [DisplayName("就诊时间")]
        public string bka017 { get; set; }
    }

    class GetPatientInfoOutput : EntityBase
    {
        public List<PersonInfo> personInfo;
        public List<FreezeInfo> freezeInfo;
        public List<SPInfo> spInfo;
        public List<InjuryOrBirthInfo> injuryOrBirthInfo;
    }

    /// <summary>
    /// 个人信息实体类
    /// </summary>
    public class PersonInfo
    {
        /// <summary>
        /// 个人电脑号
        /// 类型：string, 长度：20
        /// </summary>
        [Column(Name = "aac001", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("个人电脑号")]
        public string aac001 { get; set; }

        /// <summary>
        /// 姓名
        /// 类型：string, 长度：20
        /// </summary>
        [Column(Name = "aac003", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("姓名")]
        public string aac003 { get; set; }

        /// <summary>
        /// 性别
        /// 类型：string, 长度：1
        /// 备注："2"——"女"；"1"——"男"
        /// </summary>
        [Column(Name = "aac004", Storage = null, DbType = "VarChar(1)", CanBeNull = true)]
        [StringLength(1)]
        [DisplayName("性别")]
        public string aac004 { get; set; }

        /// <summary>
        /// 人员类别
        /// 类型：string, 长度：10
        /// </summary>
        [Column(Name = "bka004", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10)]
        [DisplayName("人员类别")]
        public string bka004 { get; set; }

        /// <summary>
        /// 用工形式
        /// 类型：string, 长度：10
        /// 备注：见码表
        /// </summary>
        [Column(Name = "aac013", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10)]
        [DisplayName("用工形式")]
        public string aac013 { get; set; }

        /// <summary>
        /// 行政职务级别
        /// 类型：string, 长度：3
        /// </summary>
        [Column(Name = "bka005", Storage = null, DbType = "VarChar(3)", CanBeNull = true)]
        [StringLength(3)]
        [DisplayName("行政职务级别")]
        public string bka005 { get; set; }

        /// <summary>
        /// 社会保障号码
        /// 类型：string, 长度：25
        /// </summary>
        [Column(Name = "aac002", Storage = null, DbType = "VarChar(25)", CanBeNull = true)]
        [StringLength(25)]
        [DisplayName("社会保障号码")]
        public string aac002 { get; set; }

        /// <summary>
        /// 联系电话
        /// 类型：string, 长度：25
        /// </summary>
        [Column(Name = "aae005", Storage = null, DbType = "VarChar(25)", CanBeNull = true)]
        [StringLength(25)]
        [DisplayName("联系电话")]
        public string aae005 { get; set; }

        /// <summary>
        /// 出生日期
        /// 类型：string, 长度：10
        /// 备注：格式：yyyyMMdd
        /// </summary>
        [Column(Name = "aac006", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10)]
        [RegularExpression(@"^\d{8}$")]
        [DisplayName("出生日期")]
        public string aac006 { get; set; }

        /// <summary>
        /// 地区编码
        /// 类型：string, 长度：10
        /// </summary>
        [Column(Name = "baa027", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10)]
        [DisplayName("地区编码")]
        public string baa027 { get; set; }

        /// <summary>
        /// 单位编码
        /// 类型：string, 长度：20
        /// </summary>
        [Column(Name = "aab001", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("单位编码")]
        public string aab001 { get; set; }

        /// <summary>
        /// 单位名称
        /// 类型：string, 长度：50
        /// </summary>
        [Column(Name = "bka008", Storage = null, DbType = "VarChar(50)", CanBeNull = true)]
        [StringLength(50)]
        [DisplayName("单位名称")]
        public string bka008 { get; set; }

        /// <summary>
        /// 险种类型
        /// 类型：string, 长度：10
        /// </summary>
        [Column(Name = "aae140", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10)]
        [DisplayName("险种类型")]
        public string aae140 { get; set; }
    }

    /// <summary>
    /// 基金状态信息实体类
    /// </summary>
    public class FreezeInfo
    {
        /// <summary>
        /// 基金款项代码
        /// 类型：string, 长度：3
        /// </summary>
        [Column(Name = "aaa157", Storage = null, DbType = "VarChar(3)", CanBeNull = true)]
        [StringLength(3)]
        [DisplayName("基金款项代码")]
        public string aaa157 { get; set; }

        /// <summary>
        /// 基金名称
        /// 类型：string, 长度：30
        /// </summary>
        [Column(Name = "aad006", Storage = null, DbType = "VarChar(30)", CanBeNull = true)]
        [StringLength(30)]
        [DisplayName("基金名称")]
        public string aad006 { get; set; }

        /// <summary>
        /// 基金状态标志
        /// 类型：string, 长度：1
        /// 备注："0"——"正常"; "1"——"冻结"; "2"——"暂停参保"; "3"——"中止参保"; "9" —— "未参保"
        /// </summary>
        [Column(Name = "aac031", Storage = null, DbType = "VarChar(1)", CanBeNull = true)]
        [StringLength(1)]
        [DisplayName("基金状态标志")]
        public string aac031 { get; set; }
    }

    /// <summary>
    /// 待遇申请信息 - 特殊处理信息
    /// </summary>
    public class SPInfo
    {
        /// <summary>
        /// 待遇类型
        /// 类型：string, 长度：6
        /// 备注：见码表
        /// </summary>
        [Column(Name = "bka006", Storage = null, DbType = "VarChar(6)", CanBeNull = true)]
        [StringLength(6)]
        [DisplayName("待遇类型")]
        public string bka006 { get; set; }

        /// <summary>
        /// 待遇类型名称
        /// 类型：string, 长度：50
        /// </summary>
        [Column(Name = "bka345", Storage = null, DbType = "VarChar(50)", CanBeNull = true)]
        [StringLength(50)]
        [DisplayName("待遇类型名称")]
        public string bka345 { get; set; }

        /// <summary>
        /// 业务类型
        /// 类型：string, 长度：2
        /// 备注：见码表
        /// </summary>
        [Column(Name = "aka130", Storage = null, DbType = "VarChar(2)", CanBeNull = true)]
        [StringLength(2)]
        [DisplayName("业务类型")]
        public string aka130 { get; set; }

        /// <summary>
        /// 疾病编码
        /// 类型：string, 长度：20
        /// </summary>
        [Column(Name = "bka026", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("疾病编码")]
        public string bka026 { get; set; }

        /// <summary>
        /// 疾病名称
        /// 类型：string, 长度：60
        /// </summary>
        [Column(Name = "aka121", Storage = null, DbType = "VarChar(60)", CanBeNull = true)]
        [StringLength(60)]
        [DisplayName("疾病名称")]
        public string aka121 { get; set; }

        /// <summary>
        /// 申请生效时间
        /// 类型：string, 长度：10
        /// 备注：格式：yyyyMMdd
        /// </summary>
        [Column(Name = "aae030", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10)]
        [RegularExpression(@"^\d{8}$")]
        [DisplayName("申请生效时间")]
        public string aae030 { get; set; }

        /// <summary>
        /// 申请到期时间
        /// 类型：string, 长度：10
        /// 备注：格式：yyyyMMdd
        /// </summary>
        [Column(Name = "aae031", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10)]
        [RegularExpression(@"^\d{8}$")]
        [DisplayName("申请到期时间")]
        public string aae031 { get; set; }
    }

    /// <summary>
    /// 工伤申请信息 
    /// </summary>
    public class InjuryOrBirthInfo
    {
        /// <summary>
        /// 工伤凭证号
        /// 类型：string, 长度：20
        /// </summary>
        [Column(Name = "bka042", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        [DisplayName("工伤凭证号")]
        public string bka042 { get; set; }

        /// <summary>
        /// 申请生效时间
        /// 类型：string, 长度：10
        /// 备注：格式：yyyyMMdd
        /// </summary>
        [Column(Name = "aae030", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10)]
        [RegularExpression(@"^\d{8}$")]
        [DisplayName("申请生效时间")]
        public string aae030 { get; set; }

        /// <summary>
        /// 申请到期时间
        /// 类型：string, 长度：10
        /// 备注：格式：yyyyMMdd
        /// </summary>
        [Column(Name = "aae031", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10)]
        [RegularExpression(@"^\d{8}$")]
        [DisplayName("申请到期时间")]
        public string aae031 { get; set; }

        /// <summary>
        /// 工伤认定书编号
        /// 类型：string, 长度：1000
        /// </summary>
        [Column(Name = "Alc011", Storage = null, DbType = "VarChar(1000)", CanBeNull = true)]
        [StringLength(1000)]
        [DisplayName("工伤认定书编号")]
        public string Alc011 { get; set; }
    }
}
