﻿using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Data.Linq.Mapping;
using PTMIBase.Entity;


namespace DongGuanWI.Entity.Outpatient
{
    class RegisterInput:EntityBase
    {
        /// <summary>
        /// 交易号
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "function_id", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "交易号不能为空")]
        [StringLength(20)]
        public string function_id { get; set; }

        /// <summary>
        /// 工伤保险中心编码
        /// 类型：string, 长度：6, 不允许为空
        /// </summary>
        [Column(Name = "aaa027", Storage = null, DbType = "VarChar(6)", CanBeNull = false)]
        [Required(ErrorMessage = "工伤保险中心编码不能为空")]
        [StringLength(6)]
        public string aaa027 { get; set; }

        /// <summary>
        /// 医疗机构编码
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "akb020", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "医疗机构编码不能为空")]
        [StringLength(20)]
        public string akb020 { get; set; }

        /// <summary>
        /// 个人电脑号
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "aac001", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "个人电脑号不能为空")]
        [StringLength(20)]
        public string aac001 { get; set; }

        /// <summary>
        /// 业务类型
        /// 类型：string, 长度：2, 不允许为空
        /// 备注：见码表
        /// </summary>
        [Column(Name = "aka130", Storage = null, DbType = "VarChar(2)", CanBeNull = false)]
        [Required(ErrorMessage = "业务类型不能为空")]
        [StringLength(2)]
        public string aka130 { get; set; }

        /// <summary>
        /// 医疗待遇类型
        /// 类型：string, 长度：6, 不允许为空
        /// 备注：见码表
        /// </summary>
        [Column(Name = "bka006", Storage = null, DbType = "VarChar(6)", CanBeNull = false)]
        [Required(ErrorMessage = "医疗待遇类型不能为空")]
        [StringLength(6)]
        public string bka006 { get; set; }

        /// <summary>
        /// 就诊时间
        /// 类型：string, 长度：10, 不允许为空
        /// 格式：yyyyMMdd
        /// </summary>
        [Column(Name = "bka017", Storage = null, DbType = "VarChar(10)", CanBeNull = false)]
        [Required(ErrorMessage = "就诊时间不能为空")]
        [StringLength(10)]
        public string bka017 { get; set; }

        /// <summary>
        /// 登记人员工号
        /// 类型：string, 长度：10, 不允许为空
        /// </summary>
        [Column(Name = "bka014", Storage = null, DbType = "VarChar(10)", CanBeNull = false)]
        [Required(ErrorMessage = "登记人员工号不能为空")]
        [StringLength(10)]
        public string bka014 { get; set; }

        /// <summary>
        /// 登记人姓名
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "bka015", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "登记人姓名不能为空")]
        [StringLength(20)]
        public string bka015 { get; set; }

        /// <summary>
        /// 病区编码
        /// 类型：string, 长度：10, 不允许为空
        /// </summary>
        [Column(Name = "bka021", Storage = null, DbType = "VarChar(10)", CanBeNull = false)]
        [Required(ErrorMessage = "病区编码不能为空")]
        [StringLength(10)]
        public string bka021 { get; set; }

        /// <summary>
        /// 病区名称
        /// 类型：string, 长度：30, 不允许为空
        /// </summary>
        [Column(Name = "bka022", Storage = null, DbType = "VarChar(30)", CanBeNull = false)]
        [Required(ErrorMessage = "病区名称不能为空")]
        [StringLength(30)]
        public string bka022 { get; set; }

        /// <summary>
        /// 就诊科室
        /// 类型：string, 长度：10, 不允许为空
        /// </summary>
        [Column(Name = "bka019", Storage = null, DbType = "VarChar(10)", CanBeNull = false)]
        [Required(ErrorMessage = "就诊科室不能为空")]
        [StringLength(10)]
        public string bka019 { get; set; }

        /// <summary>
        /// 就诊科室名称
        /// 类型：string, 长度：30, 不允许为空
        /// </summary>
        [Column(Name = "bka020", Storage = null, DbType = "VarChar(30)", CanBeNull = false)]
        [Required(ErrorMessage = "就诊科室名称不能为空")]
        [StringLength(30)]
        public string bka020 { get; set; }

        /// <summary>
        /// 诊断（疾病ICD编码）
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "bka026", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "诊断（疾病ICD编码）不能为空")]
        [StringLength(20)]
        public string bka026 { get; set; }

        /// <summary>
        /// 挂号（医院HIS就医序列号）
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "bka025", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "挂号（医院HIS就医序列号）不能为空")]
        [StringLength(20)]
        public string bka025 { get; set; }

        /// <summary>
        /// 处方号
        /// 类型：string, 长度：20, 允许为空
        /// </summary>
        [Column(Name = "bka070", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        public string bka070 { get; set; }

        /// <summary>
        /// 保存标志
        /// 类型：string, 长度：1, 不允许为空
        /// 备注："0"——"试算"; "1"——"收费"
        /// </summary>
        [Column(Name = "bka893", Storage = null, DbType = "VarChar(1)", CanBeNull = false)]
        [Required(ErrorMessage = "保存标志不能为空")]
        [StringLength(1)]
        public string bka893 { get; set; }

        /// <summary>
        /// 工伤凭证号
        /// 类型：string, 长度：20, 不允许为空
        /// 备注：工伤业务
        /// </summary>
        [Column(Name = "bka042", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "工伤凭证号不能为空")]
        [StringLength(20)]
        public string bka042 { get; set; }

        public List<FeeInfoInput> feeInfoInput;
    }

    public class FeeInfoInput:EntityBase
    {
        /// <summary>
        /// 项目药品类型
        /// 类型：string, 长度：2, 不允许为空
        /// 备注：见码表
        /// </summary>
        [Column(Name = "aka063", Storage = null, DbType = "VarChar(2)", CanBeNull = false)]
        [Required(ErrorMessage = "项目药品类型不能为空")]
        [StringLength(2)]
        public string aka063 { get; set; }

        /// <summary>
        /// 医院药品项目编码
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "ake005", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "医院药品项目编码不能为空")]
        [StringLength(20)]
        public string ake005 { get; set; }

        /// <summary>
        /// 医院药品项目名称
        /// 类型：string, 长度：50, 不允许为空
        /// </summary>
        [Column(Name = "ake006", Storage = null, DbType = "VarChar(50)", CanBeNull = false)]
        [Required(ErrorMessage = "医院药品项目名称不能为空")]
        [StringLength(50)]
        public string ake006 { get; set; }

        /// <summary>
        /// 剂型
        /// 类型：string, 长度：30, 允许为空
        /// </summary>
        [Column(Name = "bka052", Storage = null, DbType = "VarChar(30)", CanBeNull = true)]
        [StringLength(30)]
        public string bka052 { get; set; }

        /// <summary>
        /// 厂家
        /// 类型：string, 长度：50, 允许为空
        /// </summary>
        [Column(Name = "bka053", Storage = null, DbType = "VarChar(50)", CanBeNull = true)]
        [StringLength(50)]
        public string bka053 { get; set; }

        /// <summary>
        /// 规格
        /// 类型：string, 长度：30, 允许为空
        /// </summary>
        [Column(Name = "bka054", Storage = null, DbType = "VarChar(30)", CanBeNull = true)]
        [StringLength(30)]
        public string bka054 { get; set; }

        /// <summary>
        /// 费用发生时间
        /// 类型：string, 长度：10, 不允许为空
        /// 格式：yyyyMMdd
        /// </summary>
        [Column(Name = "bka051", Storage = null, DbType = "VarChar(10)", CanBeNull = false)]
        [Required(ErrorMessage = "费用发生时间不能为空")]
        [StringLength(10)]
        public string bka051 { get; set; }

        /// <summary>
        /// 计量单位
        /// 类型：string, 长度：10, 允许为空
        /// </summary>
        [Column(Name = "bka055", Storage = null, DbType = "VarChar(10)", CanBeNull = true)]
        [StringLength(10)]
        public string bka055 { get; set; }

        /// <summary>
        /// 单价
        /// 类型：string, 长度：12, 不允许为空
        /// 精确到小数点后4位
        /// </summary>
        [Column(Name = "bka056", Storage = null, DbType = "VarChar(12)", CanBeNull = false)]
        [Required(ErrorMessage = "单价不能为空")]
        [StringLength(12)]
        public string bka056 { get; set; }

        /// <summary>
        /// 用量
        /// 类型：string, 长度：12, 不允许为空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka057", Storage = null, DbType = "VarChar(12)", CanBeNull = false)]
        [Required(ErrorMessage = "用量不能为空")]
        [StringLength(12)]
        public string bka057 { get; set; }

        /// <summary>
        /// 金额
        /// 类型：string, 长度：12, 不允许为空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka058", Storage = null, DbType = "VarChar(12)", CanBeNull = false)]
        [Required(ErrorMessage = "金额不能为空")]
        [StringLength(12)]
        public string bka058 { get; set; }

        /// <summary>
        /// 处方号
        /// 类型：string, 长度：20, 允许为空
        /// </summary>
        [Column(Name = "bka070", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        public string bka070 { get; set; }

        /// <summary>
        /// 处方医生编号
        /// 类型：string, 长度：12, 允许为空
        /// </summary>
        [Column(Name = "bka074", Storage = null, DbType = "VarChar(12)", CanBeNull = true)]
        [StringLength(12)]
        public string bka074 { get; set; }

        /// <summary>
        /// 处方医生姓名
        /// 类型：string, 长度：20, 允许为空
        /// </summary>
        [Column(Name = "bka075", Storage = null, DbType = "VarChar(20)", CanBeNull = true)]
        [StringLength(20)]
        public string bka075 { get; set; }

        /// <summary>
        /// 医院费用的唯一标识
        /// 类型：string, 长度：30, 允许为空
        /// </summary>
        [Column(Name = "bka071", Storage = null, DbType = "VarChar(30)", CanBeNull = true)]
        [StringLength(30)]
        public string bka071 { get; set; }

        /// <summary>
        /// 限制使用标志
        /// 类型：string, 长度：1, 允许为空
        /// 备注："0"——"否"; "1"——"是"
        /// </summary>
        [Column(Name = "aaz267", Storage = null, DbType = "VarChar(1)", CanBeNull = true)]
        [StringLength(1)]
        public string aaz267 { get; set; }

        /// <summary>
        /// 伤病分离使用标志
        /// 类型：string, 长度：10, 不允许为空
        /// 备注：1----因病；0----因伤
        /// </summary>
        [Column(Name = "bka061", Storage = null, DbType = "VarChar(10)", CanBeNull = false)]
        [Required(ErrorMessage = "伤病分离使用标志不能为空")]
        [StringLength(10)]
        public string bka061 { get; set; }

        /// <summary>
        /// 费用序号
        /// 类型：string, 长度：9, 允许为空
        /// 如果是退费操作，需使用4.1.3接口来获取该费用序号进行传入，以确定具体要进行退费操作的药品项目；正常收费时该值传空。
        /// </summary>
        [Column(Name = "aaz213", Storage = null, DbType = "VarChar(9)", CanBeNull = true)]
        [StringLength(9, ErrorMessage = "费用序号长度不能超过9个字符")]
        public string aaz213 { get; set; }
    }

    class RegisterOutput : EntityBase
    {
        public List<PayInfo> payInfo;
    }

    /// <summary>
    /// 支付信息实体类
    /// </summary>
    public class PayInfo:EntityBase
    {
        /// <summary>
        /// 医院编号
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "akb020", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "医院编号不能为空")]
        [StringLength(20, ErrorMessage = "医院编号长度不能超过20个字符")]
        public string akb020 { get; set; }

        /// <summary>
        /// 就医登记号
        /// 类型：string, 长度：20, 不允许为空
        /// </summary>
        [Column(Name = "aaz218", Storage = null, DbType = "VarChar(20)", CanBeNull = false)]
        [Required(ErrorMessage = "就医登记号不能为空")]
        [StringLength(20, ErrorMessage = "就医登记号长度不能超过20个字符")]
        public string aaz218 { get; set; }

        /// <summary>
        /// 医疗总费用
        /// 类型：string, 长度：12, 不允许为空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "akc264", Storage = null, DbType = "VarChar(12)", CanBeNull = false)]
        [Required(ErrorMessage = "医疗总费用不能为空")]
        [StringLength(12, ErrorMessage = "医疗总费用长度不能超过12个字符")]
        public string akc264 { get; set; }

        /// <summary>
        /// 个人自付
        /// 类型：string, 长度：12, 不允许为空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka831", Storage = null, DbType = "VarChar(12)", CanBeNull = false)]
        [Required(ErrorMessage = "个人自付不能为空")]
        [StringLength(12, ErrorMessage = "个人自付长度不能超过12个字符")]
        public string bka831 { get; set; }

        /// <summary>
        /// 工伤保险支付
        /// 类型：string, 长度：12, 不允许为空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka832", Storage = null, DbType = "VarChar(12)", CanBeNull = false)]
        [Required(ErrorMessage = "工伤保险支付不能为空")]
        [StringLength(12, ErrorMessage = "工伤保险支付长度不能超过12个字符")]
        public string bka832 { get; set; }

        /// <summary>
        /// 全自费费用
        /// 类型：string, 长度：12, 不允许为空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka825", Storage = null, DbType = "VarChar(12)", CanBeNull = false)]
        [Required(ErrorMessage = "全自费费用不能为空")]
        [StringLength(12, ErrorMessage = "全自费费用长度不能超过12个字符")]
        public string bka825 { get; set; }

        /// <summary>
        /// 部分自费费用
        /// 类型：string, 长度：12, 不允许为空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka826", Storage = null, DbType = "VarChar(12)", CanBeNull = false)]
        [Required(ErrorMessage = "部分自费费用不能为空")]
        [StringLength(12, ErrorMessage = "部分自费费用长度不能超过12个字符")]
        public string bka826 { get; set; }

        /// <summary>
        /// 起付线费用
        /// 类型：string, 长度：12, 不允许为空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "aka151", Storage = null, DbType = "VarChar(12)", CanBeNull = false)]
        [Required(ErrorMessage = "起付线费用不能为空")]
        [StringLength(12, ErrorMessage = "起付线费用长度不能超过12个字符")]
        public string aka151 { get; set; }

        /// <summary>
        /// 超共付段费用个人自付
        /// 类型：string, 长度：12, 不允许为空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka838", Storage = null, DbType = "VarChar(12)", CanBeNull = false)]
        [Required(ErrorMessage = "超共付段费用个人自付不能为空")]
        [StringLength(12, ErrorMessage = "超共付段费用个人自付长度不能超过12个字符")]
        public string bka838 { get; set; }

        /// <summary>
        /// 个人现金支付
        /// 类型：string, 长度：12, 不允许为空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "akb067", Storage = null, DbType = "VarChar(12)", CanBeNull = false)]
        [Required(ErrorMessage = "个人现金支付不能为空")]
        [StringLength(12, ErrorMessage = "个人现金支付长度不能超过12个字符")]
        public string akb067 { get; set; }

        /// <summary>
        /// 个人账户支付
        /// 类型：string, 长度：12, 不允许为空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "akb066", Storage = null, DbType = "VarChar(12)", CanBeNull = false)]
        [Required(ErrorMessage = "个人账户支付不能为空")]
        [StringLength(12, ErrorMessage = "个人账户支付长度不能超过12个字符")]
        public string akb066 { get; set; }

        /// <summary>
        /// 民政救助金支付
        /// 类型：string, 长度：12, 不允许为空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka821", Storage = null, DbType = "VarChar(12)", CanBeNull = false)]
        [Required(ErrorMessage = "民政救助金支付不能为空")]
        [StringLength(12, ErrorMessage = "民政救助金支付长度不能超过12个字符")]
        public string bka821 { get; set; }

        /// <summary>
        /// 其他支付
        /// 类型：string, 长度：12, 不允许为空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka839", Storage = null, DbType = "VarChar(12)", CanBeNull = false)]
        [Required(ErrorMessage = "其他支付不能为空")]
        [StringLength(12, ErrorMessage = "其他支付长度不能超过12个字符")]
        public string bka839 { get; set; }

        /// <summary>
        /// 工伤保险统筹基金支付
        /// 类型：string, 长度：12, 不允许为空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "ake039", Storage = null, DbType = "VarChar(12)", CanBeNull = false)]
        [Required(ErrorMessage = "工伤保险统筹基金支付不能为空")]
        [StringLength(12, ErrorMessage = "工伤保险统筹基金支付长度不能超过12个字符")]
        public string ake039 { get; set; }

        /// <summary>
        /// 公务员医疗补助基金支付
        /// 类型：string, 长度：12, 不允许为空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "ake035", Storage = null, DbType = "VarChar(12)", CanBeNull = false)]
        [Required(ErrorMessage = "公务员医疗补助基金支付不能为空")]
        [StringLength(12, ErrorMessage = "公务员医疗补助基金支付长度不能超过12个字符")]
        public string ake035 { get; set; }

        /// <summary>
        /// 企业补充工伤保险基金支付
        /// 类型：string, 长度：12, 不允许为空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "ake026", Storage = null, DbType = "VarChar(12)", CanBeNull = false)]
        [Required(ErrorMessage = "企业补充工伤保险基金支付不能为空")]
        [StringLength(12, ErrorMessage = "企业补充工伤保险基金支付长度不能超过12个字符")]
        public string ake026 { get; set; }

        /// <summary>
        /// 大额医疗费用补助基金支付
        /// 类型：string, 长度：12, 不允许为空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "ake029", Storage = null, DbType = "VarChar(12)", CanBeNull = false)]
        [Required(ErrorMessage = "大额医疗费用补助基金支付不能为空")]
        [StringLength(12, ErrorMessage = "大额医疗费用补助基金支付长度不能超过12个字符")]
        public string ake029 { get; set; }

        /// <summary>
        /// 单位支付
        /// 类型：string, 长度：12, 不允许为空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka841", Storage = null, DbType = "VarChar(12)", CanBeNull = false)]
        [Required(ErrorMessage = "单位支付不能为空")]
        [StringLength(12, ErrorMessage = "单位支付长度不能超过12个字符")]
        public string bka841 { get; set; }

        /// <summary>
        /// 医院垫付
        /// 类型：string, 长度：12, 不允许为空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka842", Storage = null, DbType = "VarChar(12)", CanBeNull = false)]
        [Required(ErrorMessage = "医院垫付不能为空")]
        [StringLength(12, ErrorMessage = "医院垫付长度不能超过12个字符")]
        public string bka842 { get; set; }

        /// <summary>
        /// 其他基金支付
        /// 类型：string, 长度：12, 不允许为空
        /// 精确到小数点后2位
        /// </summary>
        [Column(Name = "bka840", Storage = null, DbType = "VarChar(12)", CanBeNull = false)]
        [Required(ErrorMessage = "其他基金支付不能为空")]
        [StringLength(12, ErrorMessage = "其他基金支付长度不能超过12个字符")]
        public string bka840 { get; set; }
    }
}
