﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace PTMIBase.Entity.Interfaces.Configuration.IRIS
{   
    /// <summary>
    /// 接口信息，包括接口表存储的相关信息以及扩展
    /// </summary>
    public interface IInterfaceInfo
    {
        /// <summary>
        /// 接口编号,接口表的Dr
        /// </summary>
        int InterfaceDr { get; set; }


        /// <summary>
        /// 接口ID,接口表中给各医院分配的编号，例如:A,B,C
        /// </summary>
        string InterfaceID { get; set; }

        /// <summary>
        /// 接口名称
        /// </summary>
        string InterfaceName { get; set; }

        /// <summary>
        /// HIS中的医院Dr
        /// </summary>
        int HisHospitalDr { get; set; }

        /// <summary>
        /// 医保平台的医院Dr
        /// </summary>
        int HospitalDr { get; set; }

        /// <summary>
        /// 医院名称
        /// </summary>
        string HospitalName { get; set; }

        /// <summary>
        /// 中心分配给医院编码
        /// </summary>
        string HospitalNO { get; set; }

        /// <summary>
        /// 中心URL
        /// </summary>
        string CenterURL { get; set; }

        /// <summary>
        /// 中心备用URL,现在改为BASE64编码的各业务地址密钥信息
        /// </summary>
        string CenterURL2 { get; set; }

        /// <summary>
        /// 区域编码
        /// </summary>
        string MdtrtareaAdmvs { get; set; }

        /// <summary>
        /// 动态链接库名称
        /// </summary>
        string DllName { get; set; }

        /// <summary>
        /// 版本号
        /// </summary>
        string Version { get; set; }

        /// <summary>
        /// 医院等级
        /// </summary>
        string HospitalLevel { get; set; }

        /// <summary>
        /// 使用标志 False 停用 True 使用
        /// </summary>
         string UseFlag { get; set; }

        /// <summary>
        /// 序号 （根据该序号决定所有接口的优先级，比如显示优先级等等.原则上该序号在省内唯一，各省之间允许重复）
        /// </summary>
         int SerialNO { get; set; }

        /// <summary>
        /// 医院区域
        /// </summary>
         int InsuRegionDr { get; set; }

        /// <summary>
        /// 医保区域目录标志 0 或空 不是  1 是     1 表示该目录是该区域的主目录  0 该目录会自动查询区域主目录 -1 该目录禁止自动查询区域主目录
        /// </summary>
         int InsuRegionFlag { get; set; }

        /// <summary>
        /// 区域通用目录 
        /// </summary>
         int InsuCurrencyCataLogue { get; set; }

        /// <summary>
        /// 区域配置 （该配置决定了该目录是否启用区域）
        /// 配置说明 0|0|0|   第一位表示启用共享目录  第二位表示启用区域共享字典   第三位表示启用区域对照关系  
        /// 默认1|0|0|    0表示未启用，只查询本地 1表示启用，先查询本地，当本地木有时查询主接口目录 2.表示启用，但仅仅查询主接口目录
        /// </summary>
         string RegionConfig { get; set; } 

        /// <summary>
        /// 自助机适用标志 -1 不适用 0 适用 1 适用且为启动目录
        /// </summary>
         int SelfServiceFlag { get; set; } 

        /// <summary>
        /// 移动支付密钥信息
        /// </summary>
        IBranchBusinessInfo MobilePay { get; set; }

        /// <summary>
        /// 处方流转密钥信息
        /// </summary>
        IBranchBusinessInfo PresCir { get; set; }
    }
}
