﻿using PTMIBase.Entity.Interfaces.HIS;
using PTMIBase.Entity.Interfaces.InsuInfo;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace PTMIBase.Entity.Interfaces
{
	/// <summary>
	/// 患者信息全局变量，包括基本信息，结算信息
	/// </summary>
    public interface IPatient
    {
		/// <summary>
		/// HIS传过来的患者信息
		/// </summary>
		IBaseHISInfo BaseHISInfo { get; set; }

		/// <summary>
		/// 基本参保信息
		/// </summary>
		IBaseInsuInfo BaseInsuInfo { get; set; }

		/// <summary>
		/// 医保就诊登记号
		/// </summary>
		string MdtrtID { get; set; }


		/// <summary>
		/// 身份证号码
		/// </summary>
		string IDCardNumber { get; set; }

		/// <summary>
		/// 就诊类型  门诊，住院，
		/// </summary>
		string AdmType { get; set; }

		/// <summary>
		/// 诊断组
		/// </summary>
		IItemInfo[] Diagnosis { get; set; }

		/// <summary>
		/// 主诊断
		/// </summary>
		IItemInfo MainDiagnosis{ get; set; }

		/// <summary>
		/// 病种
		/// </summary>
		IItemInfo Disease { get; set; }

		/// <summary>
		/// 手术操作
		/// </summary>
		IItemInfo Operation { get; set; }

		/// <summary>
		/// 入院科室
		/// </summary>
		IItemInfo AdmittingDepartment { get; set; }

		/// <summary>
		/// 出院科室
		/// </summary>
		IItemInfo DischargeDepartment { get; set; }

		/// <summary>
		/// 开单科室
		/// </summary>
		IItemInfo OrderingDepartment { get; set; }

		/// <summary>
		/// 执行科室
		/// </summary>
		IItemInfo PerformingDepartment { get; set; }

		/// <summary>
		/// 主治医生
		/// </summary>
		IItemInfo AttendingDoctor { get; set; }


		/// <summary>
		/// 当前选择的参保信息
		/// </summary>
		ICurrentInsuInfo CurrentInsuInfo { get; set; }

		/// <summary>
		/// 结算信息
		/// </summary>
		ISettlement Settl { get; set; }

		/// <summary>
		/// 移动支付信息，可能不需要
		/// </summary>
		IMobilePay MobilePay { get; set; }
	}
}
