﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace PTMIBase.Entity.Interfaces.InsuInfo
{
    /// <summary>
    /// 结算的相关信息
    /// </summary>
    public interface ISettlement
    {
        /// <summary>
        /// 结算ID
        /// </summary>
         string SettlementID { get; set; }


        /// <summary>
        /// 结算日期
        /// </summary>
         DateTime SettlementDate { get; set; }

        /// <summary>
        /// 结算日期时间
        /// </summary>
         DateTime SettlementDateTime { get; set; }

        /// <summary>
        /// 就诊凭证类型
        /// </summary>
         string MdtrtCertType { get; set; }

        /// <summary>
        /// 医疗类别
        /// </summary>
         string MedicalType { get; set; }

        /// <summary>
        /// 医疗费总额
        /// </summary>
         string Sumamt { get; set; }

        /// <summary>
        /// 全自费金额
        /// </summary>
         string OwnPayAmount { get; set; }

        /// <summary>
        /// 超限价自费费用
        /// </summary>
         string OverLimitAmount { get; set; }

        /// <summary>
        /// 先行自付金额
        /// </summary>
         string PreSelfPayAmount { get; set; }

        /// <summary>
        /// 符合政策范围金额
        /// </summary>
         string InPolicyRangeAmount { get; set; }

        /// <summary>
        /// 实际支付起付线
        /// </summary>
         string ActualPayDeductible { get; set; }

        /// <summary>
        /// 基本医疗保险统筹基金支出
        /// </summary>
         string HealthInsurancePay { get; set; }

        /// <summary>
        /// 基本医疗保险统筹基金支付比例
        /// </summary>
         string HealthInsuranceRatio { get; set; }

        /// <summary>
        /// 公务员医疗补助资金支出
        /// </summary>
         string CivilserviceAllowancePay { get; set; }

        /// <summary>
        /// 企业补充医疗保险基金支出
        /// </summary>
         string EnterpriseSupplementPay { get; set; }

        /// <summary>
        /// 居民大病保险资金支出
        /// </summary>
         string SeriousIllnessPay { get; set; }

        /// <summary>
        /// 职工大额医疗费用补助基金支出
        /// </summary>
         string LargeExpensesSupplementPay { get; set; }

        /// <summary>
        /// 医疗救助基金支出
        /// </summary>
         string MedicalAssistPay { get; set; }

        /// <summary>
        /// 医院负担金额
        /// </summary>
         string HospitalPartAmount { get; set; }

        /// <summary>
        /// 其他支出
        /// </summary>
         string OtherPay { get; set; }

        /// <summary>
        /// 基金支付总额
        /// </summary>
         string FundPaySumamt { get; set; }

        /// <summary>
        /// 个人负担总金额
        /// </summary>
         string PersonPaySumamt { get; set; }

        /// <summary>
        /// 个人账户支出
        /// </summary>
         string AccountPaySumamt { get; set; }

        /// <summary>
        /// 个人现金支出
        /// </summary>
         string PersonCashPay { get; set; }

        /// <summary>
        /// 余额
        /// </summary>
         string Balance { get; set; }

        /// <summary>
        /// 个人账户共济支付金额
        /// </summary>
         string AccountMutualAidAmount { get; set; }

        /// <summary>
        /// 医药机构结算ID
        /// </summary>
         string OrganSettlementID { get; set; }

        /// <summary>
        /// 清算经办机构
        /// </summary>
         string ClearingOrgan { get; set; }

        /// <summary>
        /// 清算方式
        /// </summary>
         string ClearingWay { get; set; }

        /// <summary>
        /// 清算类别
        /// </summary>
         string ClearingType { get; set; }

        /// <summary>
        /// 有效标志 0 无效 1 有效
        /// </summary>
         int ValidFlag { get; set; }

        /// <summary>
        /// 单据类型 1 正票 -1 负票 9 异常票据
        /// </summary>
         int BillType { get; set; }

        /// <summary>
        /// 账单ID
        /// </summary>
         int BillID { get; set; }

        /// <summary>
        /// 接口编号 指向接口表
        /// </summary>
         string InterfaceDr { get; set; }

        /// <summary>
        /// 发生时间
        /// </summary>
         DateTime OccurTime { get; set; }

        /// <summary>
        /// 报文ID （配合冲正）
        /// </summary>
         string MSGID { get; set; }

        /// <summary>
        /// 就诊类型 1.门诊 2.住院 3.线上支付门诊 4.线上支付住院
        /// </summary>
         int AdmType { get; set; }

        /// <summary>
        /// 付款记录ID
        /// </summary>
         int RecordID { get; set; }

        /// <summary>
        /// 参保地医保区划(InsurancePlaceDivision)
        /// </summary>
         string InsuranceAreaCode { get; set; }

        /// <summary>
        /// 住院次数
        /// </summary>
         int HospitalizationsTimes { get; set; }

        /// <summary>
        /// 住院天数
        /// </summary>
         int HospitalizationsDays { get; set; }

        /// <summary>
        /// HIS入院时间
        /// </summary>
         DateTime HISAdmTime { get; set; }

        /// <summary>
        /// HIS出院时间
        /// </summary>
         DateTime HISDischargeTime { get; set; }

        /// <summary>
        /// 共济账户主结算ID
        /// </summary>
         string MainSettlementIDOfMutualAid { get; set; }

        /// <summary>
        /// 共济标志 0或空 未启用共济 大于0 启用了共济账户，同时代表共济的结算数据笔数，第一笔为主共济结算，一般要求所有结算均为医保结算。
        /// </summary>
         int MutualAidFlag { get; set; }

        /// <summary>
        /// 扩展字段 基线版医保接口扩展字段
        /// </summary>
         string ExpContent { get; set; }

        /// <summary>
        /// 确认标志 0未确认 1 已确认
        /// </summary>
         int ConfirmFlag { get; set; }

        /// <summary>
        /// 订单ID，配合移动支付
        /// </summary>
         string PayOrdID { get; set; }

        /// <summary>
        /// 对账标志 0未确认 1 已账户支付 3 已确认 5 已对账
        /// </summary>
         int CheckMark { get; set; }

        /// <summary>
        /// 特病类别
        /// </summary>
         string SpecialType { get; set; }

        /// <summary>
        /// 特殊人员类别
        /// </summary>
         string SpecialPersonType { get; set; }

        /// <summary>
        /// 结算方式
        /// </summary>
         string SettlementWay { get; set; }

        /// <summary>
        /// 病种编码
        /// </summary>
         string DiseaseCode { get; set; }

        /// <summary>
        /// 病种名称
        /// </summary>
         string DiseaseName { get; set; }

        /// <summary>
        /// 商保支付标志 0-商保未缴费 1-商保正常报销 2-个人负担（不含超限价）超6万 3-商保计算服务调用异常、4-商保已支付
        /// </summary>
         string CommercialRenFlag { get; set; }

        /// <summary>
        /// 商保支付金额
        /// </summary>
         string CommercialReimamt { get; set; }

        /// <summary>
        /// 冲正标志 0 正常 1 已冲正
        /// </summary>
         string ReversalFlag { get; set; }
    }
}
