﻿using PTMIBase.Extensions.Attributes;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;

namespace PTMIBase.Entity.MIDatatable
{
    class ClearingRecord
    {
        /// <summary>
        /// 医院编号 指向医院表
        /// 类型：int, 不允许为空
        /// </summary>
        [IrisColumn(Name = "HospitalDr", Desc = "医院编号", DbType = "Int", SqlFieldName = "Hosp_Dr", Order = 2, CanBeNull = false)]
        [Required(ErrorMessage = "医院编号不能为空")]
        public int HospitalDr { get; set; }

        /// <summary>
        /// 接口编号 指向接口表
        /// 类型：HBMedInsuInterface, 不允许为空
        /// </summary>
        [IrisColumn(Name = "InterfaceDr", Desc = "接口编号", DbType = "VarChar(50)", SqlFieldName = "Interface_Dr", Order = 3, CanBeNull = false)]
        [Required(ErrorMessage = "接口编号不能为空")]
        [StringLength(50, ErrorMessage = "接口编号长度不能超过50个字符")]
        public string InterfaceDr { get; set; }

        /// <summary>
        /// 月结算申请ID
        /// 类型：string, 大写, 不允许为空
        /// </summary>
        [IrisColumn(Name = "ApplyID", Desc = "月结算申请ID", DbType = "VarChar(50)", SqlFieldName = "ApplyID", Order = 4, CanBeNull = false)]
        [Required(ErrorMessage = "月结算申请ID不能为空")]
        [StringLength(50, ErrorMessage = "月结算申请ID长度不能超过50个字符")]
        public string ApplyID { get; set; }

        /// <summary>
        /// 发生时间
        /// 类型：DateTime, 不允许为空
        /// </summary>
        [IrisColumn(Name = "OccurTime", Desc = "发生时间", DbType = "DateTime", SqlFieldName = "OccurTime", Order = 5, CanBeNull = false)]
        [Required(ErrorMessage = "发生时间不能为空")]
        public DateTime OccurTime { get; set; }

        /// <summary>
        /// 清算类别
        /// 类型：string, 不允许为空
        /// </summary>
        [IrisColumn(Name = "ClrType", Desc = "清算类别", DbType = "VarChar(50)", SqlFieldName = "ClrType", Order = 6, CanBeNull = false)]
        [Required(ErrorMessage = "清算类别不能为空")]
        [StringLength(50, ErrorMessage = "清算类别长度不能超过50个字符")]
        public string ClrType { get; set; }

        /// <summary>
        /// 清算方式
        /// 类型：string, 可为空
        /// </summary>
        [IrisColumn(Name = "ClrWay", Desc = "清算方式", DbType = "VarChar(50)", SqlFieldName = "ClrWay", Order = 7, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "清算方式长度不能超过50个字符")]
        public string ClrWay { get; set; }

        /// <summary>
        /// 清算年月
        /// 类型：string, 可为空
        /// </summary>
        [IrisColumn(Name = "ClearYearMonth", Desc = "清算年月", DbType = "VarChar(50)", SqlFieldName = "ClearYearMonth", Order = 8, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "清算年月长度不能超过50个字符")]
        public string ClearYearMonth { get; set; }

        /// <summary>
        /// 人次
        /// 类型：int, 可为空
        /// </summary>
        [IrisColumn(Name = "PersonTime", Desc = "人次", DbType = "Int", SqlFieldName = "PersonTime", Order = 9, CanBeNull = true)]
        public int? PersonTime { get; set; }

        /// <summary>
        /// 总金额
        /// 类型：decimal, 不允许为空
        /// </summary>
        [IrisColumn(Name = "Sumamt", Desc = "总金额", DbType = "Decimal(18,2)", SqlFieldName = "Sumamt", Order = 10, CanBeNull = false)]
        [Required(ErrorMessage = "总金额不能为空")]
        public decimal Sumamt { get; set; }

        /// <summary>
        /// 医保认可金额
        /// 类型：decimal, 可为空
        /// </summary>
        [IrisColumn(Name = "MedAcceptSumamt", Desc = "医保认可金额", DbType = "Decimal(18,2)", SqlFieldName = "MedAcceptSumamt", Order = 11, CanBeNull = true)]
        public decimal? MedAcceptSumamt { get; set; }

        /// <summary>
        /// 基金支付金额
        /// 类型：decimal, 可为空
        /// </summary>
        [IrisColumn(Name = "FundPay", Desc = "基金支付金额", DbType = "Decimal(18,2)", SqlFieldName = "FundPay", Order = 12, CanBeNull = true)]
        public decimal? FundPay { get; set; }

        /// <summary>
        /// 现金支付金额
        /// 类型：decimal, 可为空
        /// </summary>
        [IrisColumn(Name = "CashPay", Desc = "现金支付金额", DbType = "Decimal(18,2)", SqlFieldName = "CashPay", Order = 13, CanBeNull = true)]
        public decimal? CashPay { get; set; }

        /// <summary>
        /// 账户支付金额
        /// 类型：decimal, 可为空
        /// </summary>
        [IrisColumn(Name = "AccountPay", Desc = "账户支付金额", DbType = "Decimal(18,2)", SqlFieldName = "AccountPay", Order = 14, CanBeNull = true)]
        public decimal? AccountPay { get; set; }

        /// <summary>
        /// 开始时间
        /// 类型：DateTime, 不允许为空
        /// </summary>
        [IrisColumn(Name = "Begndate", Desc = "开始时间", DbType = "DateTime", SqlFieldName = "Begndate", Order = 15, CanBeNull = false)]
        [Required(ErrorMessage = "开始时间不能为空")]
        public DateTime Begndate { get; set; }

        /// <summary>
        /// 截止时间
        /// 类型：DateTime, 不允许为空
        /// </summary>
        [IrisColumn(Name = "Enddate", Desc = "截止时间", DbType = "DateTime", SqlFieldName = "Enddate", Order = 16, CanBeNull = false)]
        [Required(ErrorMessage = "截止时间不能为空")]
        public DateTime Enddate { get; set; }

        /// <summary>
        /// 有效标志
        /// 类型：int, 不允许为空
        /// </summary>
        [IrisColumn(Name = "ValidFlag", Desc = "有效标志", DbType = "Int", SqlFieldName = "ValidFlag", Order = 17, CanBeNull = false)]
        [Required(ErrorMessage = "有效标志不能为空")]
        public int ValidFlag { get; set; }

        /// <summary>
        /// 经办人
        /// 类型：string, 可为空
        /// </summary>
        [IrisColumn(Name = "Operator", Desc = "经办人", DbType = "VarChar(50)", SqlFieldName = "Operator", Order = 18, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "经办人长度不能超过50个字符")]
        public string Operator { get; set; }

        /// <summary>
        /// 公务员统筹支付金额
        /// 类型：decimal, 可为空
        /// </summary>
        [IrisColumn(Name = "CivilservicePay", Desc = "公务员统筹支付金额", DbType = "Decimal(18,2)", SqlFieldName = "CivilservicePay", Order = 19, CanBeNull = true)]
        public decimal? CivilservicePay { get; set; }

        /// <summary>
        /// 大额医疗支付金额
        /// 类型：decimal, 可为空
        /// </summary>
        [IrisColumn(Name = "LargeExpensesPay", Desc = "大额医疗支付金额", DbType = "Decimal(18,2)", SqlFieldName = "LargeExpensesPay", Order = 20, CanBeNull = true)]
        public decimal? LargeExpensesPay { get; set; }

        /// <summary>
        /// 清算中心
        /// 类型：string, 可为空
        /// </summary>
        [IrisColumn(Name = "ClearingOrgan", Desc = "清算中心", DbType = "VarChar(50)", SqlFieldName = "ClearingOrgan", Order = 21, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "清算中心长度不能超过50个字符")]
        public string ClearingOrgan { get; set; }

        /// <summary>
        /// 险种类型
        /// 类型：string, 可为空
        /// </summary>
        [IrisColumn(Name = "InsuranceType", Desc = "险种类型", DbType = "VarChar(50)", SqlFieldName = "InsuranceType", Order = 22, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "险种类型长度不能超过50个字符")]
        public string InsuranceType { get; set; }

        /// <summary>
        /// 医疗类型
        /// 类型：string, 可为空
        /// </summary>
        [IrisColumn(Name = "MedType", Desc = "医疗类型", DbType = "VarChar(50)", SqlFieldName = "MedType", Order = 23, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "医疗类型长度不能超过50个字符")]
        public string MedType { get; set; }

        /// <summary>
        /// 医保交易编码
        /// 类型：string, 可为空
        /// </summary>
        [IrisColumn(Name = "InsuBusinessID", Desc = "医保交易编码", DbType = "VarChar(50)", SqlFieldName = "InsuBusinessID", Order = 24, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "医保交易编码长度不能超过50个字符")]
        public string InsuBusinessID { get; set; }
    
    }
}
