﻿using PTMIBase.Extensions.Attributes;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;

namespace PTMIBase.Entity.MIDatatable
{
    class CurrentInsuInfo
    {
        /// <summary>
        /// 医院编号 指向医院表
        /// </summary>
        [IrisColumn(Name = "HospitalDr", Desc = "医院编号", DbType = "Int", SqlFieldName = "Hospital_Dr", Order = 2, CanBeNull = false)]
        [Required(ErrorMessage = "医院编号不能为空")]
        public int HospitalDr { get; set; }

        /// <summary>
        /// 接口编号 指向接口表
        /// </summary>
        [IrisColumn(Name = "InterfaceDr", Desc = "接口编号", DbType = "Int", SqlFieldName = "Interface_Dr", Order = 3, CanBeNull = false)]
        [Required(ErrorMessage = "接口编号不能为空")]
        public int InterfaceDr { get; set; }

        /// <summary>
        /// 患者医院ID
        /// </summary>
        [IrisColumn(Name = "AdmID", Desc = "患者医院ID", DbType = "Varchar(50)", SqlFieldName = "AdmID", Order = 4, CanBeNull = false)]
        [Required(ErrorMessage = "患者医院ID不能为空")]
        [StringLength(50, ErrorMessage = "患者医院ID长度不能超过50个字符")]
        public string AdmID { get; set; }

        /// <summary>
        /// 患者姓名
        /// </summary>
        [IrisColumn(Name = "PatientName", Desc = "患者姓名", DbType = "Varchar(50)", SqlFieldName = "PatientName", Order = 5, CanBeNull = false)]
        [Required(ErrorMessage = "患者姓名不能为空")]
        [StringLength(50, ErrorMessage = "患者姓名长度不能超过50个字符")]
        public string PatientName { get; set; }

        /// <summary>
        /// 患者医保编号
        /// </summary>
        [IrisColumn(Name = "PersonalNO", Desc = "患者医保编号", DbType = "Varchar(50)", SqlFieldName = "PersonalNO", Order = 6, CanBeNull = false)]
        [Required(ErrorMessage = "患者医保编号不能为空")]
        [StringLength(50, ErrorMessage = "患者医保编号长度不能超过50个字符")]
        public string PersonalNO { get; set; }

        /// <summary>
        /// 医保登记号
        /// </summary>
        [IrisColumn(Name = "MdtrtID", Desc = "医保登记号", DbType = "Varchar(50)", SqlFieldName = "MdtrtID", Order = 7, CanBeNull = false)]
        [Required(ErrorMessage = "医保登记号不能为空")]
        [StringLength(50, ErrorMessage = "医保登记号长度不能超过50个字符")]
        public string MdtrtID { get; set; }

        /// <summary>
        /// 医保凭证类型
        /// </summary>
        [IrisColumn(Name = "PsnCertType", Desc = "医保凭证类型", DbType = "Varchar(50)", SqlFieldName = "PsnCertType", Order = 8, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "医保凭证类型长度不能超过50个字符")]
        public string PsnCertType { get; set; }

        /// <summary>
        /// 医保凭证编码
        /// </summary>
        [IrisColumn(Name = "PsnCertNO", Desc = "医保凭证编码", DbType = "Varchar(50)", SqlFieldName = "PsnCertNO", Order = 9, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "医保凭证编码长度不能超过50个字符")]
        public string PsnCertNO { get; set; }

        /// <summary>
        /// 性别
        /// </summary>
        [IrisColumn(Name = "Gend", Desc = "性别", DbType = "Varchar(50)", SqlFieldName = "Gend", Order = 10, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "性别长度不能超过50个字符")]
        public string Gend { get; set; }

        /// <summary>
        /// 民族
        /// </summary>
        [IrisColumn(Name = "Naty", Desc = "民族", DbType = "Varchar(50)", SqlFieldName = "Naty", Order = 11, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "民族长度不能超过50个字符")]
        public string Naty { get; set; }

        /// <summary>
        /// 出生日期
        /// </summary>
        [IrisColumn(Name = "Brdy", Desc = "出生日期", DbType = "Date", SqlFieldName = "Brdy", Order = 12, CanBeNull = true)]
        public DateTime? Brdy { get; set; }

        /// <summary>
        /// 年龄
        /// </summary>
        [IrisColumn(Name = "Age", Desc = "年龄", DbType = "Varchar(50)", SqlFieldName = "Age", Order = 13, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "年龄长度不能超过50个字符")]
        public string Age { get; set; }

        /// <summary>
        /// 余额
        /// </summary>
        [IrisColumn(Name = "Balc", Desc = "余额", DbType = "Decimal(18,2)", SqlFieldName = "Balc", Order = 14, CanBeNull = true)]
        public decimal? Balc { get; set; }

        /// <summary>
        /// 险种类型
        /// </summary>
        [IrisColumn(Name = "Insutype", Desc = "险种类型", DbType = "Varchar(50)", SqlFieldName = "Insutype", Order = 15, CanBeNull = false)]
        [Required(ErrorMessage = "险种类型不能为空")]
        [StringLength(50, ErrorMessage = "险种类型长度不能超过50个字符")]
        public string Insutype { get; set; }

        /// <summary>
        /// 人员类别
        /// </summary>
        [IrisColumn(Name = "PsnType", Desc = "人员类别", DbType = "Varchar(50)", SqlFieldName = "PsnType", Order = 16, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "人员类别长度不能超过50个字符")]
        public string PsnType { get; set; }

        /// <summary>
        /// 人员参保状态
        /// </summary>
        [IrisColumn(Name = "PsnInsuStas", Desc = "人员参保状态", DbType = "Varchar(50)", SqlFieldName = "PsnInsuStas", Order = 17, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "人员参保状态长度不能超过50个字符")]
        public string PsnInsuStas { get; set; }

        /// <summary>
        /// 人员参保日期
        /// </summary>
        [IrisColumn(Name = "PsnInsuDate", Desc = "人员参保日期", DbType = "Date", SqlFieldName = "PsnInsuDate", Order = 18, CanBeNull = true)]
        public DateTime? PsnInsuDate { get; set; }

        /// <summary>
        /// 暂停参保日期
        /// </summary>
        [IrisColumn(Name = "PausInsuDate", Desc = "暂停参保日期", DbType = "Date", SqlFieldName = "PausInsuDate", Order = 19, CanBeNull = true)]
        public DateTime? PausInsuDate { get; set; }

        /// <summary>
        /// 公务员标志
        /// </summary>
        [IrisColumn(Name = "Cvlservflag", Desc = "公务员标志", DbType = "Varchar(50)", SqlFieldName = "Cvlservflag", Order = 20, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "公务员标志长度不能超过50个字符")]
        public string Cvlservflag { get; set; }

        /// <summary>
        /// 人员参保区划
        /// </summary>
        [IrisColumn(Name = "insuplcAdmdvs", Desc = "人员参保区划", DbType = "Varchar(50)", SqlFieldName = "insuplcAdmdvs", Order = 21, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "人员参保区划长度不能超过50个字符")]
        public string insuplcAdmdvs { get; set; }

        /// <summary>
        /// 单位名称
        /// </summary>
        [IrisColumn(Name = "EmpName", Desc = "单位名称", DbType = "Varchar(300)", SqlFieldName = "EmpName", Order = 22, CanBeNull = true)]
        [StringLength(300, ErrorMessage = "单位名称长度不能超过300个字符")]
        public string EmpName { get; set; }

        /// <summary>
        /// 人员身份类别
        /// </summary>
        [IrisColumn(Name = "PsnIdettype", Desc = "人员身份类别", DbType = "Varchar(50)", SqlFieldName = "PsnIdettype", Order = 23, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "人员身份类别长度不能超过50个字符")]
        public string PsnIdettype { get; set; }

        /// <summary>
        /// 人员类别等级
        /// </summary>
        [IrisColumn(Name = "PsnTypeLv", Desc = "人员类别等级", DbType = "Varchar(50)", SqlFieldName = "PsnTypeLv", Order = 24, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "人员类别等级长度不能超过50个字符")]
        public string PsnTypeLv { get; set; }

        /// <summary>
        /// 人员身份开始时间
        /// </summary>
        [IrisColumn(Name = "IdetBegntime", Desc = "人员身份开始时间", DbType = "Date", SqlFieldName = "IdetBegntime", Order = 25, CanBeNull = true)]
        public DateTime? IdetBegntime { get; set; }

        /// <summary>
        /// 人员身份结束时间
        /// </summary>
        [IrisColumn(Name = "IdetEndtime", Desc = "人员身份结束时间", DbType = "Date", SqlFieldName = "IdetEndtime", Order = 26, CanBeNull = true)]
        public DateTime? IdetEndtime { get; set; }

        /// <summary>
        /// 扩展字段1
        /// </summary>
        [IrisColumn(Name = "ExtField1", Desc = "扩展字段1", DbType = "Text", SqlFieldName = "ExtField1", Order = 27, CanBeNull = true)]
        public string ExtField1 { get; set; }

        /// <summary>
        /// 扩展字段2
        /// </summary>
        [IrisColumn(Name = "ExtField2", Desc = "扩展字段2", DbType = "Varchar(50)", SqlFieldName = "ExtField2", Order = 28, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "扩展字段2长度不能超过50个字符")]
        public string ExtField2 { get; set; }

        /// <summary>
        /// 扩展字段3
        /// </summary>
        [IrisColumn(Name = "ExtField3", Desc = "扩展字段3", DbType = "Varchar(50)", SqlFieldName = "ExtField3", Order = 29, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "扩展字段3长度不能超过50个字符")]
        public string ExtField3 { get; set; }

        /// <summary>
        /// 扩展字段4
        /// </summary>
        [IrisColumn(Name = "ExtField4", Desc = "扩展字段4", DbType = "Varchar(50)", SqlFieldName = "ExtField4", Order = 30, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "扩展字段4长度不能超过50个字符")]
        public string ExtField4 { get; set; }

        /// <summary>
        /// 扩展字段 基线版医保接口扩展字段
        /// </summary>
        [IrisColumn(Name = "ExpContent", Desc = "扩展字段", DbType = "Varchar(500)", SqlFieldName = "ExpContent", Order = 31, CanBeNull = true)]
        [StringLength(500, ErrorMessage = "扩展字段长度不能超过500个字符")]
        public string ExpContent { get; set; }
    }
}
