﻿using PTMIBase.Extensions.Attributes;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;


namespace PTMIBase.Entity.MIDatatable
{
    class Directory
    {
        // <summary>
        /// 医院编号 指向医院表
        /// </summary>
        [IrisColumn(Name = "HospitalDr", Desc = "医院编号", DbType = "Int", SqlFieldName = "Hospital_Dr", Order = 2, CanBeNull = false)]
        [Required(ErrorMessage = "医院编号不能为空")]
        public int HospitalDr { get; set; }

        /// <summary>
        /// 接口编号 指向接口表
        /// </summary>
        [IrisColumn(Name = "InterfaceDr", Desc = "接口编号", DbType = "Int", SqlFieldName = "Interface_Dr", Order = 3, CanBeNull = false)]
        [Required(ErrorMessage = "接口编号不能为空")]
        public int InterfaceDr { get; set; }

        /// <summary>
        /// 医保编码
        /// </summary>
        [IrisColumn(Name = "Code", Desc = "医保编码", DbType = "Varchar(50)", SqlFieldName = "Code", Order = 4, CanBeNull = false)]
        [Required(ErrorMessage = "医保编码不能为空")]
        [StringLength(50, ErrorMessage = "医保编码长度不能超过50个字符")]
        public string Code { get; set; }

        /// <summary>
        /// 医保名称
        /// </summary>
        [IrisColumn(Name = "Name", Desc = "医保名称", DbType = "Varchar(100)", SqlFieldName = "Name", Order = 5, CanBeNull = false)]
        [Required(ErrorMessage = "医保名称不能为空")]
        [StringLength(100, ErrorMessage = "医保名称长度不能超过100个字符")]
        public string Name { get; set; }

        /// <summary>
        /// 医院目录类型 HisType 1.药品 2.诊疗 3.材料 4.疾病诊断 5.手术 6.慢性病 7.DRGs 8.日间手术 9.待定
        /// 10.中药饮片 11.医疗机构制剂 12.民族药品 13.肿瘤形态学 14.中医疾病目录 15 中医证候目录
        /// </summary>
        [IrisColumn(Name = "HisType", Desc = "医院目录类型", DbType = "Varchar(50)", SqlFieldName = "HisType", Order = 6, CanBeNull = false)]
        [Required(ErrorMessage = "医院目录类型不能为空")]
        [StringLength(50, ErrorMessage = "医院目录类型长度不能超过50个字符")]
        public string HisType { get; set; }

        /// <summary>
        /// 医院类型名称
        /// </summary>
        [IrisColumn(Name = "HisTypeName", Desc = "医院类型名称", DbType = "Varchar(100)", SqlFieldName = "HisTypeName", Order = 7, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "医院类型名称长度不能超过100个字符")]
        public string HisTypeName { get; set; }

        /// <summary>
        /// 医保本地编码
        /// </summary>
        [IrisColumn(Name = "LocateCode", Desc = "医保本地编码", DbType = "Varchar(50)", SqlFieldName = "LocateCode", Order = 8, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "医保本地编码长度不能超过50个字符")]
        public string LocateCode { get; set; }

        /// <summary>
        /// 医保本地名称
        /// </summary>
        [IrisColumn(Name = "LocateName", Desc = "医保本地名称", DbType = "Varchar(100)", SqlFieldName = "LocateName", Order = 9, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "医保本地名称长度不能超过100个字符")]
        public string LocateName { get; set; }

        /// <summary>
        /// 本位码
        /// </summary>
        [IrisColumn(Name = "DrugSafetyStandardCode", Desc = "本位码", DbType = "Varchar(50)", SqlFieldName = "DrugSafetyStandardCode", Order = 29, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "本位码长度不能超过50个字符")]
        public string DrugSafetyStandardCode { get; set; }

        /// <summary>
        /// 剂型编码
        /// </summary>
        [IrisColumn(Name = "DosageFormCode", Desc = "剂型编码", DbType = "Varchar(100)", SqlFieldName = "DosageFormCode", Order = 10, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "剂型编码长度不能超过100个字符")]
        public string DosageFormCode { get; set; }

        /// <summary>
        /// 剂型名称
        /// </summary>
        [IrisColumn(Name = "DosageFormName", Desc = "剂型名称", DbType = "Varchar(500)", SqlFieldName = "DosageFormName", Order = 11, CanBeNull = true)]
        [StringLength(500, ErrorMessage = "剂型名称长度不能超过500个字符")]
        public string DosageFormName { get; set; }

        /// <summary>
        /// 类别编码
        /// </summary>
        [IrisColumn(Name = "CategoryCode", Desc = "类别编码", DbType = "Varchar(50)", SqlFieldName = "CategoryCode", Order = 12, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "类别编码长度不能超过50个字符")]
        public string CategoryCode { get; set; }

        /// <summary>
        /// 类别名称
        /// </summary>
        [IrisColumn(Name = "CategoryName", Desc = "类别名称", DbType = "Varchar(50)", SqlFieldName = "CategoryName", Order = 13, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "类别名称长度不能超过50个字符")]
        public string CategoryName { get; set; }

        /// <summary>
        /// 规格
        /// </summary>
        [IrisColumn(Name = "Specification", Desc = "规格", DbType = "Varchar(500)", SqlFieldName = "Specification", Order = 14, CanBeNull = true)]
        [StringLength(500, ErrorMessage = "规格长度不能超过500个字符")]
        public string Specification { get; set; }

        /// <summary>
        /// 规格代码
        /// </summary>
        [IrisColumn(Name = "SpecificationCode", Desc = "规格代码", DbType = "Varchar(50)", SqlFieldName = "SpecificationCode", Order = 15, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "规格代码长度不能超过50个字符")]
        public string SpecificationCode { get; set; }

        /// <summary>
        /// 包装单位
        /// </summary>
        [IrisColumn(Name = "UnitOfPackag", Desc = "包装单位", DbType = "Varchar(50)", SqlFieldName = "UnitOfPackag", Order = 16, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "包装单位长度不能超过50个字符")]
        public string UnitOfPackag { get; set; }

        /// <summary>
        /// 计价单位
        /// </summary>
        [IrisColumn(Name = "UnitOfValuation", Desc = "计价单位", DbType = "Varchar(50)", SqlFieldName = "UnitOfValuation", Order = 17, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "计价单位长度不能超过50个字符")]
        public string UnitOfValuation { get; set; }

        /// <summary>
        /// 开始日期
        /// </summary>
        [IrisColumn(Name = "StartDate", Desc = "开始日期", DbType = "DateTime", SqlFieldName = "StartDate", Order = 18, CanBeNull = true)]
        public DateTime? StartDate { get; set; }

        /// <summary>
        /// 结束日期
        /// </summary>
        [IrisColumn(Name = "EndDate", Desc = "结束日期", DbType = "DateTime", SqlFieldName = "EndDate", Order = 19, CanBeNull = true)]
        public DateTime? EndDate { get; set; }

        /// <summary>
        /// 拼音助记码
        /// </summary>
        [IrisColumn(Name = "PinyinSearchCode", Desc = "拼音助记码", DbType = "Varchar(50)", SqlFieldName = "PinyinSearchCode", Order = 20, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "拼音助记码长度不能超过50个字符")]
        public string PinyinSearchCode { get; set; }

        /// <summary>
        /// 说明
        /// </summary>
        [IrisColumn(Name = "Instructions", Desc = "说明", DbType = "Varchar(500)", SqlFieldName = "Instructions", Order = 21, CanBeNull = true)]
        [StringLength(500, ErrorMessage = "说明长度不能超过500个字符")]
        public string Instructions { get; set; }

        /// <summary>
        /// 除外内容
        /// </summary>
        [IrisColumn(Name = "ExceptContent", Desc = "除外内容", DbType = "Varchar(500)", SqlFieldName = "ExceptContent", Order = 22, CanBeNull = true)]
        [StringLength(500, ErrorMessage = "除外内容长度不能超过500个字符")]
        public string ExceptContent { get; set; }

        /// <summary>
        /// 项目内涵
        /// </summary>
        [IrisColumn(Name = "Connotation", Desc = "项目内涵", DbType = "Varchar(500)", SqlFieldName = "Connotation", Order = 23, CanBeNull = true)]
        [StringLength(500, ErrorMessage = "项目内涵长度不能超过500个字符")]
        public string Connotation { get; set; }

        /// <summary>
        /// 有效标志
        /// </summary>
        [IrisColumn(Name = "ValidFlag", Desc = "有效标志", DbType = "Int", SqlFieldName = "ValidFlag", Order = 24, CanBeNull = true)]
        public int? ValidFlag { get; set; }

        /// <summary>
        /// 备注
        /// </summary>
        [IrisColumn(Name = "Note", Desc = "备注", DbType = "Varchar(200)", SqlFieldName = "Note", Order = 25, CanBeNull = true)]
        [StringLength(200, ErrorMessage = "备注长度不能超过200个字符")]
        public string Note { get; set; }

        /// <summary>
        /// 批准文号
        /// </summary>
        [IrisColumn(Name = "ApprovalNO", Desc = "批准文号", DbType = "Varchar(200)", SqlFieldName = "ApprovalNO", Order = 30, CanBeNull = true)]
        [StringLength(200, ErrorMessage = "批准文号长度不能超过200个字符")]
        public string ApprovalNO { get; set; }

        /// <summary>
        /// 版本号
        /// </summary>
        [IrisColumn(Name = "VersionNO", Desc = "版本号", DbType = "Varchar(50)", SqlFieldName = "VersionNO", Order = 26, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "版本号长度不能超过50个字符")]
        public string VersionNO { get; set; }

        /// <summary>
        /// 版本名称
        /// </summary>
        [IrisColumn(Name = "VersionName", Desc = "版本名称", DbType = "Varchar(50)", SqlFieldName = "VersionName", Order = 27, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "版本名称长度不能超过50个字符")]
        public string VersionName { get; set; }

        /// <summary>
        /// 使用标志
        /// </summary>
        [IrisColumn(Name = "UseFlag", Desc = "使用标志", DbType = "Int", SqlFieldName = "UseFlag", Order = 28, CanBeNull = true)]
        public int? UseFlag { get; set; }

        /// <summary>
        /// 特殊药品标志
        /// </summary>
        [IrisColumn(Name = "SpecialFlag", Desc = "特殊药品标志", DbType = "Int", SqlFieldName = "SpecialFlag", Order = 31, CanBeNull = true)]
        public int? SpecialFlag { get; set; }

        /// <summary>
        /// 限制标志
        /// </summary>
        [IrisColumn(Name = "LimitFlag", Desc = "限制标志", DbType = "Int", SqlFieldName = "LimitFlag", Order = 32, CanBeNull = true)]
        public int? LimitFlag { get; set; }

        /// <summary>
        /// 限制范围
        /// </summary>
        [IrisColumn(Name = "LimitRange", Desc = "限制范围", DbType = "Varchar(500)", SqlFieldName = "LimitRange", Order = 33, CanBeNull = true)]
        [StringLength(500, ErrorMessage = "限制范围长度不能超过500个字符")]
        public string LimitRange { get; set; }

        /// <summary>
        /// 唯一记录号
        /// </summary>
        [IrisColumn(Name = "UniqueRecordNO", Desc = "唯一记录号", DbType = "Varchar(50)", SqlFieldName = "UniqueRecordNO", Order = 34, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "唯一记录号长度不能超过50个字符")]
        public string UniqueRecordNO { get; set; }

        /// <summary>
        /// 厂家
        /// </summary>
        [IrisColumn(Name = "Manufacturers", Desc = "厂家", DbType = "Varchar(200)", SqlFieldName = "Manufacturers", Order = 35, CanBeNull = true)]
        [StringLength(200, ErrorMessage = "厂家长度不能超过200个字符")]
        public string Manufacturers { get; set; }

        /// <summary>
        /// 国家项目编码
        /// </summary>
        [IrisColumn(Name = "NationalCode", Desc = "国家项目编码", DbType = "Varchar(50)", SqlFieldName = "NationalCode", Order = 36, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "国家项目编码长度不能超过50个字符")]
        public string NationalCode { get; set; }

        /// <summary>
        /// 国家项目名称
        /// </summary>
        [IrisColumn(Name = "NationalName", Desc = "国家项目名称", DbType = "Varchar(100)", SqlFieldName = "NationalName", Order = 37, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "国家项目名称长度不能超过100个字符")]
        public string NationalName { get; set; }

        /// <summary>
        /// 更新时间
        /// </summary>
        [IrisColumn(Name = "UpdateTime", Desc = "更新时间", DbType = "DateTime", SqlFieldName = "UpdateTime", Order = 38, CanBeNull = true)]
        public DateTime? UpdateTime { get; set; }

        /// <summary>
        /// 收费项目等级 01 甲类 02 乙类 03 自费
        /// </summary>
        [IrisColumn(Name = "ChargeItemLevel", Desc = "收费项目等级", DbType = "Varchar(50)", SqlFieldName = "ChargeItemLevel", Order = 39, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "收费项目等级长度不能超过50个字符")]
        public string ChargeItemLevel { get; set; }

        /// <summary>
        /// 收费项目等级名称 01 甲类 02 乙类 03 自费 04 可报丙类
        /// </summary>
        [IrisColumn(Name = "ChargeItemLevelName", Desc = "收费项目等级名称", DbType = "Varchar(200)", SqlFieldName = "ChargeItemLevelName", Order = 40, CanBeNull = true)]
        [StringLength(200, ErrorMessage = "收费项目等级名称长度不能超过200个字符")]
        public string ChargeItemLevelName { get; set; }

        /// <summary>
        /// 自付比例
        /// </summary>
        [IrisColumn(Name = "SelfPercent", Desc = "自付比例", DbType = "Varchar(50)", SqlFieldName = "SelfPercent", Order = 41, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "自付比例长度不能超过50个字符")]
        public string SelfPercent { get; set; }

        /// <summary>
        /// 医疗收费项目类别 基线版：01 床位费 08 卫生材料费 02 诊察费 09 西药费 03 检查费 10 中药饮片费
        /// 04 化验费 11 中成药费 05 治疗费 12 一般诊疗费 06 手术费 13 挂号费 07 护理费 14 其他费
        /// </summary>
        [IrisColumn(Name = "ChargeItemType", Desc = "医疗收费项目类别", DbType = "Varchar(50)", SqlFieldName = "ChargeItemType", Order = 42, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "医疗收费项目类别长度不能超过50个字符")]
        public string ChargeItemType { get; set; }

        /// <summary>
        /// 收费标准
        /// </summary>
        [IrisColumn(Name = "ChargeStandards", Desc = "收费标准", DbType = "Varchar(50)", SqlFieldName = "ChargeStandards", Order = 43, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "收费标准长度不能超过50个字符")]
        public string ChargeStandards { get; set; }

        /// <summary>
        /// 最高限价
        /// </summary>
        [IrisColumn(Name = "CeilingPrice", Desc = "最高限价", DbType = "Varchar(50)", SqlFieldName = "CeilingPrice", Order = 44, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "最高限价长度不能超过50个字符")]
        public string CeilingPrice { get; set; }

        /// <summary>
        /// 包装材质
        /// </summary>
        [IrisColumn(Name = "PackagingMaterial", Desc = "包装材质", DbType = "Varchar(200)", SqlFieldName = "PackagingMaterial", Order = 45, CanBeNull = true)]
        [StringLength(200, ErrorMessage = "包装材质长度不能超过200个字符")]
        public string PackagingMaterial { get; set; }

        /// <summary>
        /// 最小包装数量
        /// </summary>
        [IrisColumn(Name = "MinPackagingQuantity", Desc = "最小包装数量", DbType = "Varchar(50)", SqlFieldName = "MinPackagingQuantity", Order = 46, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "最小包装数量长度不能超过50个字符")]
        public string MinPackagingQuantity { get; set; }

        /// <summary>
        /// 最小制剂单位
        /// </summary>
        [IrisColumn(Name = "MinDosageUnit", Desc = "最小制剂单位", DbType = "Varchar(50)", SqlFieldName = "MinDosageUnit", Order = 47, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "最小制剂单位长度不能超过50个字符")]
        public string MinDosageUnit { get; set; }

        /// <summary>
        /// 最小包装单位
        /// </summary>
        [IrisColumn(Name = "MinPackagingUnit", Desc = "最小包装单位", DbType = "Varchar(50)", SqlFieldName = "MinPackagingUnit", Order = 48, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "最小包装单位长度不能超过50个字符")]
        public string MinPackagingUnit { get; set; }

        /// <summary>
        /// 累计增负标志 天津专用
        /// </summary>
        [IrisColumn(Name = "CumulativeNegativeBurdenFlag", Desc = "累计增负标志", DbType = "Int", SqlFieldName = "CumulativeNegativeBurdenFlag", Order = 49, CanBeNull = true)]
        public int? CumulativeNegativeBurdenFlag { get; set; }

        /// <summary>
        /// 目录支付比例
        /// </summary>
        [IrisColumn(Name = "DirectoryPayPercent", Desc = "目录支付比例", DbType = "Varchar(50)", SqlFieldName = "DirectoryPayPercent", Order = 51, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "目录支付比例长度不能超过50个字符")]
        public string DirectoryPayPercent { get; set; }
    }
}
