﻿using PTMIBase.Extensions.Attributes;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;

namespace PTMIBase.Entity.MIDatatable
{
    class DirectoryInsuInfo
    {
        /// <summary>
        /// 医院编号 指向医院表
        /// </summary>
        [IrisColumn(Name = "HospitalDr", Desc = "医院编号", DbType = "Int", SqlFieldName = "Hospital_Dr", Order = 2, CanBeNull = false)]
        [Required(ErrorMessage = "医院编号不能为空")]
        public int HospitalDr { get; set; }

        /// <summary>
        /// 接口编号 指向接口表
        /// </summary>
        [IrisColumn(Name = "InterfaceDr", Desc = "接口编号", DbType = "Int", SqlFieldName = "Interface_Dr", Order = 3, CanBeNull = false)]
        [Required(ErrorMessage = "接口编号不能为空")]
        public int InterfaceDr { get; set; }

        /// <summary>
        /// 目录编号 指向医保目录表
        /// </summary>
        [IrisColumn(Name = "DirectoryDr", Desc = "目录编号", DbType = "Int", SqlFieldName = "Directory_Dr", Order = 4, CanBeNull = false)]
        [Required(ErrorMessage = "目录编号不能为空")]
        public int DirectoryDr { get; set; }

        /// <summary>
        /// 医保编码
        /// </summary>
        [IrisColumn(Name = "Code", Desc = "医保编码", DbType = "Varchar(50)", SqlFieldName = "Code", Order = 5, CanBeNull = false)]
        [Required(ErrorMessage = "医保编码不能为空")]
        [StringLength(50, ErrorMessage = "医保编码长度不能超过50个字符")]
        public string Code { get; set; }

        /// <summary>
        /// 医保名称
        /// </summary>
        [IrisColumn(Name = "Name", Desc = "医保名称", DbType = "Varchar(100)", SqlFieldName = "Name", Order = 6, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "医保名称长度不能超过100个字符")]
        public string Name { get; set; }

        /// <summary>
        /// 参保地医保区划
        /// </summary>
        [IrisColumn(Name = "InsuranceAreaCode", Desc = "参保地医保区划", DbType = "Varchar(50)", SqlFieldName = "InsuranceAreaCode", Order = 7, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "参保地医保区划长度不能超过50个字符")]
        public string InsuranceAreaCode { get; set; }

        /// <summary>
        /// 开始日期
        /// </summary>
        [IrisColumn(Name = "BeginDate", Desc = "开始日期", DbType = "DateTime", SqlFieldName = "BeginDate", Order = 8, CanBeNull = true)]
        public DateTime? BeginDate { get; set; }

        /// <summary>
        /// 结束日期
        /// </summary>
        [IrisColumn(Name = "EndDate", Desc = "结束日期", DbType = "DateTime", SqlFieldName = "EndDate", Order = 9, CanBeNull = true)]
        public DateTime? EndDate { get; set; }

        /// <summary>
        /// 收费项目类别
        /// </summary>
        [IrisColumn(Name = "ChargeItemType", Desc = "收费项目类别", DbType = "Varchar(50)", SqlFieldName = "ChargeItemType", Order = 10, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "收费项目类别长度不能超过50个字符")]
        public string ChargeItemType { get; set; }

        /// <summary>
        /// 收费项目等级
        /// </summary>
        [IrisColumn(Name = "ChargeItemLevel", Desc = "收费项目等级", DbType = "Varchar(50)", SqlFieldName = "ChargeItemLevel", Order = 11, CanBeNull = false)]
        [Required(ErrorMessage = "收费项目等级不能为空")]
        [StringLength(50, ErrorMessage = "收费项目等级长度不能超过50个字符")]
        public string ChargeItemLevel { get; set; }

        /// <summary>
        /// 限制使用标志
        /// </summary>
        [IrisColumn(Name = "LimitUsedFalg", Desc = "限制使用标志", DbType = "Varchar(50)", SqlFieldName = "LimitUsedFalg", Order = 12, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "限制使用标志长度不能超过50个字符")]
        public string LimitUsedFalg { get; set; }

        /// <summary>
        /// 目录类别
        /// </summary>
        [IrisColumn(Name = "ListType", Desc = "目录类别", DbType = "Varchar(50)", SqlFieldName = "ListType", Order = 13, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "目录类别长度不能超过50个字符")]
        public string ListType { get; set; }

        /// <summary>
        /// 医疗使用标志
        /// </summary>
        [IrisColumn(Name = "MedUsedFlag", Desc = "医疗使用标志", DbType = "Varchar(50)", SqlFieldName = "MedUsedFlag", Order = 14, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "医疗使用标志长度不能超过50个字符")]
        public string MedUsedFlag { get; set; }

        /// <summary>
        /// 生育使用标志
        /// </summary>
        [IrisColumn(Name = "MatnUsedFalg", Desc = "生育使用标志", DbType = "Varchar(50)", SqlFieldName = "MatnUsedFalg", Order = 15, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "生育使用标志长度不能超过50个字符")]
        public string MatnUsedFalg { get; set; }

        /// <summary>
        /// 医保目录使用类别
        /// </summary>
        [IrisColumn(Name = "UsedType", Desc = "医保目录使用类别", DbType = "Varchar(50)", SqlFieldName = "UsedType", Order = 16, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "医保目录使用类别长度不能超过50个字符")]
        public string UsedType { get; set; }

        /// <summary>
        /// 限复方使用类型
        /// </summary>
        [IrisColumn(Name = "LimitCpndType", Desc = "限复方使用类型", DbType = "Varchar(50)", SqlFieldName = "LimitCpndType", Order = 17, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "限复方使用类型长度不能超过50个字符")]
        public string LimitCpndType { get; set; }

        /// <summary>
        /// 备注
        /// </summary>
        [IrisColumn(Name = "Memo", Desc = "备注", DbType = "Varchar(200)", SqlFieldName = "Memo", Order = 18, CanBeNull = true)]
        [StringLength(200, ErrorMessage = "备注长度不能超过200个字符")]
        public string Memo { get; set; }

        /// <summary>
        /// 有效标志
        /// </summary>
        [IrisColumn(Name = "ValidFlag", Desc = "有效标志", DbType = "Varchar(50)", SqlFieldName = "ValidFlag", Order = 19, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "有效标志长度不能超过50个字符")]
        public string ValidFlag { get; set; }

        /// <summary>
        /// 唯一记录号
        /// </summary>
        [IrisColumn(Name = "RequiredID", Desc = "唯一记录号", DbType = "Varchar(50)", SqlFieldName = "RequiredID", Order = 20, CanBeNull = false)]
        [Required(ErrorMessage = "唯一记录号不能为空")]
        [StringLength(50, ErrorMessage = "唯一记录号长度不能超过50个字符")]
        public string RequiredID { get; set; }

        /// <summary>
        /// 统筹区
        /// </summary>
        [IrisColumn(Name = "PoolAreaNO", Desc = "统筹区", DbType = "Varchar(50)", SqlFieldName = "PoolAreaNO", Order = 21, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "统筹区长度不能超过50个字符")]
        public string PoolAreaNO { get; set; }

        /// <summary>
        /// 更新时间
        /// </summary>
        [IrisColumn(Name = "UpdateTime", Desc = "更新时间", DbType = "DateTime", SqlFieldName = "UpdateTime", Order = 22, CanBeNull = true)]
        public DateTime? UpdateTime { get; set; }
    }
}
