﻿using PTMIBase.Extensions.Attributes;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;

namespace PTMIBase.Entity.MIDatatable
{
    class FeeSeparater
    {
        /// <summary>
        /// 医院ID 指向CB_Hospital
        /// 类型：CBHospital, 不允许为空
        /// </summary>
        [IrisColumn(Name = "HospitalDr", Desc = "医院ID", DbType = "Int", SqlFieldName = "Hospital_Dr", Order = 2, CanBeNull = false)]
        [Required(ErrorMessage = "医院ID不能为空")]
        public int HospitalDr { get; set; }

        /// <summary>
        /// 病人ID 指向患者信息表
        /// 类型：int, 不允许为空
        /// </summary>
        [IrisColumn(Name = "AdmID", Desc = "病人ID", DbType = "Int", SqlFieldName = "AdmID", Order = 3, CanBeNull = false)]
        [Required(ErrorMessage = "病人ID不能为空")]
        public int AdmID { get; set; }

        /// <summary>
        /// 登记Dr 指向登记表
        /// 类型：int, 可为空
        /// </summary>
        [IrisColumn(Name = "RegisterDr", Desc = "登记Dr", DbType = "Int", SqlFieldName = "RegDr", Order = 4, CanBeNull = true)]
        public int? RegisterDr { get; set; }

        /// <summary>
        /// 费用明细流水号
        /// 类型：string, 不允许为空
        /// </summary>
        [IrisColumn(Name = "SerialNO", Desc = "费用明细流水号", DbType = "VarChar(50)", SqlFieldName = "SerialNO", Order = 5, CanBeNull = false)]
        [Required(ErrorMessage = "费用明细流水号不能为空")]
        [StringLength(50, ErrorMessage = "费用明细流水号长度不能超过50个字符")]
        public string SerialNO { get; set; }

        /// <summary>
        /// 原费用流水号
        /// 类型：string, 可为空
        /// </summary>
        [IrisColumn(Name = "OriginalSerialNO", Desc = "原费用流水号", DbType = "VarChar(50)", SqlFieldName = "OriginalSerialNO", Order = 6, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "原费用流水号长度不能超过50个字符")]
        public string OriginalSerialNO { get; set; }

        /// <summary>
        /// 就诊ID
        /// 类型：string, 不允许为空
        /// </summary>
        [IrisColumn(Name = "MdtrtID", Desc = "就诊ID", DbType = "VarChar(50)", SqlFieldName = "MdtrtID", Order = 7, CanBeNull = false)]
        [Required(ErrorMessage = "就诊ID不能为空")]
        [StringLength(50, ErrorMessage = "就诊ID长度不能超过50个字符")]
        public string MdtrtID { get; set; }

        /// <summary>
        /// 医嘱号
        /// 类型：string, 不允许为空
        /// </summary>
        [IrisColumn(Name = "DoctorOrderNO", Desc = "医嘱号", DbType = "VarChar(50)", SqlFieldName = "DoctorOrderNO", Order = 8, CanBeNull = false)]
        [Required(ErrorMessage = "医嘱号不能为空")]
        [StringLength(50, ErrorMessage = "医嘱号长度不能超过50个字符")]
        public string DoctorOrderNO { get; set; }

        /// <summary>
        /// 人员编号
        /// 类型：string, 不允许为空
        /// </summary>
        [IrisColumn(Name = "PersonnelNO", Desc = "人员编号", DbType = "VarChar(50)", SqlFieldName = "PersonnelNO", Order = 9, CanBeNull = false)]
        [Required(ErrorMessage = "人员编号不能为空")]
        [StringLength(50, ErrorMessage = "人员编号长度不能超过50个字符")]
        public string PersonnelNO { get; set; }

        /// <summary>
        /// 医疗类别
        /// 类型：string, 可为空
        /// </summary>
        [IrisColumn(Name = "MedicalType", Desc = "医疗类别", DbType = "VarChar(50)", SqlFieldName = "MedicalType", Order = 10, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "医疗类别长度不能超过50个字符")]
        public string MedicalType { get; set; }

        /// <summary>
        /// 费用发生时间
        /// 类型：DateTime, 不允许为空
        /// </summary>
        [IrisColumn(Name = "FeeOccurTime", Desc = "费用发生时间", DbType = "DateTime", SqlFieldName = "FeeOccurTime", Order = 11, CanBeNull = false)]
        [Required(ErrorMessage = "费用发生时间不能为空")]
        public DateTime FeeOccurTime { get; set; }

        /// <summary>
        /// 医疗目录编码
        /// 类型：string, 不允许为空
        /// </summary>
        [IrisColumn(Name = "MedInsuNO", Desc = "医疗目录编码", DbType = "VarChar(50)", SqlFieldName = "MedInsuNO", Order = 12, CanBeNull = false)]
        [Required(ErrorMessage = "医疗目录编码不能为空")]
        [StringLength(50, ErrorMessage = "医疗目录编码长度不能超过50个字符")]
        public string MedInsuNO { get; set; }

        /// <summary>
        /// 医药机构目录编码
        /// 类型：string, 不允许为空
        /// </summary>
        [IrisColumn(Name = "HISCode", Desc = "医药机构目录编码", DbType = "VarChar(50)", SqlFieldName = "HISCode", Order = 13, CanBeNull = false)]
        [Required(ErrorMessage = "医药机构目录编码不能为空")]
        [StringLength(50, ErrorMessage = "医药机构目录编码长度不能超过50个字符")]
        public string HISCode { get; set; }

        /// <summary>
        /// 明细项目费用总额
        /// 类型：decimal, 不允许为空
        /// </summary>
        [IrisColumn(Name = "Sumamt", Desc = "明细项目费用总额", DbType = "Decimal(18,2)", SqlFieldName = "Sumamt", Order = 14, CanBeNull = false)]
        [Required(ErrorMessage = "明细项目费用总额不能为空")]
        public decimal Sumamt { get; set; }

        /// <summary>
        /// 数量
        /// 类型：decimal, 不允许为空
        /// </summary>
        [IrisColumn(Name = "Count", Desc = "数量", DbType = "Decimal(18,2)", SqlFieldName = "Count", Order = 15, CanBeNull = false)]
        [Required(ErrorMessage = "数量不能为空")]
        public decimal Count { get; set; }

        /// <summary>
        /// 单价
        /// 类型：decimal, 不允许为空
        /// </summary>
        [IrisColumn(Name = "Price", Desc = "单价", DbType = "Decimal(18,2)", SqlFieldName = "Price", Order = 16, CanBeNull = false)]
        [Required(ErrorMessage = "单价不能为空")]
        public decimal Price { get; set; }

        /// <summary>
        /// 全自费金额
        /// 类型：decimal, 可为空
        /// </summary>
        [IrisColumn(Name = "OwnPayAmount", Desc = "全自费金额", DbType = "Decimal(18,2)", SqlFieldName = "OwnPayAmount", Order = 17, CanBeNull = true)]
        public decimal? OwnPayAmount { get; set; }

        /// <summary>
        /// 先行自付金额 增负金额
        /// 类型：decimal, 可为空
        /// </summary>
        [IrisColumn(Name = "PreSelfPayAmount", Desc = "先行自付金额 增负金额", DbType = "Decimal(18,2)", SqlFieldName = "PreSelfPayAmount", Order = 18, CanBeNull = true)]
        public decimal? PreSelfPayAmount { get; set; }

        /// <summary>
        /// 申报金额
        /// 类型：decimal, 可为空
        /// </summary>
        [IrisColumn(Name = "DeclaredAmount", Desc = "申报金额", DbType = "Decimal(18,2)", SqlFieldName = "DeclaredAmount", Order = 19, CanBeNull = true)]
        public decimal? DeclaredAmount { get; set; }

        /// <summary>
        /// 自付比例
        /// 类型：decimal, 可为空
        /// </summary>
        [IrisColumn(Name = "SelfPayRatio", Desc = "自付比例", DbType = "Decimal(18,2)", SqlFieldName = "SelfPayRatio", Order = 20, CanBeNull = true)]
        public decimal? SelfPayRatio { get; set; }

        /// <summary>
        /// 累计增负标志
        /// 类型：string, 可为空
        /// </summary>
        [IrisColumn(Name = "AccruingPreSelfPayFlag", Desc = "累计增负标志", DbType = "VarChar(50)", SqlFieldName = "AccruingPreSelfPayFlag", Order = 21, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "累计增负标志长度不能超过50个字符")]
        public string AccruingPreSelfPayFlag { get; set; }

        /// <summary>
        /// 统计代码
        /// 类型：string, 可为空
        /// </summary>
        [IrisColumn(Name = "StatisticalCode", Desc = "统计代码", DbType = "VarChar(50)", SqlFieldName = "StatisticalCode", Order = 22, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "统计代码长度不能超过50个字符")]
        public string StatisticalCode { get; set; }

        /// <summary>
        /// 序号
        /// 类型：int, 可为空
        /// </summary>
        [IrisColumn(Name = "OrderNO", Desc = "序号", DbType = "Int", SqlFieldName = "OrderNO", Order = 23, CanBeNull = true)]
        public int? OrderNO { get; set; }

        /// <summary>
        /// 医药机构目录名称
        /// 类型：string, 不允许为空
        /// </summary>
        [IrisColumn(Name = "HISName", Desc = "医药机构目录名称", DbType = "VarChar(50)", SqlFieldName = "HISName", Order = 24, CanBeNull = false)]
        [Required(ErrorMessage = "医药机构目录名称不能为空")]
        [StringLength(50, ErrorMessage = "医药机构目录名称长度不能超过50个字符")]
        public string HISName { get; set; }

        /// <summary>
        /// 剂型
        /// 类型：string, 最大长度：500, 可为空
        /// </summary>
        [IrisColumn(Name = "DosageForm", Desc = "剂型", DbType = "VarChar(500)", SqlFieldName = "DosageForm", Order = 25, CanBeNull = true)]
        [StringLength(500, ErrorMessage = "剂型长度不能超过500个字符")]
        public string DosageForm { get; set; }

        /// <summary>
        /// 规格
        /// 类型：string, 最大长度：500, 可为空
        /// </summary>
        [IrisColumn(Name = "Specification", Desc = "规格", DbType = "VarChar(500)", SqlFieldName = "Specification", Order = 26, CanBeNull = true)]
        [StringLength(500, ErrorMessage = "规格长度不能超过500个字符")]
        public string Specification { get; set; }

        /// <summary>
        /// 增负药品标志
        /// 类型：string, 可为空
        /// </summary>
        [IrisColumn(Name = "PreSelfPayDrugFlag", Desc = "增负药品标志", DbType = "VarChar(50)", SqlFieldName = "PreSelfPayDrugFlag", Order = 27, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "增负药品标志长度不能超过50个字符")]
        public string PreSelfPayDrugFlag { get; set; }

        /// <summary>
        /// 用量
        /// 类型：decimal, 可为空
        /// </summary>
        [IrisColumn(Name = "UsedDosage", Desc = "用量", DbType = "Decimal(18,2)", SqlFieldName = "UsedDosage", Order = 28, CanBeNull = true)]
        public decimal? UsedDosage { get; set; }

        /// <summary>
        /// 用法
        /// 类型：string, 最大长度：100, 可为空
        /// </summary>
        [IrisColumn(Name = "UsedWay", Desc = "用法", DbType = "VarChar(100)", SqlFieldName = "UsedWay", Order = 29, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "用法长度不能超过100个字符")]
        public string UsedWay { get; set; }

        /// <summary>
        /// 批准文号
        /// 类型：string, 可为空
        /// </summary>
        [IrisColumn(Name = "ApprovalNO", Desc = "批准文号", DbType = "VarChar(50)", SqlFieldName = "ApprovalNO", Order = 30, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "批准文号长度不能超过50个字符")]
        public string ApprovalNO { get; set; }

        /// <summary>
        /// 医保专用票据号
        /// 类型：string, 可为空
        /// </summary>
        [IrisColumn(Name = "MISpecialInvoiceNO", Desc = "医保专用票据号", DbType = "VarChar(50)", SqlFieldName = "MISpecialInvoiceNO", Order = 31, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "医保专用票据号长度不能超过50个字符")]
        public string MISpecialInvoiceNO { get; set; }

        /// <summary>
        /// 用药天数
        /// 类型：string, 可为空
        /// </summary>
        [IrisColumn(Name = "DaysOfUsedDrug", Desc = "用药天数", DbType = "VarChar(50)", SqlFieldName = "DaysOfUsedDrug", Order = 32, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "用药天数长度不能超过50个字符")]
        public string DaysOfUsedDrug { get; set; }

        /// <summary>
        /// 门诊申报情况说明
        /// 类型：string, 最大长度：500, 可为空
        /// </summary>
        [IrisColumn(Name = "OutpatDeclareNote", Desc = "门诊申报情况说明", DbType = "VarChar(500)", SqlFieldName = "OutpatDeclareNote", Order = 33, CanBeNull = true)]
        [StringLength(500, ErrorMessage = "门诊申报情况说明长度不能超过500个字符")]
        public string OutpatDeclareNote { get; set; }

        /// <summary>
        /// 用量编码
        /// 类型：string, 可为空
        /// </summary>
        [IrisColumn(Name = "UsedDosageCode", Desc = "用量编码", DbType = "VarChar(50)", SqlFieldName = "UsedDosageCode", Order = 34, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "用量编码长度不能超过50个字符")]
        public string UsedDosageCode { get; set; }

        /// <summary>
        /// 用量单位
        /// 类型：string, 可为空
        /// </summary>
        [IrisColumn(Name = "DosageUnit", Desc = "用量单位", DbType = "VarChar(50)", SqlFieldName = "DosageUnit", Order = 35, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "用量单位长度不能超过50个字符")]
        public string DosageUnit { get; set; }

        /// <summary>
        /// 用量单位说明
        /// 类型：string, 最大长度：500, 可为空
        /// </summary>
        [IrisColumn(Name = "DosageUnitNote", Desc = "用量单位说明", DbType = "VarChar(500)", SqlFieldName = "DosageUnitNote", Order = 36, CanBeNull = true)]
        [StringLength(500, ErrorMessage = "用量单位说明长度不能超过500个字符")]
        public string DosageUnitNote { get; set; }

        /// <summary>
        /// 用法类型@每几时/日@次数
        /// 类型：string, 可为空
        /// </summary>
        [IrisColumn(Name = "UsedWayType", Desc = "用法类型@每几时/日@次数", DbType = "VarChar(50)", SqlFieldName = "UsedWayType", Order = 37, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "用法类型@每几时/日@次数长度不能超过50个字符")]
        public string UsedWayType { get; set; }

        /// <summary>
        /// 用法说明
        /// 类型：string, 最大长度：500, 可为空
        /// </summary>
        [IrisColumn(Name = "UsedWayNote", Desc = "用法说明", DbType = "VarChar(500)", SqlFieldName = "UsedWayNote", Order = 38, CanBeNull = true)]
        [StringLength(500, ErrorMessage = "用法说明长度不能超过500个字符")]
        public string UsedWayNote { get; set; }

        /// <summary>
        /// 给药途径
        /// 类型：string, 可为空
        /// </summary>
        [IrisColumn(Name = "RouteofAdministration", Desc = "给药途径", DbType = "VarChar(50)", SqlFieldName = "RouteofAdministration", Order = 39, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "给药途径长度不能超过50个字符")]
        public string RouteofAdministration { get; set; }

        /// <summary>
        /// 手术费用标志
        /// 类型：string, 可为空
        /// </summary>
        [IrisColumn(Name = "OperationFeeFlag", Desc = "手术费用标志", DbType = "VarChar(50)", SqlFieldName = "OperationFeeFlag", Order = 40, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "手术费用标志长度不能超过50个字符")]
        public string OperationFeeFlag { get; set; }
    }
}
