﻿using PTMIBase.Extensions.Attributes;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;

namespace PTMIBase.Entity.MIDatatable
{
    class FeeUploadRecord
    {
        /// <summary>
        /// 医院ID 指向CB_Hospital
        /// </summary>
        [IrisColumn(Name = "HospitalDr", Desc = "医院ID", DbType = "Int", SqlFieldName = "Hospital_Dr", Order = 2, CanBeNull = false)]
        [Required(ErrorMessage = "医院ID不能为空")]
        public int HospitalDr { get; set; }

        /// <summary>
        /// 病人ID 指向患者信息表
        /// </summary>
        [IrisColumn(Name = "AdmID", Desc = "病人ID", DbType = "Int", SqlFieldName = "AdmID", Order = 3, CanBeNull = false)]
        [Required(ErrorMessage = "病人ID不能为空")]
        public int AdmID { get; set; }

        /// <summary>
        /// 登记Dr 指向登记表
        /// </summary>
        [IrisColumn(Name = "RegisterDr", Desc = "登记Dr", DbType = "Int", SqlFieldName = "RegDr", Order = 4, CanBeNull = true)]
        public int? RegisterDr { get; set; }

        /// <summary>
        /// 费用明细流水号
        /// </summary>
        [IrisColumn(Name = "SerialNO", Desc = "费用明细流水号", DbType = "VarChar(50)", SqlFieldName = "SerialNO", Order = 5, CanBeNull = false)]
        [Required(ErrorMessage = "费用明细流水号不能为空")]
        [StringLength(50, ErrorMessage = "费用明细流水号长度不能超过50个字符")]
        public string SerialNO { get; set; }

        /// <summary>
        /// 原费用流水号
        /// </summary>
        [IrisColumn(Name = "OriginalSerialNO", Desc = "原费用流水号", DbType = "VarChar(50)", SqlFieldName = "OriginalSerialNO", Order = 6, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "原费用流水号长度不能超过50个字符")]
        public string OriginalSerialNO { get; set; }

        /// <summary>
        /// 就诊ID
        /// </summary>
        [IrisColumn(Name = "MdtrtID", Desc = "就诊ID", DbType = "VarChar(50)", SqlFieldName = "MdtrtID", Order = 7, CanBeNull = false)]
        [Required(ErrorMessage = "就诊ID不能为空")]
        [StringLength(50, ErrorMessage = "就诊ID长度不能超过50个字符")]
        public string MdtrtID { get; set; }

        /// <summary>
        /// 医嘱号
        /// </summary>
        [IrisColumn(Name = "DoctorOrderNO", Desc = "医嘱号", DbType = "VarChar(50)", SqlFieldName = "DoctorOrderNO", Order = 8, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "医嘱号长度不能超过50个字符")]
        public string DoctorOrderNO { get; set; }

        /// <summary>
        /// 人员编号
        /// </summary>
        [IrisColumn(Name = "PersonnelNO", Desc = "人员编号", DbType = "VarChar(50)", SqlFieldName = "PersonnelNO", Order = 9, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "人员编号长度不能超过50个字符")]
        public string PersonnelNO { get; set; }

        /// <summary>
        /// 医疗类别
        /// </summary>
        [IrisColumn(Name = "MedicalType", Desc = "医疗类别", DbType = "VarChar(50)", SqlFieldName = "MedicalType", Order = 10, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "医疗类别长度不能超过50个字符")]
        public string MedicalType { get; set; }

        /// <summary>
        /// 费用发生时间
        /// </summary>
        [IrisColumn(Name = "FeeOccurTime", Desc = "费用发生时间", DbType = "DateTime", SqlFieldName = "FeeOccurTime", Order = 11, CanBeNull = false)]
        [Required(ErrorMessage = "费用发生时间不能为空")]
        public DateTime FeeOccurTime { get; set; }

        /// <summary>
        /// 医疗目录编码
        /// </summary>
        [IrisColumn(Name = "MedInsuNO", Desc = "医疗目录编码", DbType = "VarChar(50)", SqlFieldName = "MedInsuNO", Order = 12, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "医疗目录编码长度不能超过50个字符")]
        public string MedInsuNO { get; set; }

        /// <summary>
        /// 医药机构目录编码
        /// </summary>
        [IrisColumn(Name = "HISCode", Desc = "医药机构目录编码", DbType = "VarChar(50)", SqlFieldName = "HISCode", Order = 13, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "医药机构目录编码长度不能超过50个字符")]
        public string HISCode { get; set; }

        /// <summary>
        /// 明细项目费用总额
        /// </summary>
        [IrisColumn(Name = "Sumamt", Desc = "明细项目费用总额", DbType = "Decimal(18,2)", SqlFieldName = "Sumamt", Order = 14, CanBeNull = true)]
        public decimal? Sumamt { get; set; }

        /// <summary>
        /// 数量
        /// </summary>
        [IrisColumn(Name = "Count", Desc = "数量", DbType = "Decimal(18,2)", SqlFieldName = "Count", Order = 15, CanBeNull = true)]
        public decimal? Count { get; set; }

        /// <summary>
        /// 单价
        /// </summary>
        [IrisColumn(Name = "Price", Desc = "单价", DbType = "Decimal(18,2)", SqlFieldName = "Price", Order = 16, CanBeNull = true)]
        public decimal? Price { get; set; }

        /// <summary>
        /// 定价上限金额
        /// </summary>
        [IrisColumn(Name = "UpLimitAmount", Desc = "定价上限金额", DbType = "Decimal(18,2)", SqlFieldName = "UpLimitAmount", Order = 17, CanBeNull = true)]
        public decimal? UpLimitAmount { get; set; }

        /// <summary>
        /// 自付比例
        /// </summary>
        [IrisColumn(Name = "SelfPayProp", Desc = "自付比例", DbType = "Decimal(18,2)", SqlFieldName = "SelfPayProp", Order = 18, CanBeNull = true)]
        public decimal? SelfPayProp { get; set; }

        /// <summary>
        /// 全自费金额
        /// </summary>
        [IrisColumn(Name = "FullOwnPayAmount", Desc = "全自费金额", DbType = "Decimal(18,2)", SqlFieldName = "FullOwnPayAmount", Order = 19, CanBeNull = true)]
        public decimal? FullOwnPayAmount { get; set; }

        /// <summary>
        /// 超限价金额
        /// </summary>
        [IrisColumn(Name = "OverLimitAmount", Desc = "超限价金额", DbType = "Decimal(18,2)", SqlFieldName = "OverLimitAmount", Order = 20, CanBeNull = true)]
        public decimal? OverLimitAmount { get; set; }

        /// <summary>
        /// 先行自付金额
        /// </summary>
        [IrisColumn(Name = "PreSelfPayAmount", Desc = "先行自付金额", DbType = "Decimal(18,2)", SqlFieldName = "PreSelfPayAmount", Order = 21, CanBeNull = true)]
        public decimal? PreSelfPayAmount { get; set; }

        /// <summary>
        /// 符合政策范围金额
        /// </summary>
        [IrisColumn(Name = "InScopeAmount", Desc = "符合政策范围金额", DbType = "Decimal(18,2)", SqlFieldName = "InScopeAmount", Order = 22, CanBeNull = true)]
        public decimal? InScopeAmount { get; set; }

        /// <summary>
        /// 收费项目等级
        /// </summary>
        [IrisColumn(Name = "ChargeItemLevel", Desc = "收费项目等级", DbType = "VarChar(50)", SqlFieldName = "ChargeItemLevel", Order = 23, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "收费项目等级长度不能超过50个字符")]
        public string ChargeItemLevel { get; set; }

        /// <summary>
        /// 医疗收费项目类别
        /// </summary>
        [IrisColumn(Name = "MedicalChargeItemType", Desc = "医疗收费项目类别", DbType = "VarChar(50)", SqlFieldName = "MedicalChargeItemType", Order = 24, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "医疗收费项目类别长度不能超过50个字符")]
        public string MedicalChargeItemType { get; set; }

        /// <summary>
        /// 开单科室编码
        /// </summary>
        [IrisColumn(Name = "BillingDepartmentCode", Desc = "开单科室编码", DbType = "VarChar(50)", SqlFieldName = "BillingDepartmentCode", Order = 25, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "开单科室编码长度不能超过50个字符")]
        public string BillingDepartmentCode { get; set; }

        /// <summary>
        /// 开单科室名称
        /// </summary>
        [IrisColumn(Name = "BillingDepartmentName", Desc = "开单科室名称", DbType = "VarChar(100)", SqlFieldName = "BillingDepartmentName", Order = 26, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "开单科室名称长度不能超过100个字符")]
        public string BillingDepartmentName { get; set; }

        /// <summary>
        /// 开单医生编码
        /// </summary>
        [IrisColumn(Name = "BillingDoctorNO", Desc = "开单医生编码", DbType = "VarChar(50)", SqlFieldName = "BillingDoctorNO", Order = 27, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "开单医生编码长度不能超过50个字符")]
        public string BillingDoctorNO { get; set; }

        /// <summary>
        /// 开单医师姓名
        /// </summary>
        [IrisColumn(Name = "BillingDoctorName", Desc = "开单医师姓名", DbType = "VarChar(100)", SqlFieldName = "BillingDoctorName", Order = 28, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "开单医师姓名长度不能超过100个字符")]
        public string BillingDoctorName { get; set; }

        /// <summary>
        /// 受单科室编码
        /// </summary>
        [IrisColumn(Name = "AcceptDepartmentCode", Desc = "受单科室编码", DbType = "VarChar(50)", SqlFieldName = "AcceptDepartmentCode", Order = 29, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "受单科室编码长度不能超过50个字符")]
        public string AcceptDepartmentCode { get; set; }

        /// <summary>
        /// 受单科室名称
        /// </summary>
        [IrisColumn(Name = "AcceptDepartmentName", Desc = "受单科室名称", DbType = "VarChar(100)", SqlFieldName = "AcceptDepartmentName", Order = 30, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "受单科室名称长度不能超过100个字符")]
        public string AcceptDepartmentName { get; set; }

        /// <summary>
        /// 受单医生编码
        /// </summary>
        [IrisColumn(Name = "AcceptDoctorCode", Desc = "受单医生编码", DbType = "VarChar(50)", SqlFieldName = "AcceptDoctorCode", Order = 31, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "受单医生编码长度不能超过50个字符")]
        public string AcceptDoctorCode { get; set; }

        /// <summary>
        /// 受单医生姓名
        /// </summary>
        [IrisColumn(Name = "AcceptDoctorName", Desc = "受单医生姓名", DbType = "VarChar(100)", SqlFieldName = "AcceptDoctorName", Order = 32, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "受单医生姓名长度不能超过100个字符")]
        public string AcceptDoctorName { get; set; }

        /// <summary>
        /// 医院审批标志
        /// </summary>
        [IrisColumn(Name = "HospitalApprovalFlag", Desc = "医院审批标志", DbType = "VarChar(50)", SqlFieldName = "HospitalApprovalFlag", Order = 33, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "医院审批标志长度不能超过50个字符")]
        public string HospitalApprovalFlag { get; set; }

        /// <summary>
        /// 中药使用方式
        /// </summary>
        [IrisColumn(Name = "ChineseMedicineUsingway", Desc = "中药使用方式", DbType = "VarChar(50)", SqlFieldName = "ChineseMedicineUsingway", Order = 34, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "中药使用方式长度不能超过50个字符")]
        public string ChineseMedicineUsingway { get; set; }

        /// <summary>
        /// 外检标志
        /// </summary>
        [IrisColumn(Name = "ExternalInspectionFlag", Desc = "外检标志", DbType = "VarChar(50)", SqlFieldName = "ExternalInspectionFlag", Order = 35, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "外检标志长度不能超过50个字符")]
        public string ExternalInspectionFlag { get; set; }

        /// <summary>
        /// 外检医院编码
        /// </summary>
        [IrisColumn(Name = "ExternalInspectionHospCode", Desc = "外检医院编码", DbType = "VarChar(50)", SqlFieldName = "ExternalInspectionHospCode", Order = 36, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "外检医院编码长度不能超过50个字符")]
        public string ExternalInspectionHospCode { get; set; }

        /// <summary>
        /// 出院带药标志
        /// </summary>
        [IrisColumn(Name = "DischargeTakeDrugFlag", Desc = "出院带药标志", DbType = "VarChar(50)", SqlFieldName = "DischargeTakeDrugFlag", Order = 37, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "出院带药标志长度不能超过50个字符")]
        public string DischargeTakeDrugFlag { get; set; }

        /// <summary>
        /// 生育费用标志
        /// </summary>
        [IrisColumn(Name = "MaternityFlag", Desc = "生育费用标志", DbType = "VarChar(50)", SqlFieldName = "MaternityFlag", Order = 38, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "生育费用标志长度不能超过50个字符")]
        public string MaternityFlag { get; set; }

        /// <summary>
        /// 限制使用标志
        /// </summary>
        [IrisColumn(Name = "LimitUsedFlag", Desc = "限制使用标志", DbType = "VarChar(50)", SqlFieldName = "LimitUsedFlag", Order = 39, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "限制使用标志长度不能超过50个字符")]
        public string LimitUsedFlag { get; set; }

        /// <summary>
        /// 备注
        /// </summary>
        [IrisColumn(Name = "Memo", Desc = "备注", DbType = "VarChar(300)", SqlFieldName = "Memo", Order = 40, CanBeNull = true)]
        [StringLength(300, ErrorMessage = "备注长度不能超过300个字符")]
        public string Memo { get; set; }

        /// <summary>
        /// 组套编号
        /// </summary>
        [IrisColumn(Name = "ComponentNO", Desc = "组套编号", DbType = "VarChar(50)", SqlFieldName = "ComponentNO", Order = 41, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "组套编号长度不能超过50个字符")]
        public string ComponentNO { get; set; }

        /// <summary>
        /// 字段扩展
        /// </summary>
        [IrisColumn(Name = "ExtendContent", Desc = "字段扩展", DbType = "VarChar(50)", SqlFieldName = "ExtendContent", Order = 42, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "字段扩展长度不能超过50个字符")]
        public string ExtendContent { get; set; }

        /// <summary>
        /// 账单ID
        /// </summary>
        [IrisColumn(Name = "BillID", Desc = "账单ID", DbType = "Int", SqlFieldName = "BillID", Order = 43, CanBeNull = true)]
        public int? BillID { get; set; }

        /// <summary>
        /// 有效标志 0 无效  1 有效
        /// </summary>
        [IrisColumn(Name = "ValidFlag", Desc = "有效标志", DbType = "Int", SqlFieldName = "ValidFlag", Order = 44, CanBeNull = false)]
        [Required(ErrorMessage = "有效标志不能为空")]
        public int ValidFlag { get; set; } = 1;

        /// <summary>
        /// 付款记录ID
        /// </summary>
        [IrisColumn(Name = "RecordID", Desc = "付款记录ID", DbType = "Int", SqlFieldName = "RecordID", Order = 45, CanBeNull = true)]
        public int? RecordID { get; set; }
    }
}
