﻿using PTMIBase.Extensions.Attributes;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;

namespace PTMIBase.Entity.MIDatatable
{
    class FilingRegistRecord
    {
        /// <summary>
        /// 医院编号 指向医院表
        /// </summary>
        [IrisColumn(Name = "HospitalDr", Desc = "医院编号", DbType = "Int", SqlFieldName = "Hospital_Dr", Order = 2, CanBeNull = false)]
        [Required(ErrorMessage = "医院编号不能为空")]
        public int HospitalDr { get; set; }

        /// <summary>
        /// 接口编号 指向接口表
        /// </summary>
        [IrisColumn(Name = "InterfaceDr", Desc = "接口编号", DbType = "Int", SqlFieldName = "Interface_Dr", Order = 3, CanBeNull = false)]
        [Required(ErrorMessage = "接口编号不能为空")]
        public int InterfaceDr { get; set; }

        /// <summary>
        /// 患者医院ID
        /// </summary>
        [IrisColumn(Name = "AdmDr", Desc = "患者医院ID", DbType = "Varchar(50)", SqlFieldName = "Adm_Dr", Order = 4, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "患者医院ID长度不能超过50个字符")]
        public string AdmDr { get; set; }

        /// <summary>
        /// 患者姓名
        /// </summary>
        [IrisColumn(Name = "PatientName", Desc = "患者姓名", DbType = "Varchar(50)", SqlFieldName = "PatientName", Order = 5, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "患者姓名长度不能超过50个字符")]
        public string PatientName { get; set; }

        /// <summary>
        /// 患者医保编号
        /// </summary>
        [IrisColumn(Name = "PersonalNO", Desc = "患者医保编号", DbType = "Varchar(50)", SqlFieldName = "PersonalNO", Order = 6, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "患者医保编号长度不能超过50个字符")]
        public string PersonalNO { get; set; }

        /// <summary>
        /// 业务代码
        /// </summary>
        [IrisColumn(Name = "BusinessCode", Desc = "业务代码", DbType = "Varchar(50)", SqlFieldName = "BusinessCode", Order = 7, CanBeNull = false)]
        [Required(ErrorMessage = "业务代码不能为空")]
        [StringLength(50, ErrorMessage = "业务代码长度不能超过50个字符")]
        public string BusinessCode { get; set; }

        /// <summary>
        /// 业务描述
        /// </summary>
        [IrisColumn(Name = "BusinessDescription", Desc = "业务描述", DbType = "Varchar(50)", SqlFieldName = "BusinessDescription", Order = 8, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "业务描述长度不能超过50个字符")]
        public string BusinessDescription { get; set; }

        /// <summary>
        /// 登记发生时间
        /// </summary>
        [IrisColumn(Name = "OccurTime", Desc = "登记发生时间", DbType = "DateTime", SqlFieldName = "OccurTime", Order = 9, CanBeNull = false)]
        [Required(ErrorMessage = "登记发生时间不能为空")]
        public DateTime OccurTime { get; set; }

        /// <summary>
        /// 登记起始时间
        /// </summary>
        [IrisColumn(Name = "StartTime", Desc = "登记起始时间", DbType = "DateTime", SqlFieldName = "StartTime", Order = 10, CanBeNull = true)]
        public DateTime? StartTime { get; set; }

        /// <summary>
        /// 登记截止时间
        /// </summary>
        [IrisColumn(Name = "EndTime", Desc = "登记截止时间", DbType = "DateTime", SqlFieldName = "EndTime", Order = 11, CanBeNull = true)]
        public DateTime? EndTime { get; set; }

        /// <summary>
        /// 经办人ID
        /// </summary>
        [IrisColumn(Name = "OperatorID", Desc = "经办人ID", DbType = "Varchar(50)", SqlFieldName = "OperatorID", Order = 12, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "经办人ID长度不能超过50个字符")]
        public string OperatorID { get; set; }

        /// <summary>
        /// 经办人
        /// </summary>
        [IrisColumn(Name = "OperatorName", Desc = "经办人", DbType = "Varchar(50)", SqlFieldName = "OperatorName", Order = 13, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "经办人长度不能超过50个字符")]
        public string OperatorName { get; set; }

        /// <summary>
        /// 审核人ID
        /// </summary>
        [IrisColumn(Name = "AuditorID", Desc = "审核人ID", DbType = "Varchar(50)", SqlFieldName = "AuditorID", Order = 14, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "审核人ID长度不能超过50个字符")]
        public string AuditorID { get; set; }

        /// <summary>
        /// 审核人
        /// </summary>
        [IrisColumn(Name = "AuditorName", Desc = "审核人", DbType = "Varchar(50)", SqlFieldName = "AuditorName", Order = 15, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "审核人长度不能超过50个字符")]
        public string AuditorName { get; set; }

        /// <summary>
        /// 凭证类型
        /// </summary>
        [IrisColumn(Name = "CertificateType", Desc = "凭证类型", DbType = "Varchar(50)", SqlFieldName = "CertificateType", Order = 16, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "凭证类型长度不能超过50个字符")]
        public string CertificateType { get; set; }

        /// <summary>
        /// 凭证编号
        /// </summary>
        [IrisColumn(Name = "CertificateNO", Desc = "凭证编号", DbType = "Varchar(100)", SqlFieldName = "CertificateNO", Order = 17, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "凭证编号长度不能超过100个字符")]
        public string CertificateNO { get; set; }

        /// <summary>
        /// 申请流水号
        /// </summary>
        [IrisColumn(Name = "ApprovalNO", Desc = "申请流水号", DbType = "Varchar(100)", SqlFieldName = "ApprovalNO", Order = 18, CanBeNull = false)]
        [Required(ErrorMessage = "申请流水号不能为空")]
        [StringLength(100, ErrorMessage = "申请流水号长度不能超过100个字符")]
        public string ApprovalNO { get; set; }

        /// <summary>
        /// 中心返回内容
        /// </summary>
        [IrisColumn(Name = "CenterReturn", Desc = "中心返回内容", DbType = "Varchar(500)", SqlFieldName = "CenterReturn", Order = 19, CanBeNull = true)]
        [StringLength(500, ErrorMessage = "中心返回内容长度不能超过500个字符")]
        public string CenterReturn { get; set; }

        /// <summary>
        /// 有效标志
        /// </summary>
        [IrisColumn(Name = "ValidFlag", Desc = "有效标志", DbType = "Int", SqlFieldName = "ValidFlag", Order = 20, CanBeNull = true)]
        public int? ValidFlag { get; set; }

        /// <summary>
        /// HIS申请入参
        /// </summary>
        [IrisColumn(Name = "ApprovalParam", Desc = "HIS申请入参", DbType = "Varchar(500)", SqlFieldName = "ApprovalParam", Order = 21, CanBeNull = true)]
        [StringLength(500, ErrorMessage = "HIS申请入参长度不能超过500个字符")]
        public string ApprovalParam { get; set; }
    }
}
