﻿using PTMIBase.Extensions.Attributes;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;


namespace PTMIBase.Entity.MIDatatable
{
    class Interface
    {
        /// <summary>
        /// 医院ID 指向医院表
        /// </summary>
        [IrisColumn(Name = "HospitalDr", Desc = "医院ID", DbType = "Int", SqlFieldName = "Hospital_Dr", Order = 2, CanBeNull = false)]
        [Required(ErrorMessage = "医院ID不能为空")]
        public int HospitalDr { get; set; }

        /// <summary>
        /// 接口编号
        /// </summary>
        [IrisColumn(Name = "InterfaceNO", Desc = "接口编号", DbType = "Varchar(50)", SqlFieldName = "InterfaceNO", Order = 3, CanBeNull = false)]
        [Required(ErrorMessage = "接口编号不能为空")]
        [StringLength(50, ErrorMessage = "接口编号长度不能超过50个字符")]
        public string InterfaceNO { get; set; }

        /// <summary>
        /// 接口名称
        /// </summary>
        [IrisColumn(Name = "InterfaceName", Desc = "接口名称", DbType = "Varchar(50)", SqlFieldName = "InterfaceName", Order = 4, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "接口名称长度不能超过50个字符")]
        public string InterfaceName { get; set; }

        /// <summary>
        /// 中心分配给医院编码
        /// </summary>
        [IrisColumn(Name = "HospitalNO", Desc = "中心分配给医院编码", DbType = "Varchar(50)", SqlFieldName = "HospitalNO", Order = 5, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "中心分配给医院编码长度不能超过50个字符")]
        public string HospitalNO { get; set; }

        /// <summary>
        /// 医院等级
        /// </summary>
        [IrisColumn(Name = "HospitalLevel", Desc = "医院等级", DbType = "Varchar(50)", SqlFieldName = "HospitalLevel", Order = 6, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "医院等级长度不能超过50个字符")]
        public string HospitalLevel { get; set; }

        /// <summary>
        /// 中心URL地址
        /// </summary>
        [IrisColumn(Name = "CenterURL", Desc = "中心URL地址", DbType = "Varchar(200)", SqlFieldName = "CenterURL", Order = 7, CanBeNull = true)]
        [StringLength(200, ErrorMessage = "中心URL地址长度不能超过200个字符")]
        public string CenterURL { get; set; }

        /// <summary>
        /// 中心URL地址2
        /// </summary>
        [IrisColumn(Name = "CenterURL2", Desc = "中心URL地址2", DbType = "Varchar(MAX)", SqlFieldName = "CenterURL2", Order = 8, CanBeNull = true)]
        public string CenterURL2 { get; set; }

        /// <summary>
        /// 医保业务DLL名称
        /// </summary>
        [IrisColumn(Name = "DLLName", Desc = "医保业务DLL名称", DbType = "Varchar(50)", SqlFieldName = "DLLName", Order = 9, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "医保业务DLL名称长度不能超过50个字符")]
        public string DLLName { get; set; }

        /// <summary>
        /// 就医地区划
        /// </summary>
        [IrisColumn(Name = "AreaCode", Desc = "就医地区划", DbType = "Varchar(50)", SqlFieldName = "AreaCode", Order = 10, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "就医地区划长度不能超过50个字符")]
        public string AreaCode { get; set; }

        /// <summary>
        /// 使用标志 False 停用 True 使用
        /// </summary>
        [IrisColumn(Name = "UseFlag", Desc = "使用标志", DbType = "Varchar(50)", SqlFieldName = "UseFlag", Order = 11, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "使用标志长度不能超过50个字符")]
        public string UseFlag { get; set; }

        /// <summary>
        /// 医院名称
        /// </summary>
        [IrisColumn(Name = "HospitalName", Desc = "医院名称", DbType = "Varchar(100)", SqlFieldName = "HospitalName", Order = 12, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "医院名称长度不能超过100个字符")]
        public string HospitalName { get; set; }

        /// <summary>
        /// 序号 （根据该序号决定所有接口的优先级）
        /// </summary>
        [IrisColumn(Name = "SerialNO", Desc = "序号", DbType = "Int", SqlFieldName = "SerialNO", Order = 13, CanBeNull = true)]
        public int? SerialNO { get; set; }

        /// <summary>
        /// 医院区域
        /// </summary>
        [IrisColumn(Name = "InsuRegionDr", Desc = "医院区域", DbType = "Int", SqlFieldName = "InsuRegion_Dr", Order = 14, CanBeNull = false)]
        [Required(ErrorMessage = "医院区域不能为空")]
        public int InsuRegionDr { get; set; }

        /// <summary>
        /// 医保区域目录标志
        /// </summary>
        [IrisColumn(Name = "InsuRegionFlag", Desc = "医保区域目录标志", DbType = "Int", SqlFieldName = "InsuRegionFlag", Order = 15, CanBeNull = true)]
        public int? InsuRegionFlag { get; set; }

        /// <summary>
        /// 区域通用目录
        /// </summary>
        [IrisColumn(Name = "InsuCurrencyCataLogue", Desc = "区域通用目录", DbType = "Int", SqlFieldName = "InsuCurrencyCataLogue", Order = 16, CanBeNull = true)]
        public int? InsuCurrencyCataLogue { get; set; }

        /// <summary>
        /// 区域配置
        /// </summary>
        [IrisColumn(Name = "RegionConfig", Desc = "区域配置", DbType = "Varchar(50)", SqlFieldName = "RegionConfig", Order = 17, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "区域配置长度不能超过50个字符")]
        public string RegionConfig { get; set; } = "1|0|0|";

        /// <summary>
        /// 自助机适用标志
        /// </summary>
        [IrisColumn(Name = "SelfServiceFlag", Desc = "自助机适用标志", DbType = "Int", SqlFieldName = "SelfServiceFlag", Order = 18, CanBeNull = true)]
        public int SelfServiceFlag { get; set; } = -1;
    }
}
