﻿using PTMIBase.Extensions.Attributes;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;


namespace PTMIBase.Entity.MIDatatable
{
    class MapRelation:EntityBase
    {
        /// <summary>
        /// 医院ID 指向医院表
        /// 类型：CBHospital, 不允许为空
        /// </summary>
        [IrisColumn(Name = "HospitalDr", Desc = "医院ID", DbType = "VarChar(50)", SqlFieldName = "Hospital_Dr", Order = 2, CanBeNull = false)]
        [Required(ErrorMessage = "医院ID不能为空")]
        [StringLength(50, ErrorMessage = "医院ID长度不能超过50个字符")]
        public string HospitalDr { get; set; }

        /// <summary>
        /// 接口编号 指向接口表
        /// 类型：HBMedInsuInterface, 不允许为空
        /// </summary>
        [IrisColumn(Name = "InterfaceDr", Desc = "接口编号", DbType = "VarChar(50)", SqlFieldName = "Interface_Dr", Order = 3, CanBeNull = false)]
        [Required(ErrorMessage = "接口编号不能为空")]
        [StringLength(50, ErrorMessage = "接口编号长度不能超过50个字符")]
        public string InterfaceDr { get; set; }

        /// <summary>
        /// 收费项ID (保留但暂不启用)
        /// 类型：int, 可为空
        /// </summary>
        [IrisColumn(Name = "ChargeItemDr", Desc = "收费项ID", DbType = "Int", SqlFieldName = "ChargeItemDr", Order = 4, CanBeNull = true)]
        public int? ChargeItemDr { get; set; }

        /// <summary>
        /// HIS编码
        /// 类型：string, 长度：无限制, 大写, 不允许为空
        /// </summary>
        [IrisColumn(Name = "HISCode", Desc = "HIS编码", DbType = "VarChar(MAX)", SqlFieldName = "HISCode", Order = 5, CanBeNull = false)]
        [Required(ErrorMessage = "HIS编码不能为空")]
        public string HISCode { get; set; }

        /// <summary>
        /// HIS名称
        /// 类型：string, 长度：无限制, 可为空
        /// </summary>
        [IrisColumn(Name = "HISName", Desc = "HIS名称", DbType = "VarChar(50)", SqlFieldName = "HISName", Order = 6, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "HIS名称长度不能超过50个字符")]
        public string HISName { get; set; }

        /// <summary>
        /// 医保目录Dr
        /// 类型：HBMedInsuDirectory, 可为空
        /// </summary>
        [IrisColumn(Name = "DirecotryDr", Desc = "医保目录Dr", DbType = "VarChar(50)", SqlFieldName = "Direcotry_Dr", Order = 7, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "医保目录Dr长度不能超过50个字符")]
        public string DiretoryDr { get; set; }

        /// <summary>
        /// 医院目录类型 1药品 2诊疗 3材料 (63收费类别AKA063,70剂型AKA070,229用法BKC229)北京市医保
        /// 类型：string, 大写, 不允许为空
        /// </summary>
        [IrisColumn(Name = "HisType", Desc = "医院目录类型", DbType = "VarChar(10)", SqlFieldName = "HisType", Order = 8, CanBeNull = false)]
        [Required(ErrorMessage = "医院目录类型不能为空")]
        [StringLength(10, ErrorMessage = "医院目录类型长度不能超过10个字符")]
        public string HisType { get; set; }

        /// <summary>
        /// 状态 1.已对照 2.已对照但未上传 3 已对照且已上传
        /// 类型：int, 可为空
        /// </summary>
        [IrisColumn(Name = "State", Desc = "状态", DbType = "Int", SqlFieldName = "State", Order = 9, CanBeNull = true)]
        public int? State { get; set; }

        /// <summary>
        /// 更新时间
        /// 类型：DateTime, 不允许为空
        /// </summary>
        [IrisColumn(Name = "UpdateDate", Desc = "更新时间", DbType = "DateTime", SqlFieldName = "UpdateDate", Order = 10, CanBeNull = false)]
        [Required(ErrorMessage = "更新时间不能为空")]
        public DateTime UpdateDate { get; set; }

        /// <summary>
        /// 医保编码
        /// 类型：string, 长度：无限制, 可为空
        /// </summary>
        [IrisColumn(Name = "InsuCode", Desc = "医保编码", DbType = "VarChar(50)", SqlFieldName = "InsuCode", Order = 11, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "医保编码长度不能超过50个字符")]
        public string InsuCode { get; set; }

        /// <summary>
        /// 医保名称 1药品 2诊疗 3材料
        /// 类型：string, 长度：100, 可为空
        /// </summary>
        [IrisColumn(Name = "InsuName", Desc = "医保名称", DbType = "VarChar(100)", SqlFieldName = "InsuName", Order = 12, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "医保名称长度不能超过100个字符")]
        public string InsuName { get; set; }
    }
}
