﻿using PTMIBase.Extensions.Attributes;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;

namespace PTMIBase.Entity.MIDatatable
{
    class PresCiruElectronicSignature
    {
        /// <summary>
        /// 医院编号 指向医院表
        /// </summary>
        [IrisColumn(Name = "HospitalDr", Desc = "医院编号", DbType = "VarChar(50)", SqlFieldName = "Hospital_Dr", Order = 2, CanBeNull = false)]
        [Required(ErrorMessage = "医院编号不能为空")]
        [StringLength(50, ErrorMessage = "医院编号长度不能超过50个字符")]
        public string HospitalDr { get; set; }

        /// <summary>
        /// 接口编号 指向接口表
        /// </summary>
        [IrisColumn(Name = "InterfaceDr", Desc = "接口编号", DbType = "Int", SqlFieldName = "Interface_Dr", Order = 3, CanBeNull = false)]
        [Required(ErrorMessage = "接口编号不能为空")]
        public int InterfaceDr { get; set; }

        /// <summary>
        /// 就诊ID
        /// </summary>
        [IrisColumn(Name = "MdtrtID", Desc = "就诊ID", DbType = "VarChar(50)", SqlFieldName = "MdtrtID", Order = 4, CanBeNull = false)]
        [Required(ErrorMessage = "就诊ID不能为空")]
        [StringLength(50, ErrorMessage = "就诊ID长度不能超过50个字符")]
        public string MdtrtID { get; set; }

        /// <summary>
        /// 病人ID 指向患者信息表
        /// </summary>
        [IrisColumn(Name = "AdmDr", Desc = "病人ID", DbType = "VarChar(50)", SqlFieldName = "Adm_Dr", Order = 5, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "病人ID长度不能超过50个字符")]
        public string AdmDr { get; set; }

        /// <summary>
        /// 定点机构代码
        /// </summary>
        [IrisColumn(Name = "FixmedinsCode", Desc = "定点机构代码", DbType = "VarChar(50)", SqlFieldName = "FixmedinsCode", Order = 6, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "定点机构代码长度不能超过50个字符")]
        public string FixmedinsCode { get; set; }

        /// <summary>
        /// 定点医疗机构处方编号
        /// </summary>
        [IrisColumn(Name = "HospRxno", Desc = "定点医疗机构处方编号", DbType = "VarChar(50)", SqlFieldName = "HospRxno", Order = 7, CanBeNull = false)]
        [Required(ErrorMessage = "定点医疗机构处方编号不能为空")]
        [StringLength(50, ErrorMessage = "定点医疗机构处方编号长度不能超过50个字符")]
        public string HospRxno { get; set; }

        /// <summary>
        /// 住院/门诊号
        /// </summary>
        [IrisColumn(Name = "IptOtpNo", Desc = "住院/门诊号", DbType = "VarChar(50)", SqlFieldName = "IptOtpNo", Order = 8, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "住院/门诊号长度不能超过50个字符")]
        public string IptOtpNo { get; set; }

        /// <summary>
        /// 原始待签名处方信息
        /// </summary>
        [IrisColumn(Name = "OriginalValue", Desc = "原始待签名处方信息", DbType = "VarChar(MAX)", SqlFieldName = "OriginalValue", Order = 9, CanBeNull = true)]
        public string OriginalValue { get; set; }

        /// <summary>
        /// 原始待签名处方文件
        /// </summary>
        [IrisColumn(Name = "OriginalRxFile", Desc = "原始待签名处方文件", DbType = "VarChar(MAX)", SqlFieldName = "OriginalRxFile", Order = 10, CanBeNull = true)]
        public string OriginalRxFile { get; set; }

        /// <summary>
        /// 扩展字段
        /// </summary>
        [IrisColumn(Name = "Extras", Desc = "扩展字段", DbType = "VarChar(50)", SqlFieldName = "Extras", Order = 11, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "扩展字段长度不能超过50个字符")]
        public string Extras { get; set; }

        /// <summary>
        /// 发生时间
        /// </summary>
        [IrisColumn(Name = "OccurTime", Desc = "发生时间", DbType = "DateTime", SqlFieldName = "OccurTime", Order = 12, CanBeNull = false)]
        [Required(ErrorMessage = "发生时间不能为空")]
        public DateTime OccurTime { get; set; }

        /// <summary>
        /// 处方文件
        /// </summary>
        [IrisColumn(Name = "RxFile", Desc = "处方文件", DbType = "VarChar(MAX)", SqlFieldName = "RxFile", Order = 13, CanBeNull = true)]
        public string RxFile { get; set; }

        /// <summary>
        /// 签名/章摘要值
        /// </summary>
        [IrisColumn(Name = "SignDigest", Desc = "签名/章摘要值", DbType = "VarChar(MAX)", SqlFieldName = "SignDigest", Order = 14, CanBeNull = true)]
        public string SignDigest { get; set; }

        /// <summary>
        /// 有效截止时间
        /// </summary>
        [IrisColumn(Name = "SignCertSn", Desc = "有效截止时间", DbType = "VarChar(50)", SqlFieldName = "SignCertSn", Order = 15, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "有效截止时间长度不能超过50个字符")]
        public string SignCertSn { get; set; }

        /// <summary>
        /// 签名机构证书DN
        /// </summary>
        [IrisColumn(Name = "SignCertDn", Desc = "签名机构证书DN", DbType = "VarChar(MAX)", SqlFieldName = "SignCertDn", Order = 16, CanBeNull = true)]
        public string SignCertDn { get; set; }

        /// <summary>
        /// 操作人
        /// </summary>
        [IrisColumn(Name = "UpdateUserID", Desc = "操作人", DbType = "VarChar(50)", SqlFieldName = "UpdateUserID", Order = 17, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "操作人长度不能超过50个字符")]
        public string UpdateUserID { get; set; }
    }
}
