﻿using PTMIBase.Extensions.Attributes;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;

namespace PTMIBase.Entity.MIDatatable
{
    class PresCiruUploadPreCheck
    {
        /// <summary>
        /// 医院编号 指向医院表
        /// </summary>
        [IrisColumn(Name = "HospitalDr", Desc = "医院编号", DbType = "Int", SqlFieldName = "Hospital_Dr", Order = 2, CanBeNull = false)]
        [Required(ErrorMessage = "医院编号不能为空")]
        public int HospitalDr { get; set; }

        /// <summary>
        /// 接口编号 指向接口表
        /// </summary>
        [IrisColumn(Name = "InterfaceDr", Desc = "接口编号", DbType = "Int", SqlFieldName = "Interface_Dr", Order = 3, CanBeNull = false)]
        [Required(ErrorMessage = "接口编号不能为空")]
        public int InterfaceDr { get; set; }

        /// <summary>
        /// 就诊ID
        /// </summary>
        [IrisColumn(Name = "MdtrtID", Desc = "就诊ID", DbType = "VarChar(50)", SqlFieldName = "MdtrtID", Order = 4, CanBeNull = false)]
        [Required(ErrorMessage = "就诊ID不能为空")]
        [StringLength(50, ErrorMessage = "就诊ID长度不能超过50个字符")]
        public string MdtrtID { get; set; }

        /// <summary>
        /// 病人ID 指向患者信息表
        /// </summary>
        [IrisColumn(Name = "AdmDr", Desc = "病人ID", DbType = "VarChar(50)", SqlFieldName = "Adm_Dr", Order = 5, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "病人ID长度不能超过50个字符")]
        public string AdmDr { get; set; }

        /// <summary>
        /// 定点医疗机构处方编号
        /// </summary>
        [IrisColumn(Name = "HospRxno", Desc = "定点医疗机构处方编号", DbType = "VarChar(50)", SqlFieldName = "HospRxno", Order = 6, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "定点医疗机构处方编号长度不能超过50个字符")]
        public string HospRxno { get; set; }

        /// <summary>
        /// 就诊凭证类型
        /// </summary>
        [IrisColumn(Name = "MdtrtCertType", Desc = "就诊凭证类型", DbType = "VarChar(50)", SqlFieldName = "MdtrtCertType", Order = 7, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "就诊凭证类型长度不能超过50个字符")]
        public string MdtrtCertType { get; set; }

        /// <summary>
        /// 就诊凭证编号
        /// </summary>
        [IrisColumn(Name = "MdtrtCertNo", Desc = "就诊凭证编号", DbType = "VarChar(50)", SqlFieldName = "MdtrtCertNo", Order = 8, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "就诊凭证编号长度不能超过50个字符")]
        public string MdtrtCertNo { get; set; }

        /// <summary>
        /// 参保地编号
        /// </summary>
        [IrisColumn(Name = "InsuPlcNo", Desc = "参保地编号", DbType = "VarChar(50)", SqlFieldName = "InsuPlcNo", Order = 9, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "参保地编号长度不能超过50个字符")]
        public string InsuPlcNo { get; set; }

        /// <summary>
        /// 续方的原处方编号
        /// </summary>
        [IrisColumn(Name = "InitRxno", Desc = "续方的原处方编号", DbType = "VarChar(50)", SqlFieldName = "InitRxno", Order = 10, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "续方的原处方编号长度不能超过50个字符")]
        public string InitRxno { get; set; }

        /// <summary>
        /// 处方类别代码
        /// </summary>
        [IrisColumn(Name = "RxTypeCode", Desc = "处方类别代码", DbType = "VarChar(50)", SqlFieldName = "RxTypeCode", Order = 11, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "处方类别代码长度不能超过50个字符")]
        public string RxTypeCode { get; set; }

        /// <summary>
        /// 开方时间
        /// </summary>
        [IrisColumn(Name = "PrscTime", Desc = "开方时间", DbType = "DateTime", SqlFieldName = "PrscTime", Order = 12, CanBeNull = true)]
        public DateTime? PrscTime { get; set; }

        /// <summary>
        /// 药品类目数（剂数）
        /// </summary>
        [IrisColumn(Name = "RxDrugCnt", Desc = "药品类目数", DbType = "VarChar(50)", SqlFieldName = "RxDrugCnt", Order = 13, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "药品类目数长度不能超过50个字符")]
        public string RxDrugCnt { get; set; }

        /// <summary>
        /// 处方有效天数
        /// </summary>
        [IrisColumn(Name = "ValiDays", Desc = "处方有效天数", DbType = "VarChar(50)", SqlFieldName = "ValiDays", Order = 14, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "处方有效天数长度不能超过50个字符")]
        public string ValiDays { get; set; }

        /// <summary>
        /// 有效截止时间
        /// </summary>
        [IrisColumn(Name = "ValiEndTime", Desc = "有效截止时间", DbType = "DateTime", SqlFieldName = "ValiEndTime", Order = 15, CanBeNull = true)]
        public DateTime? ValiEndTime { get; set; }

        /// <summary>
        /// 住院/门诊号
        /// </summary>
        [IrisColumn(Name = "IptOtpNo", Desc = "住院/门诊号", DbType = "VarChar(50)", SqlFieldName = "IptOtpNo", Order = 16, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "住院/门诊号长度不能超过50个字符")]
        public string IptOtpNo { get; set; }

        /// <summary>
        /// 门诊住院标识
        /// </summary>
        [IrisColumn(Name = "OtpIptFlag", Desc = "门诊住院标识", DbType = "VarChar(50)", SqlFieldName = "OtpIptFlag", Order = 17, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "门诊住院标识长度不能超过50个字符")]
        public string OtpIptFlag { get; set; }

        /// <summary>
        /// 医保人员编号
        /// </summary>
        [IrisColumn(Name = "PsnNo", Desc = "医保人员编号", DbType = "VarChar(50)", SqlFieldName = "PsnNo", Order = 18, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "医保人员编号长度不能超过50个字符")]
        public string PsnNo { get; set; }

        /// <summary>
        /// 患者姓名
        /// </summary>
        [IrisColumn(Name = "PatnName", Desc = "患者姓名", DbType = "VarChar(100)", SqlFieldName = "PatnName", Order = 19, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "患者姓名长度不能超过100个字符")]
        public string PatnName { get; set; }

        /// <summary>
        /// 人员证件类型
        /// </summary>
        [IrisColumn(Name = "PsnCertType", Desc = "人员证件类型", DbType = "VarChar(50)", SqlFieldName = "PsnCertType", Order = 20, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "人员证件类型长度不能超过50个字符")]
        public string PsnCertType { get; set; }

        /// <summary>
        /// 证件号码
        /// </summary>
        [IrisColumn(Name = "Certno", Desc = "证件号码", DbType = "VarChar(50)", SqlFieldName = "Certno", Order = 21, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "证件号码长度不能超过50个字符")]
        public string Certno { get; set; }

        /// <summary>
        /// 年龄
        /// </summary>
        [IrisColumn(Name = "PatnAge", Desc = "年龄", DbType = "VarChar(50)", SqlFieldName = "PatnAge", Order = 22, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "年龄长度不能超过50个字符")]
        public string PatnAge { get; set; }

        /// <summary>
        /// 性别
        /// </summary>
        [IrisColumn(Name = "Gend", Desc = "性别", DbType = "VarChar(50)", SqlFieldName = "Gend", Order = 23, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "性别长度不能超过50个字符")]
        public string Gend { get; set; }

        /// <summary>
        /// 开方科室名称
        /// </summary>
        [IrisColumn(Name = "PrscDeptName", Desc = "开方科室名称", DbType = "VarChar(100)", SqlFieldName = "PrscDeptName", Order = 24, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "开方科室名称长度不能超过100个字符")]
        public string PrscDeptName { get; set; }

        /// <summary>
        /// 开方科室编号
        /// </summary>
        [IrisColumn(Name = "PrscDeptCode", Desc = "开方科室编号", DbType = "VarChar(50)", SqlFieldName = "PrscDeptCode", Order = 25, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "开方科室编号长度不能超过50个字符")]
        public string PrscDeptCode { get; set; }

        /// <summary>
        /// 开方医保医师代码
        /// </summary>
        [IrisColumn(Name = "DrCode", Desc = "开方医保医师代码", DbType = "VarChar(50)", SqlFieldName = "DrCode", Order = 26, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "开方医保医师代码长度不能超过50个字符")]
        public string DrCode { get; set; }

        /// <summary>
        /// 开方医师姓名
        /// </summary>
        [IrisColumn(Name = "PrscDrName", Desc = "开方医师姓名", DbType = "VarChar(100)", SqlFieldName = "PrscDrName", Order = 27, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "开方医师姓名长度不能超过100个字符")]
        public string PrscDrName { get; set; }

        /// <summary>
        /// 医生职称编码
        /// </summary>
        [IrisColumn(Name = "DrProfttlCodg", Desc = "医生职称编码", DbType = "VarChar(50)", SqlFieldName = "DrProfttlCodg", Order = 28, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "医生职称编码长度不能超过50个字符")]
        public string DrProfttlCodg { get; set; }

        /// <summary>
        /// 医生职称名称
        /// </summary>
        [IrisColumn(Name = "DrProfttlName", Desc = "医生职称名称", DbType = "VarChar(100)", SqlFieldName = "DrProfttlName", Order = 29, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "医生职称名称长度不能超过100个字符")]
        public string DrProfttlName { get; set; }

        /// <summary>
        /// 就诊时间
        /// </summary>
        [IrisColumn(Name = "MdtrtTime", Desc = "就诊时间", DbType = "DateTime", SqlFieldName = "MdtrtTime", Order = 30, CanBeNull = true)]
        public DateTime? MdtrtTime { get; set; }

        /// <summary>
        /// 病种编码
        /// </summary>
        [IrisColumn(Name = "DiseCodg", Desc = "病种编码", DbType = "VarChar(50)", SqlFieldName = "DiseCodg", Order = 31, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "病种编码长度不能超过50个字符")]
        public string DiseCodg { get; set; }

        /// <summary>
        /// 病种名称
        /// </summary>
        [IrisColumn(Name = "DiseName", Desc = "病种名称", DbType = "VarChar(100)", SqlFieldName = "DiseName", Order = 32, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "病种名称长度不能超过100个字符")]
        public string DiseName { get; set; }

        /// <summary>
        /// 特殊病种标志
        /// </summary>
        [IrisColumn(Name = "SpDiseFlag", Desc = "特殊病种标志", DbType = "VarChar(50)", SqlFieldName = "SpDiseFlag", Order = 33, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "特殊病种标志长度不能超过50个字符")]
        public string SpDiseFlag { get; set; }

        /// <summary>
        /// 主诊断代码
        /// </summary>
        [IrisColumn(Name = "MaindiagCode", Desc = "主诊断代码", DbType = "VarChar(50)", SqlFieldName = "MaindiagCode", Order = 34, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "主诊断代码长度不能超过50个字符")]
        public string MaindiagCode { get; set; }

        /// <summary>
        /// 主诊断名称
        /// </summary>
        [IrisColumn(Name = "MaindiagName", Desc = "主诊断名称", DbType = "VarChar(100)", SqlFieldName = "MaindiagName", Order = 35, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "主诊断名称长度不能超过100个字符")]
        public string MaindiagName { get; set; }

        /// <summary>
        /// 发生时间
        /// </summary>
        [IrisColumn(Name = "OccurTime", Desc = "发生时间", DbType = "DateTime", SqlFieldName = "OccurTime", Order = 36, CanBeNull = false)]
        [Required(ErrorMessage = "发生时间不能为空")]
        public DateTime OccurTime { get; set; }

        /// <summary>
        /// 处方追溯码
        /// </summary>
        [IrisColumn(Name = "RxTraceCode", Desc = "处方追溯码", DbType = "VarChar(50)", SqlFieldName = "RxTraceCode", Order = 37, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "处方追溯码长度不能超过50个字符")]
        public string RxTraceCode { get; set; }

        /// <summary>
        /// 医保处方编号
        /// </summary>
        [IrisColumn(Name = "HiRxno", Desc = "医保处方编号", DbType = "VarChar(50)", SqlFieldName = "HiRxno", Order = 38, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "医保处方编号长度不能超过50个字符")]
        public string HiRxno { get; set; }

        /// <summary>
        /// 操作人
        /// </summary>
        [IrisColumn(Name = "UpdateUserID", Desc = "操作人", DbType = "VarChar(50)", SqlFieldName = "UpdateUserID", Order = 39, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "操作人长度不能超过50个字符")]
        public string UpdateUserID { get; set; }

        /// <summary>
        /// 医疗类型
        /// </summary>
        [IrisColumn(Name = "MedType", Desc = "医疗类型", DbType = "VarChar(50)", SqlFieldName = "MedType", Order = 40, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "医疗类型长度不能超过50个字符")]
        public string MedType { get; set; }

        /// <summary>
        /// 审方药师医保代码
        /// </summary>
        [IrisColumn(Name = "PharCode", Desc = "审方药师医保代码", DbType = "VarChar(50)", SqlFieldName = "PharCode", Order = 41, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "审方药师医保代码长度不能超过50个字符")]
        public string PharCode { get; set; }

        /// <summary>
        /// 审方药师姓名
        /// </summary>
        [IrisColumn(Name = "PharName", Desc = "审方药师姓名", DbType = "VarChar(100)", SqlFieldName = "PharName", Order = 42, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "审方药师姓名长度不能超过100个字符")]
        public string PharName { get; set; }

        /// <summary>
        /// 审方时间
        /// </summary>
        [IrisColumn(Name = "PharChkTime", Desc = "审方时间", DbType = "VarChar(50)", SqlFieldName = "PharChkTime", Order = 43, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "审方时间长度不能超过50个字符")]
        public string PharChkTime { get; set; }

        /// <summary>
        /// 审方药师科室编码
        /// </summary>
        [IrisColumn(Name = "PharDeptCode", Desc = "审方药师科室编码", DbType = "VarChar(50)", SqlFieldName = "PharDeptCode", Order = 44, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "审方药师科室编码长度不能超过50个字符")]
        public string PharDeptCode { get; set; }

        /// <summary>
        /// 审方药师科室名称
        /// </summary>
        [IrisColumn(Name = "PharDeptName", Desc = "审方药师科室名称", DbType = "VarChar(100)", SqlFieldName = "PharDeptName", Order = 45, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "审方药师科室名称长度不能超过100个字符")]
        public string PharDeptName { get; set; }
    }
}
