﻿using PTMIBase.Extensions.Attributes;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;

namespace PTMIBase.Entity.MIDatatable
{
    class PresCiruUploadRecord
    {
        /// <summary>
        /// 医院编号 指向医院表
        /// </summary>
        [IrisColumn(Name = "HospitalDr", Desc = "医院编号", DbType = "Int", SqlFieldName = "Hospital_Dr", Order = 2, CanBeNull = false)]
        [Required(ErrorMessage = "医院编号不能为空")]
        public int HospitalDr { get; set; }

        /// <summary>
        /// 接口编号 指向接口表
        /// </summary>
        [IrisColumn(Name = "InterfaceDr", Desc = "接口编号", DbType = "Int", SqlFieldName = "Interface_Dr", Order = 3, CanBeNull = false)]
        [Required(ErrorMessage = "接口编号不能为空")]
        public int InterfaceDr { get; set; }

        /// <summary>
        /// 就诊ID
        /// </summary>
        [IrisColumn(Name = "MdtrtID", Desc = "就诊ID", DbType = "VarChar(50)", SqlFieldName = "MdtrtID", Order = 4, CanBeNull = false)]
        [Required(ErrorMessage = "就诊ID不能为空")]
        [StringLength(50, ErrorMessage = "就诊ID长度不能超过50个字符")]
        public string MdtrtID { get; set; }

        /// <summary>
        /// 病人ID 指向患者信息表
        /// </summary>
        [IrisColumn(Name = "AdmDr", Desc = "病人ID", DbType = "VarChar(50)", SqlFieldName = "Adm_Dr", Order = 5, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "病人ID长度不能超过50个字符")]
        public string AdmDr { get; set; }

        /// <summary>
        /// 医保处方编号
        /// </summary>
        [IrisColumn(Name = "HiRxno", Desc = "医保处方编号", DbType = "VarChar(50)", SqlFieldName = "HiRxno", Order = 6, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "医保处方编号长度不能超过50个字符")]
        public string HiRxno { get; set; }

        /// <summary>
        /// 处方追溯码
        /// </summary>
        [IrisColumn(Name = "RxTraceCode", Desc = "处方追溯码", DbType = "VarChar(50)", SqlFieldName = "RxTraceCode", Order = 7, CanBeNull = false)]
        [Required(ErrorMessage = "处方追溯码不能为空")]
        [StringLength(50, ErrorMessage = "处方追溯码长度不能超过50个字符")]
        public string RxTraceCode { get; set; }

        /// <summary>
        /// 患者姓名
        /// </summary>
        [IrisColumn(Name = "PatnName", Desc = "患者姓名", DbType = "VarChar(100)", SqlFieldName = "PatnName", Order = 8, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "患者姓名长度不能超过100个字符")]
        public string PatnName { get; set; }

        /// <summary>
        /// 人员证件类型
        /// </summary>
        [IrisColumn(Name = "PsnCertType", Desc = "人员证件类型", DbType = "VarChar(50)", SqlFieldName = "PsnCertType", Order = 9, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "人员证件类型长度不能超过50个字符")]
        public string PsnCertType { get; set; }

        /// <summary>
        /// 证件号码
        /// </summary>
        [IrisColumn(Name = "Certno", Desc = "证件号码", DbType = "VarChar(50)", SqlFieldName = "Certno", Order = 10, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "证件号码长度不能超过50个字符")]
        public string Certno { get; set; }

        /// <summary>
        /// 定点医疗机构名称
        /// </summary>
        [IrisColumn(Name = "FixmedinsName", Desc = "定点医疗机构名称", DbType = "VarChar(100)", SqlFieldName = "FixmedinsName", Order = 11, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "定点医疗机构名称长度不能超过100个字符")]
        public string FixmedinsName { get; set; }

        /// <summary>
        /// 定点医疗机构编号
        /// </summary>
        [IrisColumn(Name = "FixmedinsCode", Desc = "定点医疗机构编号", DbType = "VarChar(50)", SqlFieldName = "FixmedinsCode", Order = 12, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "定点医疗机构编号长度不能超过50个字符")]
        public string FixmedinsCode { get; set; }

        /// <summary>
        /// 开方医保医师代码
        /// </summary>
        [IrisColumn(Name = "DrCode", Desc = "开方医保医师代码", DbType = "VarChar(50)", SqlFieldName = "DrCode", Order = 13, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "开方医保医师代码长度不能超过50个字符")]
        public string DrCode { get; set; }

        /// <summary>
        /// 开方医师姓名
        /// </summary>
        [IrisColumn(Name = "PrscDrName", Desc = "开方医师姓名", DbType = "VarChar(100)", SqlFieldName = "PrscDrName", Order = 14, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "开方医师姓名长度不能超过100个字符")]
        public string PrscDrName { get; set; }

        /// <summary>
        /// 审方药师科室名称
        /// </summary>
        [IrisColumn(Name = "PharDeptName", Desc = "审方药师科室名称", DbType = "VarChar(100)", SqlFieldName = "PharDeptName", Order = 15, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "审方药师科室名称长度不能超过100个字符")]
        public string PharDeptName { get; set; }

        /// <summary>
        /// 审方药师科室编号
        /// </summary>
        [IrisColumn(Name = "PharDeptCode", Desc = "审方药师科室编号", DbType = "VarChar(50)", SqlFieldName = "PharDeptCode", Order = 16, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "审方药师科室编号长度不能超过50个字符")]
        public string PharDeptCode { get; set; }

        /// <summary>
        /// 审方医保药师代码
        /// </summary>
        [IrisColumn(Name = "PharCode", Desc = "审方医保药师代码", DbType = "VarChar(50)", SqlFieldName = "PharCode", Order = 17, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "审方医保药师代码长度不能超过50个字符")]
        public string PharCode { get; set; }

        /// <summary>
        /// 审方药师姓名
        /// </summary>
        [IrisColumn(Name = "PharName", Desc = "审方药师姓名", DbType = "VarChar(100)", SqlFieldName = "PharName", Order = 18, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "审方药师姓名长度不能超过100个字符")]
        public string PharName { get; set; }

        /// <summary>
        /// 医疗机构药师审方时间
        /// </summary>
        [IrisColumn(Name = "PharChkTime", Desc = "医疗机构药师审方时间", DbType = "DateTime", SqlFieldName = "PharChkTime", Order = 19, CanBeNull = true)]
        public DateTime? PharChkTime { get; set; }

        /// <summary>
        /// 发生时间
        /// </summary>
        [IrisColumn(Name = "OccurTime", Desc = "发生时间", DbType = "DateTime", SqlFieldName = "OccurTime", Order = 20, CanBeNull = false)]
        [Required(ErrorMessage = "发生时间不能为空")]
        public DateTime OccurTime { get; set; }

        /// <summary>
        /// 处方原件
        /// </summary>
        [IrisColumn(Name = "RxFile", Desc = "处方原件", DbType = "Text", SqlFieldName = "RxFile", Order = 21, CanBeNull = true)]
        public string RxFile { get; set; }

        /// <summary>
        /// 处方信息签名值
        /// </summary>
        [IrisColumn(Name = "SignDigest", Desc = "处方信息签名值", DbType = "VarChar(MAX)", SqlFieldName = "SignDigest", Order = 22, CanBeNull = true)]
        [StringLength(int.MaxValue, ErrorMessage = "处方信息签名值长度超出限制")]
        public string SignDigest { get; set; }

        /// <summary>
        /// 扩展字段
        /// </summary>
        [IrisColumn(Name = "Extras", Desc = "扩展字段", DbType = "VarChar(MAX)", SqlFieldName = "Extras", Order = 23, CanBeNull = true)]
        [StringLength(int.MaxValue, ErrorMessage = "扩展字段长度超出限制")]
        public string Extras { get; set; }

        /// <summary>
        /// 医保处方状态编码 1有效 2已失效 3已撤销
        /// </summary>
        [IrisColumn(Name = "RxStasCodg", Desc = "医保处方状态编码", DbType = "VarChar(50)", SqlFieldName = "RxStasCodg", Order = 24, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "医保处方状态编码长度不能超过50个字符")]
        public string RxStasCodg { get; set; }

        /// <summary>
        /// 医保处方状态名称
        /// </summary>
        [IrisColumn(Name = "RxStasName", Desc = "医保处方状态名称", DbType = "VarChar(100)", SqlFieldName = "RxStasName", Order = 25, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "医保处方状态名称长度不能超过100个字符")]
        public string RxStasName { get; set; }

        /// <summary>
        /// 是否上传 N否Y是
        /// </summary>
        [IrisColumn(Name = "Upload", Desc = "是否上传", DbType = "VarChar(1)", SqlFieldName = "Upload", Order = 26, CanBeNull = true)]
        [StringLength(1, ErrorMessage = "是否上传长度不能超过1个字符")]
        public string Upload { get; set; }

        /// <summary>
        /// 操作人
        /// </summary>
        [IrisColumn(Name = "UpdateUserID", Desc = "操作人", DbType = "VarChar(50)", SqlFieldName = "UpdateUserID", Order = 27, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "操作人长度不能超过50个字符")]
        public string UpdateUserID { get; set; }

        /// <summary>
        /// 撤销医师的医保医师代码
        /// </summary>
        [IrisColumn(Name = "UndoDrCode", Desc = "撤销医师的医保医师代码", DbType = "VarChar(50)", SqlFieldName = "UndrCode", Order = 28, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "撤销医师的医保医师代码长度不能超过50个字符")]
        public string UndoDrCode { get; set; }

        /// <summary>
        /// 撤销医师姓名
        /// </summary>
        [IrisColumn(Name = "UndoDrName", Desc = "撤销医师姓名", DbType = "VarChar(100)", SqlFieldName = "UndoDrName", Order = 29, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "撤销医师姓名长度不能超过100个字符")]
        public string UndoDrName { get; set; }

        /// <summary>
        /// 撤销医师证件类型
        /// </summary>
        [IrisColumn(Name = "UndoDrCertType", Desc = "撤销医师证件类型", DbType = "VarChar(50)", SqlFieldName = "UndoDrCertType", Order = 30, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "撤销医师证件类型长度不能超过50个字符")]
        public string UndoDrCertType { get; set; }

        /// <summary>
        /// 撤销医师证件号码
        /// </summary>
        [IrisColumn(Name = "UndoDrCertno", Desc = "撤销医师证件号码", DbType = "VarChar(50)", SqlFieldName = "UndoDrCertno", Order = 31, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "撤销医师证件号码长度不能超过50个字符")]
        public string UndoDrCertno { get; set; }

        /// <summary>
        /// 撤销原因描述
        /// </summary>
        [IrisColumn(Name = "UndoRea", Desc = "撤销原因描述", DbType = "VarChar(500)", SqlFieldName = "UndoRea", Order = 32, CanBeNull = true)]
        [StringLength(500, ErrorMessage = "撤销原因描述长度不能超过500个字符")]
        public string UndoRea { get; set; }

        /// <summary>
        /// 撤销时间
        /// </summary>
        [IrisColumn(Name = "UndoTime", Desc = "撤销时间", DbType = "VarChar(50)", SqlFieldName = "UndoTime", Order = 33, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "撤销时间长度不能超过50个字符")]
        public string UndoTime { get; set; }

        /// <summary>
        /// 处方审核状态代码
        /// </summary>
        [IrisColumn(Name = "RxChkStasCodg", Desc = "处方审核状态代码", DbType = "VarChar(50)", SqlFieldName = "RxChkStasCodg", Order = 34, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "处方审核状态代码长度不能超过50个字符")]
        public string RxChkStasCodg { get; set; }

        /// <summary>
        /// 处方审核意见
        /// </summary>
        [IrisColumn(Name = "RxChkOpnn", Desc = "处方审核意见", DbType = "VarChar(500)", SqlFieldName = "RxChkOpnn", Order = 35, CanBeNull = true)]
        [StringLength(500, ErrorMessage = "处方审核意见长度不能超过500个字符")]
        public string RxChkOpnn { get; set; }

        /// <summary>
        /// 处方审核时间
        /// </summary>
        [IrisColumn(Name = "RxChkTime", Desc = "处方审核时间", DbType = "VarChar(50)", SqlFieldName = "RxChkTime", Order = 36, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "处方审核时间长度不能超过50个字符")]
        public string RxChkTime { get; set; }

        /// <summary>
        /// 处方审核状态名称
        /// </summary>
        [IrisColumn(Name = "RxChkStasName", Desc = "处方审核状态名称", DbType = "VarChar(100)", SqlFieldName = "RxChkStasName", Order = 37, CanBeNull = true)]
        [StringLength(100, ErrorMessage = "处方审核状态名称长度不能超过100个字符")]
        public string RxChkStasName { get; set; }

        /// <summary>
        /// 定点医疗机构处方编号
        /// </summary>
        [IrisColumn(Name = "HospRxno", Desc = "定点医疗机构处方编号", DbType = "VarChar(50)", SqlFieldName = "HospRxno", Order = 38, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "定点医疗机构处方编号长度不能超过50个字符")]
        public string HospRxno { get; set; }
    }
}
