﻿using PTMIBase.Extensions.Attributes;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;

namespace PTMIBase.Entity.MIDatatable
{
    class RegisterInfo
    {
        /// <summary>
        /// 医院编号 指向医院表
        /// 类型：CBHospital, 不允许为空
        /// </summary>
        [IrisColumn(Name = "HospitalDr", Desc = "医院编号", DbType = "VarChar(50)", SqlFieldName = "Hospital_Dr", Order = 2, CanBeNull = false)]
        [Required(ErrorMessage = "医院编号不能为空")]
        [StringLength(50, ErrorMessage = "医院编号长度不能超过50个字符")]
        public string HospitalDr { get; set; }

        /// <summary>
        /// 接口编号 指向接口表
        /// 类型：HBMedInsuInterface, 不允许为空
        /// </summary>
        [IrisColumn(Name = "InterfaceDr", Desc = "接口编号", DbType = "VarChar(50)", SqlFieldName = "Interface_Dr", Order = 3, CanBeNull = false)]
        [Required(ErrorMessage = "接口编号不能为空")]
        [StringLength(50, ErrorMessage = "接口编号长度不能超过50个字符")]
        public string InterfaceDr { get; set; }

        /// <summary>
        /// 患者医院ID 
        /// 类型：string, 不允许为空
        /// </summary>
        [IrisColumn(Name = "AdmDr", Desc = "患者医院ID", DbType = "VarChar(50)", SqlFieldName = "Adm_Dr", Order = 4, CanBeNull = false)]
        [Required(ErrorMessage = "患者医院ID不能为空")]
        [StringLength(50, ErrorMessage = "患者医院ID长度不能超过50个字符")]
        public string AdmDr { get; set; }

        /// <summary>
        /// 患者姓名
        /// 类型：string, 不允许为空
        /// </summary>
        [IrisColumn(Name = "PatientName", Desc = "患者姓名", DbType = "VarChar(50)", SqlFieldName = "PatientName", Order = 5, CanBeNull = false)]
        [Required(ErrorMessage = "患者姓名不能为空")]
        [StringLength(50, ErrorMessage = "患者姓名长度不能超过50个字符")]
        public string PatientName { get; set; }

        /// <summary>
        /// 患者医保编号
        /// 类型：string, 不允许为空
        /// </summary>
        [IrisColumn(Name = "PersonalNO", Desc = "患者医保编号", DbType = "VarChar(50)", SqlFieldName = "PersonalNO", Order = 6, CanBeNull = false)]
        [Required(ErrorMessage = "患者医保编号不能为空")]
        [StringLength(50, ErrorMessage = "患者医保编号长度不能超过50个字符")]
        public string PersonalNO { get; set; }

        /// <summary>
        /// 医保登记号
        /// 类型：string, 大写, 最大长度：50, 不允许为空
        /// </summary>
        [IrisColumn(Name = "InsuRegID", Desc = "医保登记号", DbType = "VarChar(50)", SqlFieldName = "InsuRegID", Order = 7, CanBeNull = false)]
        [Required(ErrorMessage = "医保登记号不能为空")]
        [StringLength(50, ErrorMessage = "医保登记号长度不能超过50个字符")]
        public string InsuRegID { get; set; }

        /// <summary>
        /// 医保登记时间
        /// 类型：DateTime, 不允许为空
        /// </summary>
        [IrisColumn(Name = "RegDate", Desc = "医保登记时间", DbType = "DateTime", SqlFieldName = "RegDate", Order = 8, CanBeNull = false)]
        [Required(ErrorMessage = "医保登记时间不能为空")]
        public DateTime RegDate { get; set; }

        /// <summary>
        /// 登记发生时间
        /// 类型：DateTime, 不允许为空
        /// </summary>
        [IrisColumn(Name = "OccurTime", Desc = "登记发生时间", DbType = "DateTime", SqlFieldName = "OccurTime", Order = 9, CanBeNull = false)]
        [Required(ErrorMessage = "登记发生时间不能为空")]
        public DateTime OccurTime { get; set; }

        /// <summary>
        /// 险种类型
        /// 类型：string, 不允许为空
        /// </summary>
        [IrisColumn(Name = "InsuType", Desc = "险种类型", DbType = "VarChar(50)", SqlFieldName = "InsuType", Order = 10, CanBeNull = false)]
        [Required(ErrorMessage = "险种类型不能为空")]
        [StringLength(50, ErrorMessage = "险种类型长度不能超过50个字符")]
        public string InsuType { get; set; }

        // 其他属性按照相同模式继续定义...

        /// <summary>
        /// HIS患者ID
        /// 类型：string, 可为空
        /// </summary>
        [IrisColumn(Name = "patID", Desc = "HIS患者ID", DbType = "VarChar(50)", SqlFieldName = "patId", Order = 40, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "HIS患者ID长度不能超过50个字符")]
        public string patID { get; set; }
    }
}
