﻿using PTMIBase.Extensions.Attributes;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;

namespace PTMIBase.Entity.MIDatatable
{
    class SettlementDetail
    {
        /// <summary>
        /// 医院编号 指向医院表
        /// </summary>
        [IrisColumn(Name = "HospitalDr", Desc = "医院编号", DbType = "Int", SqlFieldName = "Hospital_Dr", Order = 2, CanBeNull = false)]
        [Required(ErrorMessage = "医院编号不能为空")]
        public int HospitalDr { get; set; }

        /// <summary>
        /// 接口编号 指向接口表
        /// </summary>
        [IrisColumn(Name = "InterfaceDr", Desc = "接口编号", DbType = "Int", SqlFieldName = "Interface_Dr", Order = 3, CanBeNull = false)]
        [Required(ErrorMessage = "接口编号不能为空")]
        public int InterfaceDr { get; set; }

        /// <summary>
        /// 病人ID 指向患者信息表
        /// </summary>
        [IrisColumn(Name = "AdmDr", Desc = "病人ID", DbType = "Int", SqlFieldName = "Adm_Dr", Order = 4, CanBeNull = false)]
        [Required(ErrorMessage = "病人ID不能为空")]
        public int AdmDr { get; set; }

        /// <summary>
        /// 就诊ID
        /// </summary>
        [IrisColumn(Name = "MdtrtID", Desc = "就诊ID", DbType = "Varchar(50)", SqlFieldName = "MdtrtID", Order = 5, CanBeNull = false)]
        [Required(ErrorMessage = "就诊ID不能为空")]
        [StringLength(50, ErrorMessage = "就诊ID长度不能超过50个字符")]
        public string MdtrtID { get; set; }

        /// <summary>
        /// 结算ID
        /// </summary>
        [IrisColumn(Name = "SettlementID", Desc = "结算ID", DbType = "Varchar(50)", SqlFieldName = "SettlementID", Order = 6, CanBeNull = false)]
        [Required(ErrorMessage = "结算ID不能为空")]
        [StringLength(50, ErrorMessage = "结算ID长度不能超过50个字符")]
        public string SettlementID { get; set; }

        /// <summary>
        /// 基金支付类型
        /// </summary>
        [IrisColumn(Name = "PayTypeCode", Desc = "基金支付类型", DbType = "Varchar(50)", SqlFieldName = "PayTypeCode", Order = 7, CanBeNull = false)]
        [Required(ErrorMessage = "基金支付类型不能为空")]
        [StringLength(50, ErrorMessage = "基金支付类型长度不能超过50个字符")]
        public string PayTypeCode { get; set; }

        /// <summary>
        /// 基金支付名称
        /// </summary>
        [IrisColumn(Name = "PayTypeName", Desc = "基金支付名称", DbType = "Varchar(50)", SqlFieldName = "PayTypeName", Order = 8, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "基金支付名称长度不能超过50个字符")]
        public string PayTypeName { get; set; }

        /// <summary>
        /// 符合政策范围金额
        /// </summary>
        [IrisColumn(Name = "InScopyAmount", Desc = "符合政策范围金额", DbType = "Float", SqlFieldName = "InScopyAmount", Order = 9, CanBeNull = true)]
        public float? InScopyAmount { get; set; }

        /// <summary>
        /// 本次可支付限额金额
        /// </summary>
        [IrisColumn(Name = "CurrLimtAmount", Desc = "本次可支付限额金额", DbType = "Float", SqlFieldName = "CurrLimtAmount", Order = 10, CanBeNull = true)]
        public float? CurrLimtAmount { get; set; }

        /// <summary>
        /// 基金支付金额
        /// </summary>
        [IrisColumn(Name = "FundPayAmount", Desc = "基金支付金额", DbType = "Float", SqlFieldName = "FundPayAmount", Order = 11, CanBeNull = true)]
        public float? FundPayAmount { get; set; }

        /// <summary>
        /// 结算过程信息
        /// </summary>
        [IrisColumn(Name = "SettlProcInfo", Desc = "结算过程信息", DbType = "Varchar(50)", SqlFieldName = "SettlProcInfo", Order = 12, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "结算过程信息长度不能超过50个字符")]
        public string SettlProcInfo { get; set; }
    }
}
