﻿using PTMIBase.Extensions.Attributes;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;


namespace PTMIBase.Entity.MIDatatable
{
    class SignRecord
    {
        /// <summary>
        /// 医院ID 指向医院表 CB_Hospital
        /// </summary>
        [IrisColumn(Name = "HospitalDr", Desc = "医院ID", DbType = "Int", SqlFieldName = "Hospital_Dr", Order = 2, CanBeNull = false)]
        [Required(ErrorMessage = "医院ID不能为空")]
        public int HospitalDr { get; set; }

        /// <summary>
        /// 接口编号 指向接口表
        /// </summary>
        [IrisColumn(Name = "InterfaceDr", Desc = "接口编号", DbType = "Int", SqlFieldName = "Interface_Dr", Order = 3, CanBeNull = false)]
        [Required(ErrorMessage = "接口编号不能为空")]
        public int InterfaceDr { get; set; }

        /// <summary>
        /// 编号
        /// </summary>
        [IrisColumn(Name = "OperatorNO", Desc = "编号", DbType = "Varchar(50)", SqlFieldName = "OperatorNO", Order = 4, CanBeNull = false)]
        [Required(ErrorMessage = "编号不能为空")]
        [StringLength(50, ErrorMessage = "编号长度不能超过50个字符")]
        public string OperatorNO { get; set; }

        /// <summary>
        /// 姓名
        /// </summary>
        [IrisColumn(Name = "OperatorName", Desc = "姓名", DbType = "Varchar(50)", SqlFieldName = "OperatorName", Order = 5, CanBeNull = false)]
        [Required(ErrorMessage = "姓名不能为空")]
        [StringLength(50, ErrorMessage = "姓名长度不能超过50个字符")]
        public string OperatorName { get; set; }

        /// <summary>
        /// 签到日期
        /// </summary>
        [IrisColumn(Name = "SignDate", Desc = "签到日期", DbType = "Date", SqlFieldName = "SignDate", Order = 6, CanBeNull = true)]
        public DateTime? SignDate { get; set; }

        /// <summary>
        /// MAC 地址
        /// </summary>
        [IrisColumn(Name = "Mac", Desc = "MAC 地址", DbType = "Varchar(50)", SqlFieldName = "Mac", Order = 7, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "MAC 地址长度不能超过50个字符")]
        public string Mac { get; set; }

        /// <summary>
        /// IP 地址
        /// </summary>
        [IrisColumn(Name = "IP", Desc = "IP 地址", DbType = "Varchar(50)", SqlFieldName = "IP", Order = 8, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "IP 地址长度不能超过50个字符")]
        public string IP { get; set; }

        /// <summary>
        /// 签到编号
        /// </summary>
        [IrisColumn(Name = "SignNo", Desc = "签到编号", DbType = "Varchar(50)", SqlFieldName = "SignNo", Order = 9, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "签到编号长度不能超过50个字符")]
        public string SignNo { get; set; }

        /// <summary>
        /// 区域
        /// </summary>
        [IrisColumn(Name = "Division", Desc = "区域", DbType = "Varchar(50)", SqlFieldName = "Division", Order = 10, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "区域长度不能超过50个字符")]
        public string Division { get; set; }

        /// <summary>
        /// 创建日期 系统自动产生
        /// </summary>
        [IrisColumn(Name = "CreateTime", Desc = "创建日期", DbType = "DateTime", SqlFieldName = "CreateTime", Order = 11, CanBeNull = false)]
        [Required(ErrorMessage = "创建日期不能为空")]
        public DateTime CreateTime { get; set; }

        /// <summary>
        /// 状态标志 -1表示无效 签退的情况下 赋值为-1
        /// </summary>
        [IrisColumn(Name = "State", Desc = "状态标志", DbType = "Varchar(50)", SqlFieldName = "State", Order = 12, CanBeNull = true)]
        [StringLength(50, ErrorMessage = "状态标志长度不能超过50个字符")]
        public string State { get; set; }
    }
}
