﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Newtonsoft.Json.Linq;
using PTMIBase.MIForm.BaseLine.ChooseCard;
using PTMIBase.Service.Iris;

namespace PPTMIBase.MIForm.BaseLine.ChooseCard
{
    public partial class SearchAdmdvs : Form
    {
        // 通过构造函数注入的 SearchAdmKey
        private readonly string _initialSearchAdmKey;

        // 替代 Global.pat.card 的两个属性
        public string SearchAdmCode { get; private set; }
        public string SearchAdmName { get; private set; }

        // 依赖注入：用于获取数据的服务接口
        private readonly IBaseIrisService _admdvsDataService;

        // 构造函数
        public SearchAdmdvs(string initialSearchAdmKey, IBaseIrisService admdvsDataService)
        {
            InitializeComponent();
            _initialSearchAdmKey = initialSearchAdmKey;
            _admdvsDataService = admdvsDataService ?? throw new ArgumentNullException(nameof(admdvsDataService));
        }

        private void FrmInsuplc_Admdvs_Load(object sender, EventArgs e)
        {
            // 初始化搜索关键字
            edt_SearchKey.Text = _initialSearchAdmKey;

            // 设置 GridView 数据
            GridViewSetter gvdSetter = new GridViewSetter();
            gvdSetter.SetAdmdvsData(dbAdmdvs);

            // 执行搜索
            Search(_initialSearchAdmKey);
        }

        private void btnOk_Click(object sender, EventArgs e)
        {
            SelectAdmIndex();
        }

        private void btnCancel_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void edt_SearchKey_DoEnter(object sender, EventArgs e)
        {
            Search(edt_SearchKey.Text);
        }

        private void Search(string sKey)
        {
            string filter = " AND DesCripts LIKE '%" + sKey + "%' ";
            string sqlStr = " SELECT TOP 8 B.Code, B.Descripts AS Name " +
                            " FROM HB_Dictionary A " +
                            " JOIN HB_DictionaryDataDetail B ON A.ID = B.HBDictionary_Dr " +
                            " WHERE A.InsuCode = 'admdvs'" + filter;

            // 使用依赖注入的服务获取数据
            DataTable dt = _admdvsDataService.GetAdmdvsTable(sqlStr);
            dbAdmdvs.DataSource = dt;
        }

        private void SelectAdmIndex()
        {
            if (dbAdmdvs.CurrentRow == null)
            {
                MessageBox.Show("请选择一个有效的行！");
                return;
            }

            int selectedIndex = dbAdmdvs.CurrentRow.Index;

            // 设置 SearchAdmCode 和 SearchAdmName 属性
            SearchAdmCode = dbAdmdvs.Rows[selectedIndex].Cells["Code"].Value.ToString();
            SearchAdmName = dbAdmdvs.Rows[selectedIndex].Cells["Name"].Value.ToString();

            DialogResult = DialogResult.OK;
        }

        private void dbAdmdvs_CellDoubleClick(object sender, DataGridViewCellEventArgs e)
        {
            SelectAdmIndex();
        }
    }
}
