﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace PTMIBase.Utils
{
    /// <summary>
    /// 日期处理工具
    /// </summary>
    class DateHelper
    {
        /// <summary>
        /// 返回当前短日期 yyyy-MM-dd
        /// </summary>
        /// <returns></returns>
        public static string GetShortDateTimeNow()
        {
            return DateTime.Now.ToString("yyyy-MM-dd");
        }

        /// <summary>
        /// 返回当前长日期 yyyy-MM-dd HH:mm:ss
        /// </summary>
        /// <returns></returns>
        public static string GetDateTimeNow()
        {
            return DateTime.Now.ToString("yyyy-MM-dd HH:mm:ss");
        }

        /// <summary>
        /// 获取交易号  hospitalNO + DateTime.Now.ToString("yyyyMMddHHmmssffff")
        /// </summary>
        /// <returns></returns>
        public static string GetTradeNo(string hospitalNO)
        {
            return hospitalNO + DateTime.Now.ToString("yyyyMMddHHmmssffff");
        }
        /// <summary>
        /// 日期转换为时间戳Timestamp
        /// </summary>
        /// <param name="dateTime">要转换的日期</param>
        /// <returns></returns>
        public static long GetTimeStamp(DateTime dateTime)
        {
            DateTime _dtStart = new DateTime(1970, 1, 1, 8, 0, 0);
            //10位的时间戳
            long timeStamp = Convert.ToInt32(dateTime.Subtract(_dtStart).TotalSeconds);
            //13位的时间戳
            //long timeStamp = Convert.ToInt64(dateTime.Subtract(_dtStart).TotalMilliseconds);
            return timeStamp;
        }

        /// <summary>
        /// UTC时间戳Timestamp转换为北京时间
        /// </summary>
        /// <param name="timestamp">要转换的时间戳</param>
        /// <returns></returns>
        public static DateTime GetDateTime(long timestamp)
        {
            //DateTime dtStart = TimeZone.CurrentTimeZone.ToLocalTime(new DateTime(1970, 1, 1)); 
            //使用上面的方式会显示TimeZone已过时
            DateTime dtStart = TimeZoneInfo.ConvertTime(new DateTime(1970, 1, 1), TimeZoneInfo.Local);
            DateTime targetDt = dtStart.AddMilliseconds(timestamp).AddHours(8);
            return targetDt;
        }


        /// <summary>
        /// UTC时间戳Timestamp转换为北京时间 yyyy-MM-dd
        /// </summary>
        /// <returns></returns>
        public static string ConvertLongToDate(string strValue)
        {
            DateTime dateTime = DateTimeOffset.FromUnixTimeMilliseconds(long.Parse(strValue)).DateTime;
            return dateTime.ToString("yyyy-MM-dd");
        }

        /// <summary>
        /// 将转换为yyyyMMdd  转换为 yyyy-MM-dd
        /// </summary>
        /// <param name="strValue"></param>
        /// <returns></returns>
        public static string ConvertShortDate(string strValue)
        {
            if (!strValue.Contains("-") && strValue.Length >= 8)
            {
                return strValue.Substring(0, 4) + "-" + strValue.Substring(4, 2) + "-" + strValue.Substring(6, 2);
            }
            return strValue.Length > 10 ? strValue.Substring(0, 10) : strValue;
        }

        /// <summary>
        /// 将yyyy-MM-dd 转换为yyyyMMdd
        /// </summary>
        /// <param name="strValue"></param>
        /// <returns></returns>
        public static string ConvertNoSplitDate(string strValue)
        {
            strValue = strValue.Replace("-", "");
            if (strValue.Length > 8)
            {
                strValue = strValue.Substring(0, 8);
            }
            return strValue;
        }
    }
}
