﻿
using Newtonsoft.Json.Linq;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.IO;
using Newtonsoft.Json;
using System.Windows.Forms;
using PTMIBase.Entity.Base.IrisTrade;
using PTMIBase.Utils.MIEncrypt;
using PTMIBase.Globals;

namespace PTMIBase.Utils
{
    public class JsonHelper
    {
        public static string toJsonString(object obj,bool missingNull)
        {
            JsonSerializerSettings settings = new JsonSerializerSettings();
            if (missingNull)
            {
                settings.NullValueHandling = NullValueHandling.Ignore;
            }
            return JsonConvert.SerializeObject(obj, Formatting.Indented, settings);
        }

        public static string toJsonString(object obj)
        {
            return toJsonString(obj,true);
        }

        public static JObject toJObject(object obj)
        {
            string data = toJsonString(obj, true);
            return JObject.Parse(data);
        }

        public static object toObject(string json)
        {
            return JsonConvert.DeserializeObject(json);
        }

        public static T toObject<T>(JObject joObject)
        {
            return joObject.ToObject<T>();
        }

        /// <summary>
        /// 解析医保平台返回对象
        /// </summary>
        /// <typeparam name="T"></typeparam>
        /// <param name="response"></param>
        /// <returns></returns>
        public static T getOutput<T>(JObject response)
        {
            if (response.ContainsKey("output")) 
            {
                return response["output"].ToObject<T>();
            }

            return response.ToObject<T>();
        }
        
        /// <summary>
        /// 解析IRIS系统返回对象
        /// </summary>
        /// <typeparam name="T"></typeparam>
        /// <param name="response"></param>
        /// <returns></returns>
        public static T getResult<T>(JObject response)
        {
            IrisResponse resp = response.ToObject<IrisResponse>();
            if (resp.errorCode == "0")
            {
                if (resp.result?.GetType() == typeof(JObject))
                {
                    JObject ret = (JObject)resp.result;
                    JArray lists = ret.Value<JArray>("rows");
                    if (lists?.Count > 0)
                    {
                        return lists.ToObject<T>();
                    }
                    else {
                        return ret.ToObject<T>();
                    }
                }
                if (resp.result?.GetType() == typeof(JArray))
                {
                    JArray lists = (JArray)resp.result;
                    if (lists?.Count > 0)
                    {
                        return lists[0].ToObject<T>();
                    }
                }
            }

            return default;

        }

        /// <summary>
        /// 根据JSonPath查找节点值，如果节点不存在则返回空值
        /// </summary>
        /// <param name="jo"></param>
        /// <param name="jsonPath"></param>
        /// <returns></returns>
        public static string getDestValue(JObject jo, string destPath)
        {
            JToken jt = jo.SelectToken("$." + destPath);
            if (jt != null)
            {
                return jt.ToString();
            }
            else
            {
                //GlobalVariables.writeLog(destPath + "的JToken属性值为空");
                return "";
            }
        }

        /// <summary>
        /// 将指定的json内容转为对象
        /// </summary>
        /// <typeparam name="T"></typeparam>
        /// <param name="jo"></param>
        /// <param name="destPath"></param>
        /// <returns></returns>
        public static T parseObject<T>(JObject jo, string destPath)
        {
            JToken jt = jo.SelectToken("$." + destPath);
            if (jt != null)
            {
                return jt.ToObject<T>();
            }
            else
            {
                //GlobalVariables.writeLog(destPath + "的JToken属性值为空");
                return default;
            }
        }


        public static string getDestProperty(JObject jo, string propertyName)
        {
            JProperty jp = jo.Property(propertyName);
            if (jp != null)
            {
                string jpStr = jp.ToString();
                string rtnResult = "{ " + jpStr + "}";
                return rtnResult;
            }
            else
            {
                //GlobalVariables.writeLog(propertyName + "的JProperty属性值为空");
                return "";
            }
            
        }
        /// <summary>
        /// 压缩JSON，占用体积减小(重载)
        /// </summary>
        /// <param name="json"></param>
        /// <returns></returns>
        public static string Compress(string json)
        {
            StringBuilder sb = new StringBuilder();
            using (StringReader reader = new StringReader(json))
            {
                int ch = -1;
                int lastch = -1;
                bool isQuoteStart = false;
                while ((ch = reader.Read()) > -1)
                {
                    if ((char) lastch != '\\' && (char) ch == '\"')
                    {
                        if (!isQuoteStart)
                        {
                            isQuoteStart = true;
                        }
                        else
                        {
                            isQuoteStart = false;
                        }
                    }
                    if (!Char.IsWhiteSpace((char) ch) || isQuoteStart)
                    {
                        sb.Append((char) ch);
                    }
                    lastch = ch;
                }
            }
            return sb.ToString();
        }
        public static string Compress(JObject jsonObj)
        {
            //https://blog.csdn.net/yangjiaosun/article/details/103717256
            return Newtonsoft.Json.JsonConvert.SerializeObject(jsonObj);
        }

        /// <summary>
        /// 组织异常JSON串
        /// </summary>
        /// <param name="errorCode"></param>
        /// <param name="errorMessage"></param>
        /// <returns></returns>
        public static JObject setExceptionJson(int errorCode, string eventName, string errorMessage)
        {
            dynamic joRtn = new JObject();
            joRtn.errorCode = errorCode;
            joRtn.errorMessage = eventName + "提示：" + errorMessage;
            return joRtn;
        }

        /// <summary>
        /// 组织中心入参(明文)。部分代码是需要解析明文入参的，为了方便增加该方法
        /// </summary>
        /// <param name="infno"></param>
        /// <param name="input"></param>
        /// <returns></returns>
        public static string setCenterInpar_plain(string infno, string input)
        {
            return setCenterInpar_plain(infno, (JObject)Newtonsoft.Json.JsonConvert.DeserializeObject(input));
        }

        /// <summary>
        /// 组织中心入参(明文)。部分代码是需要解析明文入参的，为了方便增加该方法
        /// </summary>
        /// <param name="infno"></param>
        /// <param name="input"></param>
        /// <returns></returns>
        public static string setCenterInpar_plain(string infno, JObject joInput)
        {
            return setCenterInpar(infno, joInput);
        }

        /// <summary>
        /// 移动支付组织中心入参
        /// </summary>
        /// <param name="infno"></param>
        /// <param name="input"></param>
        /// <returns></returns>
        public static string setMPCenterInpar(string infno, JObject joInput)
        {
            return setMPCenterInpar(infno, joInput.ToString());
        }

        /// <summary>
        /// 移动支付组织中心入参
        /// </summary>
        /// <param name="infno"></param>
        /// <param name="input"></param>
        /// <returns></returns>
        public static string setMPCenterInpar(string infno, string txtData)
        {
            EncryptHelper encrypt = new EncryptHelper();

            return "";
        }

        public static string setCenterInpar(string infno, JObject joInput)
        {
            dynamic Jo = new JObject();
            Jo.infno = infno;
            GlobalVariables.curEvt.MsgId = DateHelper.GetTradeNo(GlobalVariables.inf.HospitalNO);
            Jo.msgid = GlobalVariables.curEvt.MsgId;
            GlobalVariables.pat.CurrentInsuInfo.InsuplcAdmdvs = GlobalVariables.inf.MdtrtareaAdmvs;                                   

            //参保地为空默认传就医地区划
            if (string.IsNullOrEmpty(GlobalVariables.pat.CurrentInsuInfo.InsuplcAdmdvs))
            {
                GlobalVariables.pat.CurrentInsuInfo.InsuplcAdmdvs = GlobalVariables.inf.MdtrtareaAdmvs;
            }


            // 参保地医保区划
            Jo.insuplc_admdvs = GlobalVariables.pat.CurrentInsuInfo.InsuplcAdmdvs ?? "";
            // 就医地
            Jo.mdtrtarea_admvs = GlobalVariables.inf.MdtrtareaAdmvs;

            Jo.recer_sys_code = "SY";
            Jo.dev_no = "00FFF254308F";//设备编号
            Jo.dev_safe_info = ""; 
            Jo.signtype = "SM3"; ;
            Jo.infver = "v1.0";
            Jo.opter_type = GlobalVariables.user.Type; ;
            Jo.opter = GlobalVariables.user.ID; ;
            Jo.opter_name = GlobalVariables.user.Name; 
            Jo.inf_time = DateHelper.GetDateTimeNow();
            Jo.fixmedins_code = GlobalVariables.inf.HospitalNO;
            Jo.fixmedins_name = GlobalVariables.inf.HospitalName;
            Jo.sign_no = GlobalVariables.curEvt.SignNo;
            Jo.cainfo = "";
         
            //Jo.cainfo = "0416509a2c98da94f3840cfb45c6119365a0e166f608d7d1002d70f377ceb46cb0f0f483a20df1eb75e96e8498b9184106d9d8361bf37550ae8d228d6ad3e7127eb0de8868606f18f7a840f238200ab201cd5f10ec4f1490529d9e4c599f2a78dd1917287003ada3699fcc1046e493db974572386f898f3c9c96c5e0ea348e7dc0";
            if (joInput != null)
            {
                Jo.Add("input", joInput);
            }
            else
            {
                Jo.Add("input", "");
            }

            return Jo;
        }
        

        /// <summary>
        /// 组织Iris入参
        /// </summary>
        /// <param name="code"></param>
        /// <param name="joParam"></param>
        /// <returns></returns>
        public static JObject setIrisInpar(string code, JObject joParam)
        {
            try
            {
                dynamic joInparam = new JObject();
                joInparam.code = code;
                dynamic joTmp = new JObject();

                JArray jaParam = new JArray();

                jaParam.Add(joParam);
                if (!joInparam.ContainsKey("HospitalDr"))
                {
                    joInparam.Add("HospitalDr", GlobalVariables.inf.HospitalDr);
                }
                if (!joInparam.ContainsKey("InterfaceDr"))
                {
                    joInparam.Add("InterfaceDr", GlobalVariables.inf.InterfaceDr);
                }
                joInparam.Add("params", JArray.FromObject(jaParam));
                joInparam.Add("session", GlobalVariables.inparam.Session);
                return joInparam;
            }
            catch (Exception ex)
            {
                return setExceptionJson(-1, "setIrisInpar:", ex.Message);
            }

        }

        /// <summary>
        /// 组织Iris入参
        /// </summary>
        /// <param name="code"></param>
        /// <param name="joParam"></param>
        /// <returns></returns>
        public static JObject setIrisInpar(string code, JObject joParam, JObject joParam2)        
        {
            try
            {
                dynamic joInparam = new JObject();
                joInparam.code = code;
                dynamic joTmp = new JObject();

                JArray jaParam = new JArray();

                jaParam.Add(joParam);

                JArray jaParam2 = new JArray();

                jaParam2.Add(joParam);

                if (!joInparam.ContainsKey("HospitalDr"))
                {
                    joInparam.Add("HospitalDr", GlobalVariables.inf.HospitalDr);
                }
                if (!joInparam.ContainsKey("InterfaceDr"))
                {
                    joInparam.Add("InterfaceDr", GlobalVariables.inf.InterfaceDr);
                }
                joInparam.Add("params", JArray.FromObject(jaParam));
                joInparam.Add("pagination", JArray.FromObject(jaParam2));

                joInparam.Add("session", GlobalVariables.inparam.Session);
                return joInparam;
            }
            catch (Exception ex)
            {
                return setExceptionJson(-1, "setIrisInpar:", ex.Message);
            }

        }

        /// <summary>
        /// 组织Iris入参
        /// </summary>
        /// <param name="code"></param>
        /// <param name="joParam"></param>
        /// <returns></returns>
        public static JObject setIrisInpar(string code, JArray jaParams)
        {
            try
            {
                dynamic joInparam = new JObject();
                if (!joInparam.ContainsKey("interfaceDr"))
                {
                    joInparam.Add("interfaceDr", GlobalVariables.inf.InterfaceDr);
                }

                if (!joInparam.ContainsKey("hospitalDr"))
                {
                    joInparam.Add("hospitalDr", GlobalVariables.inf.HospitalDr);
                }

                joInparam.code = code;
                dynamic joTmp = new JObject();
                joInparam.Add("params", jaParams);
                joInparam.Add("session", GlobalVariables.inparam.Session);
                return joInparam;
            }
            catch (Exception ex)
            {
                return setExceptionJson(-1, "setIrisInpar:", ex.Message);
            }
        }

        /// <summary>
        /// 解析中心返参
        /// </summary>
        /// <param name="joRtn"></param>
        /// <param name="errorMsg"></param>
        /// <returns></returns>
        public static int parseCenterRtnValue(JObject joRtn,  out string errorMsg)
        {
            try
            {
                string infcode = getDestValue(joRtn, "infcode");
                string err_msg = getDestValue(joRtn, "err_msg");

                string errcode = getDestValue(joRtn, "errcode");
                string errorCode = getDestValue(joRtn, "errorCode");
                string resultCode = getDestValue(joRtn, "resultcode");
                if (!string.IsNullOrEmpty(errcode))
                {
                    errorMsg = getDestValue(joRtn, "errmsg");
                    return -1;
                }
                else if (!string.IsNullOrEmpty(errorCode))
                {
                    errorMsg = getDestValue(joRtn, "errorMessage");
                    return -2;
                }
                else if (!string.IsNullOrEmpty(resultCode))
                {
                    errorMsg = getDestValue(joRtn, "resulttext");
                    return -3;
                }
                else
                {
                    errorMsg = getDestValue(joRtn, "err_msg");
                    return int.Parse(getDestValue(joRtn, "infcode"));
                }
            }
            catch (Exception ex)
            {
                errorMsg = "解析中心返参发生异常：" + ex.Message;
                return -1;
            }
        }

        public static int parseIrisRtnResult(JObject joRtn, out string result)
        {
            try
            {
                int iResult = int.Parse(getDestValue(joRtn, "errorCode"));
                if (iResult == 0)
                {
                    result = getDestValue(joRtn, "result");
                }
                else
                {
                    result = getDestValue(joRtn, "errorMessage");
                }
                return iResult;
            }
            catch (Exception ex)
            {
                result = "解析Iris返参发生异常：" + ex.Message;
                return -1;
            }
        }

        /// <summary>
        /// 解析移动返参
        /// </summary>
        /// <param name="joRtn"></param>
        /// <param name="errorMsg"></param>
        /// <returns></returns>
        public static int parseMPRtnValue(JObject joRtn, out string errorMsg)
        {
            try
            {
                string success = getDestValue(joRtn, "success");
                string message = getDestValue(joRtn, "message");
                string encData = getDestValue(joRtn, "encData");
                if (string.IsNullOrEmpty(message)) {
                    message = getDestValue(joRtn, "errorMessage");
                }

                //GlobalVariables.writeLog("success:" + success);
                if (success != "True")
                {
                    errorMsg = message;
                    return -1;
                }
                else
                {
                    errorMsg = joRtn.ToString();
                    return 0;
                }
            }
            catch (Exception ex)
            {
                errorMsg = "解析中心返参发生异常：" + ex.Message;
                return -1;
            }
        }

        /// <summary>
        /// 组织IRIS返参
        /// </summary>
        /// <param name="errorCode"></param>
        /// <param name="errorMessage"></param>
        /// <param name="joResult"></param>
        /// <returns></returns>
        public static JObject setIrisReturnValue(int errorCode, string errorMessage, JObject joResult)
        {
            try
            {
                dynamic joRtn = new JObject();
                joRtn.errorCode = errorCode;
                joRtn.errorMessage = errorMessage;
                joRtn.Add("result", joResult);
                return joRtn;
            }
            catch (Exception ex)
            {
                return setExceptionJson(-1, "setIrisReturnValue:", ex.Message);
            }
        }

        /// <summary>
        /// 解析IRIS返参
        /// </summary>
        /// <param name="joRtn"></param>
        /// <param name="errorMsg"></param>
        /// <returns></returns>
        /// 
        public static int parseIrisRtnValue(JObject joRtn, out string errorMsg)
        {
            try
            {
                errorMsg = getDestValue(joRtn, "errorMessage");
                return int.Parse(getDestValue(joRtn, "errorCode"));
            }
            catch (Exception ex)
            {
                errorMsg = "解析Iris返参发生异常：" + ex.Message;
                return -1;
            }
        }

        /// <summary>
        /// 解析业务JSON串（业务串固定格式为{errorCode = ,errorMessage = ,result ={}}）
        /// </summary>
        /// <param name="json"></param>
        /// <param name="errorMsg"></param>
        /// <returns></returns>
        public static int parseCenterReturnJson(JObject json, out string errorMsg)
        {
            try
            {
                errorMsg = "";
                if (int.Parse(json["infcode"].ToString()) != 0)
                {
                    errorMsg = json["err_msg"].ToString();
                }
                return int.Parse(json["infcode"].ToString());
            }
            catch (Exception ex)
            {
                errorMsg = "parseCenterReturnJson" + ex.Message;
                return -1;
            }

        }

        
        /// <summary>
        /// 解析中心返参
        /// </summary>
        /// <param name="joRtn"></param>
        /// <param name="errorMsg"></param>
        /// <returns></returns>
        public static int parseEPCenterRtnValue(JObject joRtn, out string errorMsg)
        {
            try
            {
                string errcode = getDestValue(joRtn, "errcode");
                string errorCode = getDestValue(joRtn, "errorCode");
                if (errcode != "")
                {
                    errorMsg = getDestValue(joRtn, "message");
                    return -1;
                }
                else if (errorCode != "")
                {
                    errorMsg = getDestValue(joRtn, "errorMessage");
                    return -2;
                }
                else
                {
                    errorMsg = getDestValue(joRtn, "message");
                    return int.Parse(getDestValue(joRtn, "code"));
                }
            }
            catch (Exception ex)
            {
                errorMsg = "解析中心返参发生异常：" + ex.Message;
                return -1;
            }
        }
    }
}
